!USER_ENTERED_COMMAND acme multipost setup arbitrary_solver_functions
!WRAP_IN_UNDO NO
!
!  Adams Car-Ride
!  Copyright (C) 2016 MSC Software Corporation
!  All Rights Reserved.
!
!*******************************************************************
!
! Perform setup operations for the MULTI_POST_TESTRIG for
! analyses using arbitrary solver functions.
!
! $assembly:t=model
! $sfn_lf:t=string:d="0.0"
! $sfn_rf:t=string:d="0.0"
! $sfn_lr:t=string:d="0.0"
! $sfn_rr:t=string:d="0.0"
! $sfn_lr2:t=string:d=''0.0''
! $sfn_rr2:t=string:d=''0.0''
! $sfn_units:t=string
!
!END_OF_PARAMETERS
!
!
variable set variable_name=$_self.actuation_type &
 string_value=(eval(.ACME.multipost.variables.flag_actuation_type))
!
!!! Check actuation type.
if condition=(eval($_self.actuation_type!="displacement" && $_self.actuation_type!="velocity" && $_self.actuation_type!="acceleration" && $_self.actuation_type!="force"))
   acar toolkit warning &
    warning=(eval("\"$_self.actuation_type\" is an invalid actuation option for arbitrary")), &
            "solver-function excitation of the MULTI_POST_TESTRIG."
   variable set variable_name=.ACME.multipost.variables.errorFlag &
    integer_value=1
   return
end
!
!!! Obtain and store the solver-function units gain.
variable set variable_name=$_self.units_gain real_value=1.0
acme multipost setup units_gain &
 units="$sfn_units" &
 units_gain=$_self.units_gain &
 
!!! Create variables to hold the actuators (shorter names).
variable set variable_name=$_self.pad_lf &
 object_value=(eval($assembly.testrig.jms_post_pad_vertical_lf))
variable set variable_name=$_self.pad_rf &
 object_value=(eval($assembly.testrig.jms_post_pad_vertical_rf))
variable set variable_name=$_self.pad_lr &
 object_value=(eval($assembly.testrig.jms_post_pad_vertical_lr))
variable set variable_name=$_self.pad_rr &
 object_value=(eval($assembly.testrig.jms_post_pad_vertical_rr))
variable set variable_name=$_self.pad_lr2 &
 object_value=(eval($assembly.testrig.jms_post_pad_vertical_lr2))
variable set variable_name=$_self.pad_rr2 &
 object_value=(eval($assembly.testrig.jms_post_pad_vertical_rr2))


!
variable set variable_name=$_self.jprim_lf &
 object_value=(eval($assembly.testrig.jolinp_mount_post_to_spindle_vertical_front))
variable set variable_name=$_self.jprim_rf &
 object_value=(eval($assembly.testrig.jorinp_mount_post_to_spindle_vertical_front))
variable set variable_name=$_self.jprim_lr &
 object_value=(eval($assembly.testrig.jolinp_mount_post_to_spindle_vertical_rear))
variable set variable_name=$_self.jprim_rr &
 object_value=(eval($assembly.testrig.jorinp_mount_post_to_spindle_vertical_rear))
variable set variable_name=$_self.jprim_lr2 &
 object_value=(eval($assembly.testrig.jolinp_mount_post_to_spindle_vertical_rear2))
variable set variable_name=$_self.jprim_rr2 &
 object_value=(eval($assembly.testrig.jorinp_mount_post_to_spindle_vertical_rear2))
!
!!! Assign actuator functions to be the passed-in solver functions.
!
   !!! Set the activity of the post-to-spindle joints based upon
   !!! the input locations for the actuators.
   if condition=(eval(.ACME.multipost.variables.flag_input_locations)=="wheel spindles")
      constraint attributes constraint_name=(eval($_self.jprim_lf)) active=no_opinion dependents_active=no_opinion
      constraint attributes constraint_name=(eval($_self.jprim_rf)) active=no_opinion dependents_active=no_opinion
      constraint attributes constraint_name=(eval($_self.jprim_lr)) active=no_opinion dependents_active=no_opinion
      constraint attributes constraint_name=(eval($_self.jprim_rr)) active=no_opinion dependents_active=no_opinion
      constraint attributes constraint_name=(eval($_self.jprim_lr2)) active=no_opinion dependents_active=no_opinion
      constraint attributes constraint_name=(eval($_self.jprim_rr2)) active=no_opinion dependents_active=no_opinion
   else
      constraint attributes constraint_name=(eval($_self.jprim_lf)) active=off dependents_active=off
      constraint attributes constraint_name=(eval($_self.jprim_rf)) active=off dependents_active=off
      constraint attributes constraint_name=(eval($_self.jprim_lr)) active=off dependents_active=off
      constraint attributes constraint_name=(eval($_self.jprim_rr)) active=off dependents_active=off
      constraint attributes constraint_name=(eval($_self.jprim_lr2)) active=off dependents_active=off
      constraint attributes constraint_name=(eval($_self.jprim_rr2)) active=off dependents_active=off
   end 
 
   if condition=((eval($_self.units_gain==1.0)))
      acar template_builder actuator set function &
       actuator=(eval($_self.pad_lf)) function="$sfn_lf"
      acar template_builder actuator set function &
       actuator=(eval($_self.pad_rf)) function="$sfn_rf"
      acar template_builder actuator set function &
       actuator=(eval($_self.pad_lr)) function="$sfn_lr"
      acar template_builder actuator set function &
       actuator=(eval($_self.pad_rr)) function="$sfn_rr"
      acar template_builder actuator set function &
       actuator=(eval($_self.pad_lr2)) function="$sfn_lr2"
      acar template_builder actuator set function &
       actuator=(eval($_self.pad_rr2)) function="$sfn_rr2"
   else
      acar template_builder actuator set function &
       actuator=(eval($_self.pad_lf)) &
       function=(eval($_self.units_gain//"*$sfn_lf"))
      acar template_builder actuator set function &
       actuator=(eval($_self.pad_rf)) &
       function=(eval($_self.units_gain//"*$sfn_rf"))
      acar template_builder actuator set function &
       actuator=(eval($_self.pad_lr)) &
       function=(eval($_self.units_gain//"*$sfn_lr"))
      acar template_builder actuator set function &
       actuator=(eval($_self.pad_rr)) &
       function=(eval($_self.units_gain//"*$sfn_rr"))
      acar template_builder actuator set function &
       actuator=(eval($_self.pad_lr2)) &
       function=(eval($_self.units_gain//"*$sfn_lr2"))
      acar template_builder actuator set function &
       actuator=(eval($_self.pad_rr2)) &
       function=(eval($_self.units_gain//"*$sfn_rr2"))
   end
   
variable delete variable_name=(eval(db_children($_self,"variable")))
   
   
