!
!-------------------------- Default Units for Model ---------------------------!
!
!
defaults units  &
   length = mm  &
   angle = deg  &
   force = newton  &
   mass = kg  &
   time = sec
!
defaults units  &
   coordinate_system_type = cartesian  &
   orientation_type = body313
!
!------------------------ Default Attributes for Model ------------------------!
!
!
defaults attributes  &
   inheritance = bottom_up  &
   icon_visibility = off  &
   grid_visibility = off  &
   size_of_icons = 50.0  &
   spacing_for_grid = 1000.0
!
!--------------------------- Plugins used by Model ----------------------------!
!
!
plugin load  &
   plugin_name = .MDI.plugins.acar
!
!------------------------------ Adams View Model ------------------------------!
!
!
model create  &
   model_name = __ACME_MULTI_POST_TESTRIG  &
   title = "Adams Car template"
!
view erase
!
!-------------------------------- Data storage --------------------------------!
!
!
data_element create variable  &
   variable_name = .__ACME_MULTI_POST_TESTRIG._cv_solver_variable  &
   comments = "Dummy for communicators"  &
   initial_condition = 0.0  &
   function = ""
!
data_element attributes  &
   data_element_name = .__ACME_MULTI_POST_TESTRIG._cv_solver_variable  &
   visibility = off
!
data_element create array ic_array  &
   array_name = .__ACME_MULTI_POST_TESTRIG._cv_array  &
   comments = "Dummy for communicators"  &
   size = 1  &
   numbers = 0.0
!
data_element attributes  &
   data_element_name = .__ACME_MULTI_POST_TESTRIG._cv_array  &
   visibility = off
!
data_element create spline  &
   spline_name = .__ACME_MULTI_POST_TESTRIG._cv_spline  &
   comments = "Dummy for communicators"  &
   x = 1.0, 2.0, 3.0, 4.0  &
   y = 1.0, 2.0, 3.0, 4.0, 1.0, 2.0, 3.0, 4.0  &
   z = 1.0, 2.0  &
   linear_extrapolate = no
!
data_element attributes  &
   data_element_name = .__ACME_MULTI_POST_TESTRIG._cv_spline  &
   visibility = off
!
data_element create string  &
   string_name = .__ACME_MULTI_POST_TESTRIG.minor_role_string  &
   comments = "Memory for Adams Car minor role"  &
   string = "any"
!
data_element attributes  &
   data_element_name = .__ACME_MULTI_POST_TESTRIG.minor_role_string  &
   visibility = off
!
!--------------------------------- Materials ----------------------------------!
!
!
material create  &
   material_name = .__ACME_MULTI_POST_TESTRIG.steel  &
   density = 7.801E-006  &
   youngs_modulus = 2.07E+005  &
   poissons_ratio = 0.29
!
!-------------------------------- Rigid Parts ---------------------------------!
!
! Create parts and their dependent markers and graphics
!
!----------------------------------- ground -----------------------------------!
!
!
! ****** Ground Part ******
!
part modify rigid_body name_and_position  &
   part_name = ground
!
defaults model  &
   part_name = ground
!
defaults coordinate_system  &
   default_coordinate_system = .__ACME_MULTI_POST_TESTRIG.ground
!
! ****** Markers for current part ******
!
marker create  &
   marker_name = .__ACME_MULTI_POST_TESTRIG.ground.origo  &
   location = 0.0, 0.0, 0.0  &
   orientation = 0.0d, 0.0d, 0.0d
!
marker create  &
   marker_name = .__ACME_MULTI_POST_TESTRIG.ground._cv_marker  &
   comments = "Dummy for communicators"  &
   location = 0.0, 0.0, 0.0  &
   orientation = 0.0d, 0.0d, 0.0d
!
marker attributes  &
   marker_name = .__ACME_MULTI_POST_TESTRIG.ground._cv_marker  &
   visibility = off  &
   name_visibility = off
!
marker create  &
   marker_name = .__ACME_MULTI_POST_TESTRIG.ground.cfl_wheel_center_front  &
   location = 0.0, -750.0, 0.0  &
   orientation = 0.0d, 0.0d, 0.0d
!
marker attributes  &
   marker_name = .__ACME_MULTI_POST_TESTRIG.ground.cfl_wheel_center_front  &
   color = MAIZE
!
marker create  &
   marker_name = .__ACME_MULTI_POST_TESTRIG.ground.cfr_wheel_center_front  &
   location = 0.0, 750.0, 0.0  &
   orientation = 0.0d, 0.0d, 0.0d
!
marker attributes  &
   marker_name = .__ACME_MULTI_POST_TESTRIG.ground.cfr_wheel_center_front  &
   color = MAIZE
!
marker create  &
   marker_name = .__ACME_MULTI_POST_TESTRIG.ground.cfl_wheel_center_rear  &
   location = 2700.0, -750.0, 0.0  &
   orientation = 0.0d, 0.0d, 0.0d
!
marker attributes  &
   marker_name = .__ACME_MULTI_POST_TESTRIG.ground.cfl_wheel_center_rear  &
   color = MAIZE
!
marker create  &
   marker_name = .__ACME_MULTI_POST_TESTRIG.ground.cfr_wheel_center_rear  &
   location = 2700.0, 750.0, 0.0  &
   orientation = 0.0d, 0.0d, 0.0d
!
marker attributes  &
   marker_name = .__ACME_MULTI_POST_TESTRIG.ground.cfr_wheel_center_rear  &
   color = MAIZE
!
marker create  &
   marker_name = .__ACME_MULTI_POST_TESTRIG.ground.cfl_wheel_center_rear2  &
   location = 4000.0, -750.0, 0.0  &
   orientation = 0.0d, 0.0d, 0.0d
!
marker attributes  &
   marker_name = .__ACME_MULTI_POST_TESTRIG.ground.cfl_wheel_center_rear2  &
   color = MAIZE
!
marker create  &
   marker_name = .__ACME_MULTI_POST_TESTRIG.ground.cfr_wheel_center_rear2  &
   location = 4000.0, 750.0, 0.0  &
   orientation = 0.0d, 0.0d, 0.0d
!
marker attributes  &
   marker_name = .__ACME_MULTI_POST_TESTRIG.ground.cfr_wheel_center_rear2  &
   color = MAIZE
!
marker create  &
   marker_name = .__ACME_MULTI_POST_TESTRIG.ground.cfl_mount_post_pad_vertical_front  &
   location = 0.0, -750.0, 0.0  &
   orientation = 0.0d, 0.0d, 0.0d
!
marker attributes  &
   marker_name = .__ACME_MULTI_POST_TESTRIG.ground.cfl_mount_post_pad_vertical_front  &
   color = MAIZE
!
marker create  &
   marker_name = .__ACME_MULTI_POST_TESTRIG.ground.cfr_mount_post_pad_vertical_front  &
   location = 0.0, 750.0, 0.0  &
   orientation = 0.0d, 0.0d, 0.0d
!
marker attributes  &
   marker_name = .__ACME_MULTI_POST_TESTRIG.ground.cfr_mount_post_pad_vertical_front  &
   color = MAIZE
!
marker create  &
   marker_name = .__ACME_MULTI_POST_TESTRIG.ground.cfl_mount_post_pad_vertical_rear  &
   location = 2700.0, -750.0, 0.0  &
   orientation = 0.0d, 0.0d, 0.0d
!
marker attributes  &
   marker_name = .__ACME_MULTI_POST_TESTRIG.ground.cfl_mount_post_pad_vertical_rear  &
   color = MAIZE
!
marker create  &
   marker_name = .__ACME_MULTI_POST_TESTRIG.ground.cfr_mount_post_pad_vertical_rear  &
   location = 2700.0, 750.0, 0.0  &
   orientation = 0.0d, 0.0d, 0.0d
!
marker attributes  &
   marker_name = .__ACME_MULTI_POST_TESTRIG.ground.cfr_mount_post_pad_vertical_rear  &
   color = MAIZE
!
marker create  &
   marker_name = .__ACME_MULTI_POST_TESTRIG.ground.cfl_mount_post_pad_vertical_rear2  &
   location = 4000.0, -750.0, 0.0  &
   orientation = 0.0d, 0.0d, 0.0d
!
marker attributes  &
   marker_name = .__ACME_MULTI_POST_TESTRIG.ground.cfl_mount_post_pad_vertical_rear2  &
   color = MAIZE
!
marker create  &
   marker_name = .__ACME_MULTI_POST_TESTRIG.ground.cfr_mount_post_pad_vertical_rear2  &
   location = 4000.0, 750.0, 0.0  &
   orientation = 0.0d, 0.0d, 0.0d
!
marker attributes  &
   marker_name = .__ACME_MULTI_POST_TESTRIG.ground.cfr_mount_post_pad_vertical_rear2  &
   color = MAIZE
!
marker create  &
   marker_name = .__ACME_MULTI_POST_TESTRIG.ground.base_cm_fl  &
   location = 0.0, -750.0, -2400.0  &
   orientation = 0.0d, 0.0d, 0.0d
!
marker attributes  &
   marker_name = .__ACME_MULTI_POST_TESTRIG.ground.base_cm_fl  &
   visibility = off  &
   name_visibility = off
!
marker create  &
   marker_name = .__ACME_MULTI_POST_TESTRIG.ground.base_cm_fr  &
   location = 0.0, 750.0, -2400.0  &
   orientation = 0.0d, 0.0d, 0.0d
!
marker attributes  &
   marker_name = .__ACME_MULTI_POST_TESTRIG.ground.base_cm_fr  &
   visibility = off  &
   name_visibility = off
!
marker create  &
   marker_name = .__ACME_MULTI_POST_TESTRIG.ground.base_cm_rl  &
   location = 2700.0, -750.0, -2400.0  &
   orientation = 0.0d, 0.0d, 0.0d
!
marker attributes  &
   marker_name = .__ACME_MULTI_POST_TESTRIG.ground.base_cm_rl  &
   visibility = off  &
   name_visibility = off
!
marker create  &
   marker_name = .__ACME_MULTI_POST_TESTRIG.ground.base_cm_rr  &
   location = 2700.0, 750.0, -2400.0  &
   orientation = 0.0d, 0.0d, 0.0d
!
marker attributes  &
   marker_name = .__ACME_MULTI_POST_TESTRIG.ground.base_cm_rr  &
   visibility = off  &
   name_visibility = off
!
marker create  &
   marker_name = .__ACME_MULTI_POST_TESTRIG.ground.base_cm_r2l  &
   location = 4000.0, -750.0, -2400.0  &
   orientation = 0.0d, 0.0d, 0.0d
!
marker attributes  &
   marker_name = .__ACME_MULTI_POST_TESTRIG.ground.base_cm_r2l  &
   visibility = off  &
   name_visibility = off
!
marker create  &
   marker_name = .__ACME_MULTI_POST_TESTRIG.ground.base_cm_r2r  &
   location = 4000.0, 750.0, -2400.0  &
   orientation = 0.0d, 0.0d, 0.0d
!
marker attributes  &
   marker_name = .__ACME_MULTI_POST_TESTRIG.ground.base_cm_r2r  &
   visibility = off  &
   name_visibility = off
!
marker create  &
   marker_name = .__ACME_MULTI_POST_TESTRIG.ground.jxs_joint_j_1  &
   location = 0.0, -750.0, -400.0  &
   orientation = 0.0d, 0.0d, 0.0d
!
marker attributes  &
   marker_name = .__ACME_MULTI_POST_TESTRIG.ground.jxs_joint_j_1  &
   visibility = off  &
   name_visibility = off
!
marker create  &
   marker_name = .__ACME_MULTI_POST_TESTRIG.ground.jxs_joint_j_2  &
   location = 0.0, 750.0, -400.0  &
   orientation = 0.0d, 0.0d, 0.0d
!
marker attributes  &
   marker_name = .__ACME_MULTI_POST_TESTRIG.ground.jxs_joint_j_2  &
   visibility = off  &
   name_visibility = off
!
marker create  &
   marker_name = .__ACME_MULTI_POST_TESTRIG.ground.jxs_joint_j_3  &
   location = 2700.0, -750.0, -400.0  &
   orientation = 0.0d, 0.0d, 0.0d
!
marker attributes  &
   marker_name = .__ACME_MULTI_POST_TESTRIG.ground.jxs_joint_j_3  &
   visibility = off  &
   name_visibility = off
!
marker create  &
   marker_name = .__ACME_MULTI_POST_TESTRIG.ground.jxs_joint_j_4  &
   location = 4000.0, -750.0, -400.0  &
   orientation = 0.0d, 0.0d, 0.0d
!
marker attributes  &
   marker_name = .__ACME_MULTI_POST_TESTRIG.ground.jxs_joint_j_4  &
   visibility = off  &
   name_visibility = off
!
marker create  &
   marker_name = .__ACME_MULTI_POST_TESTRIG.ground.jxs_joint_j_5  &
   location = 2700.0, 750.0, -400.0  &
   orientation = 0.0d, 0.0d, 0.0d
!
marker attributes  &
   marker_name = .__ACME_MULTI_POST_TESTRIG.ground.jxs_joint_j_5  &
   visibility = off  &
   name_visibility = off
!
marker create  &
   marker_name = .__ACME_MULTI_POST_TESTRIG.ground.jxs_joint_j_6  &
   location = 4000.0, 750.0, -400.0  &
   orientation = 0.0d, 0.0d, 0.0d
!
marker attributes  &
   marker_name = .__ACME_MULTI_POST_TESTRIG.ground.jxs_joint_j_6  &
   visibility = off  &
   name_visibility = off
!
marker create  &
   marker_name = .__ACME_MULTI_POST_TESTRIG.ground.mtl_mount_j_1  &
   location = 0.0, -750.0, 0.0  &
   orientation = 0.0d, 0.0d, 0.0d
!
marker attributes  &
   marker_name = .__ACME_MULTI_POST_TESTRIG.ground.mtl_mount_j_1  &
   visibility = off  &
   name_visibility = off
!
marker create  &
   marker_name = .__ACME_MULTI_POST_TESTRIG.ground.mtr_mount_j_1  &
   location = 0.0, 750.0, 0.0  &
   orientation = 0.0d, 0.0d, 0.0d
!
marker attributes  &
   marker_name = .__ACME_MULTI_POST_TESTRIG.ground.mtr_mount_j_1  &
   visibility = off  &
   name_visibility = off
!
marker create  &
   marker_name = .__ACME_MULTI_POST_TESTRIG.ground.mtl_mount_j_2  &
   location = 2700.0, -750.0, 0.0  &
   orientation = 0.0d, 0.0d, 0.0d
!
marker attributes  &
   marker_name = .__ACME_MULTI_POST_TESTRIG.ground.mtl_mount_j_2  &
   visibility = off  &
   name_visibility = off
!
marker create  &
   marker_name = .__ACME_MULTI_POST_TESTRIG.ground.mtr_mount_j_2  &
   location = 2700.0, 750.0, 0.0  &
   orientation = 0.0d, 0.0d, 0.0d
!
marker attributes  &
   marker_name = .__ACME_MULTI_POST_TESTRIG.ground.mtr_mount_j_2  &
   visibility = off  &
   name_visibility = off
!
marker create  &
   marker_name = .__ACME_MULTI_POST_TESTRIG.ground.mtl_mount_j_3  &
   location = 4000.0, -750.0, 0.0  &
   orientation = 0.0d, 0.0d, 0.0d
!
marker attributes  &
   marker_name = .__ACME_MULTI_POST_TESTRIG.ground.mtl_mount_j_3  &
   visibility = off  &
   name_visibility = off
!
marker create  &
   marker_name = .__ACME_MULTI_POST_TESTRIG.ground.mtr_mount_j_3  &
   location = 4000.0, 750.0, 0.0  &
   orientation = 0.0d, 0.0d, 0.0d
!
marker attributes  &
   marker_name = .__ACME_MULTI_POST_TESTRIG.ground.mtr_mount_j_3  &
   visibility = off  &
   name_visibility = off
!
marker create  &
   marker_name = .__ACME_MULTI_POST_TESTRIG.ground.cfs_body_subsystem  &
   location = 0.0, 0.0, 0.0  &
   orientation = 0.0d, 0.0d, 0.0d
!
marker attributes  &
   marker_name = .__ACME_MULTI_POST_TESTRIG.ground.cfs_body_subsystem  &
   color = MAIZE
!
marker create  &
   marker_name = .__ACME_MULTI_POST_TESTRIG.ground.mts_mount_j_1  &
   location = 0.0, 0.0, 0.0  &
   orientation = 0.0d, 0.0d, 0.0d
!
marker attributes  &
   marker_name = .__ACME_MULTI_POST_TESTRIG.ground.mts_mount_j_1  &
   visibility = off  &
   name_visibility = off
!
marker create  &
   marker_name = .__ACME_MULTI_POST_TESTRIG.ground.jxs_joint_j_7  &
   location = 0.0, 0.0, 0.0  &
   orientation = 90.0d, 90.0d, 0.0d
!
marker attributes  &
   marker_name = .__ACME_MULTI_POST_TESTRIG.ground.jxs_joint_j_7  &
   visibility = off  &
   name_visibility = off
!
marker create  &
   marker_name = .__ACME_MULTI_POST_TESTRIG.ground.jxs_joint_j_8  &
   location = 0.0, 0.0, 0.0  &
   orientation = 0.0d, 0.0d, 0.0d
!
marker attributes  &
   marker_name = .__ACME_MULTI_POST_TESTRIG.ground.jxs_joint_j_8  &
   visibility = off  &
   name_visibility = off
!
marker create  &
   marker_name = .__ACME_MULTI_POST_TESTRIG.ground.std_tire_ref  &
   location = 0.0, 0.0, 0.0  &
   orientation = 0.0d, 0.0d, 0.0d
!
marker attributes  &
   marker_name = .__ACME_MULTI_POST_TESTRIG.ground.std_tire_ref  &
   visibility = off
!
marker create  &
   marker_name = .__ACME_MULTI_POST_TESTRIG.ground.cfl_mount_post_base_vertical_front  &
   location = 0.0, -750.0, -400.0  &
   orientation = 0.0d, 0.0d, 0.0d
!
marker attributes  &
   marker_name = .__ACME_MULTI_POST_TESTRIG.ground.cfl_mount_post_base_vertical_front  &
   color = MAIZE
!
marker create  &
   marker_name = .__ACME_MULTI_POST_TESTRIG.ground.cfr_mount_post_base_vertical_front  &
   location = 0.0, 750.0, -400.0  &
   orientation = 0.0d, 0.0d, 0.0d
!
marker attributes  &
   marker_name = .__ACME_MULTI_POST_TESTRIG.ground.cfr_mount_post_base_vertical_front  &
   color = MAIZE
!
marker create  &
   marker_name = .__ACME_MULTI_POST_TESTRIG.ground.cfl_mount_post_base_vertical_rear  &
   location = 2700.0, -750.0, -400.0  &
   orientation = 0.0d, 0.0d, 0.0d
!
marker attributes  &
   marker_name = .__ACME_MULTI_POST_TESTRIG.ground.cfl_mount_post_base_vertical_rear  &
   color = MAIZE
!
marker create  &
   marker_name = .__ACME_MULTI_POST_TESTRIG.ground.cfr_mount_post_base_vertical_rear  &
   location = 2700.0, 750.0, -400.0  &
   orientation = 0.0d, 0.0d, 0.0d
!
marker attributes  &
   marker_name = .__ACME_MULTI_POST_TESTRIG.ground.cfr_mount_post_base_vertical_rear  &
   color = MAIZE
!
marker create  &
   marker_name = .__ACME_MULTI_POST_TESTRIG.ground.cfl_mount_post_base_vertical_rear2  &
   location = 4000.0, -750.0, -400.0  &
   orientation = 0.0d, 0.0d, 0.0d
!
marker attributes  &
   marker_name = .__ACME_MULTI_POST_TESTRIG.ground.cfl_mount_post_base_vertical_rear2  &
   color = MAIZE
!
marker create  &
   marker_name = .__ACME_MULTI_POST_TESTRIG.ground.cfr_mount_post_base_vertical_rear2  &
   location = 4000.0, 750.0, -400.0  &
   orientation = 0.0d, 0.0d, 0.0d
!
marker attributes  &
   marker_name = .__ACME_MULTI_POST_TESTRIG.ground.cfr_mount_post_base_vertical_rear2  &
   color = MAIZE
!
! ****** Graphics for current part ******
!
geometry create shape cylinder  &
   cylinder_name = .__ACME_MULTI_POST_TESTRIG.ground.base_vertical_fl  &
   center_marker = .__ACME_MULTI_POST_TESTRIG.ground.base_cm_fl  &
   angle_extent = 360.0  &
   length = 1600.0  &
   radius = 100.0  &
   side_count_for_body = 20  &
   segment_count_for_ends = 20
!
geometry create shape cylinder  &
   cylinder_name = .__ACME_MULTI_POST_TESTRIG.ground.base_vertical_fr  &
   center_marker = .__ACME_MULTI_POST_TESTRIG.ground.base_cm_fr  &
   angle_extent = 360.0  &
   length = 1600.0  &
   radius = 100.0  &
   side_count_for_body = 20  &
   segment_count_for_ends = 20
!
geometry create shape cylinder  &
   cylinder_name = .__ACME_MULTI_POST_TESTRIG.ground.base_vertical_rl  &
   center_marker = .__ACME_MULTI_POST_TESTRIG.ground.base_cm_rl  &
   angle_extent = 360.0  &
   length = 1600.0  &
   radius = 100.0  &
   side_count_for_body = 20  &
   segment_count_for_ends = 20
!
geometry create shape cylinder  &
   cylinder_name = .__ACME_MULTI_POST_TESTRIG.ground.base_vertical_rr  &
   center_marker = .__ACME_MULTI_POST_TESTRIG.ground.base_cm_rr  &
   angle_extent = 360.0  &
   length = 1600.0  &
   radius = 100.0  &
   side_count_for_body = 20  &
   segment_count_for_ends = 20
!
geometry create shape cylinder  &
   cylinder_name = .__ACME_MULTI_POST_TESTRIG.ground.base_vertical_r2l  &
   center_marker = .__ACME_MULTI_POST_TESTRIG.ground.base_cm_r2l  &
   angle_extent = 360.0  &
   length = 1600.0  &
   radius = 100.0  &
   side_count_for_body = 20  &
   segment_count_for_ends = 20
!
geometry create shape cylinder  &
   cylinder_name = .__ACME_MULTI_POST_TESTRIG.ground.base_vertical_r2r  &
   center_marker = .__ACME_MULTI_POST_TESTRIG.ground.base_cm_r2r  &
   angle_extent = 360.0  &
   length = 1600.0  &
   radius = 100.0  &
   side_count_for_body = 20  &
   segment_count_for_ends = 20
!
!---------------------------------- _cv_part ----------------------------------!
!
!
defaults coordinate_system  &
   default_coordinate_system = .__ACME_MULTI_POST_TESTRIG.ground
!
part create rigid_body name_and_position  &
   part_name = .__ACME_MULTI_POST_TESTRIG._cv_part  &
   comments = "Dummy for communicators"  &
   location = 0.0, 0.0, 0.0  &
   orientation = 0.0d, 0.0d, 0.0d
!
defaults coordinate_system  &
   default_coordinate_system = .__ACME_MULTI_POST_TESTRIG._cv_part
!
! ****** Markers for current part ******
!
marker create  &
   marker_name = .__ACME_MULTI_POST_TESTRIG._cv_part.marker  &
   comments = "Dummy for communicators"  &
   location = 0.0, 0.0, 0.0  &
   orientation = 0.0d, 0.0d, 0.0d
!
marker attributes  &
   marker_name = .__ACME_MULTI_POST_TESTRIG._cv_part.marker  &
   visibility = off  &
   name_visibility = off
!
part create rigid_body mass_properties  &
   part_name = .__ACME_MULTI_POST_TESTRIG._cv_part  &
   mass = 0.0  &
   center_of_mass_marker = .__ACME_MULTI_POST_TESTRIG._cv_part.marker  &
   ixx = 0.0  &
   iyy = 0.0  &
   izz = 0.0  &
   ixy = 0.0  &
   izx = 0.0  &
   iyz = 0.0
!
part attributes  &
   part_name = .__ACME_MULTI_POST_TESTRIG._cv_part  &
   visibility = off  &
   name_visibility = off
!
!--------------------- gel_mount_post_pad_vertical_front ----------------------!
!
!
defaults coordinate_system  &
   default_coordinate_system = .__ACME_MULTI_POST_TESTRIG.ground
!
part create rigid_body name_and_position  &
   part_name = .__ACME_MULTI_POST_TESTRIG.gel_mount_post_pad_vertical_front  &
   location = 0.0, -750.0, 0.0  &
   orientation = 0.0d, 0.0d, 0.0d
!
defaults coordinate_system  &
   default_coordinate_system = .__ACME_MULTI_POST_TESTRIG.gel_mount_post_pad_vertical_front
!
! ****** Markers for current part ******
!
marker create  &
   marker_name = .__ACME_MULTI_POST_TESTRIG.gel_mount_post_pad_vertical_front.cm  &
   location = 0.0, 0.0, 0.0  &
   orientation = 0.0d, 0.0d, 0.0d
!
marker attributes  &
   marker_name = .__ACME_MULTI_POST_TESTRIG.gel_mount_post_pad_vertical_front.cm  &
   visibility = off  &
   name_visibility = off
!
marker create  &
   marker_name = .__ACME_MULTI_POST_TESTRIG.gel_mount_post_pad_vertical_front.inertia_frame  &
   location = 0.0, 0.0, 0.0  &
   orientation = 0.0d, 0.0d, 0.0d
!
marker create  &
   marker_name = .__ACME_MULTI_POST_TESTRIG.gel_mount_post_pad_vertical_front.gracyl_1  &
   location = 0.0, 0.0, -50.0  &
   orientation = 0.0d, 0.0d, 0.0d
!
marker attributes  &
   marker_name = .__ACME_MULTI_POST_TESTRIG.gel_mount_post_pad_vertical_front.gracyl_1  &
   visibility = off  &
   name_visibility = off
!
marker create  &
   marker_name = .__ACME_MULTI_POST_TESTRIG.gel_mount_post_pad_vertical_front.gracyl_7  &
   location = 0.0, 0.0, -1600.0  &
   orientation = 0.0d, 0.0d, 0.0d
!
marker attributes  &
   marker_name = .__ACME_MULTI_POST_TESTRIG.gel_mount_post_pad_vertical_front.gracyl_7  &
   visibility = off  &
   name_visibility = off
!
marker create  &
   marker_name = .__ACME_MULTI_POST_TESTRIG.gel_mount_post_pad_vertical_front.jxs_joint_i_1  &
   location = 0.0, 0.0, -400.0  &
   orientation = 0.0d, 0.0d, 0.0d
!
marker attributes  &
   marker_name = .__ACME_MULTI_POST_TESTRIG.gel_mount_post_pad_vertical_front.jxs_joint_i_1  &
   visibility = off  &
   name_visibility = off
!
marker create  &
   marker_name = .__ACME_MULTI_POST_TESTRIG.gel_mount_post_pad_vertical_front.jxl_joint_j_1  &
   location = 0.0, 0.0, 0.0  &
   orientation = 0.0d, 0.0d, 0.0d
!
marker attributes  &
   marker_name = .__ACME_MULTI_POST_TESTRIG.gel_mount_post_pad_vertical_front.jxl_joint_j_1  &
   visibility = off  &
   name_visibility = off
!
part create rigid_body mass_properties  &
   part_name = .__ACME_MULTI_POST_TESTRIG.gel_mount_post_pad_vertical_front  &
   mass = 1.0  &
   center_of_mass_marker =   &
                           .__ACME_MULTI_POST_TESTRIG.gel_mount_post_pad_vertical_front.cm  &
   inertia_marker =   &
                    .__ACME_MULTI_POST_TESTRIG.gel_mount_post_pad_vertical_front.inertia_frame  &
   ixx = 1.0  &
   iyy = 1.0  &
   izz = 1.0  &
   ixy = 0.0  &
   izx = 0.0  &
   iyz = 0.0
!
! ****** Graphics for current part ******
!
geometry create shape cylinder  &
   cylinder_name = .__ACME_MULTI_POST_TESTRIG.gel_mount_post_pad_vertical_front.gracyl_pad  &
   center_marker =   &
                   .__ACME_MULTI_POST_TESTRIG.gel_mount_post_pad_vertical_front.gracyl_1  &
   angle_extent = 360.0  &
   length = 50.0  &
   radius = 200.0  &
   side_count_for_body = 15  &
   segment_count_for_ends = 15
!
geometry attributes  &
   geometry_name = .__ACME_MULTI_POST_TESTRIG.gel_mount_post_pad_vertical_front.gracyl_pad  &
   color = BLUE_GRAY
!
geometry create shape cylinder  &
   cylinder_name = .__ACME_MULTI_POST_TESTRIG.gel_mount_post_pad_vertical_front.gracyl_post  &
   center_marker =   &
                   .__ACME_MULTI_POST_TESTRIG.gel_mount_post_pad_vertical_front.gracyl_7  &
   angle_extent = 360.0  &
   length = 1600.0  &
   radius = 50.0  &
   side_count_for_body = 15  &
   segment_count_for_ends = 15
!
geometry attributes  &
   geometry_name = .__ACME_MULTI_POST_TESTRIG.gel_mount_post_pad_vertical_front.gracyl_post  &
   color = BLUE_GRAY
!
part attributes  &
   part_name = .__ACME_MULTI_POST_TESTRIG.gel_mount_post_pad_vertical_front  &
   visibility = on  &
   name_visibility = on
!
!--------------------- ger_mount_post_pad_vertical_front ----------------------!
!
!
defaults coordinate_system  &
   default_coordinate_system = .__ACME_MULTI_POST_TESTRIG.ground
!
part create rigid_body name_and_position  &
   part_name = .__ACME_MULTI_POST_TESTRIG.ger_mount_post_pad_vertical_front  &
   location = 0.0, 750.0, 0.0  &
   orientation = 0.0d, 0.0d, 0.0d
!
defaults coordinate_system  &
   default_coordinate_system = .__ACME_MULTI_POST_TESTRIG.ger_mount_post_pad_vertical_front
!
! ****** Markers for current part ******
!
marker create  &
   marker_name = .__ACME_MULTI_POST_TESTRIG.ger_mount_post_pad_vertical_front.cm  &
   location = 0.0, 0.0, 0.0  &
   orientation = 0.0d, 0.0d, 0.0d
!
marker attributes  &
   marker_name = .__ACME_MULTI_POST_TESTRIG.ger_mount_post_pad_vertical_front.cm  &
   visibility = off  &
   name_visibility = off
!
marker create  &
   marker_name = .__ACME_MULTI_POST_TESTRIG.ger_mount_post_pad_vertical_front.inertia_frame  &
   location = 0.0, 0.0, 0.0  &
   orientation = 0.0d, 0.0d, 0.0d
!
marker create  &
   marker_name = .__ACME_MULTI_POST_TESTRIG.ger_mount_post_pad_vertical_front.gracyl_2  &
   location = 0.0, 0.0, -50.0  &
   orientation = 0.0d, 0.0d, 0.0d
!
marker attributes  &
   marker_name = .__ACME_MULTI_POST_TESTRIG.ger_mount_post_pad_vertical_front.gracyl_2  &
   visibility = off  &
   name_visibility = off
!
marker create  &
   marker_name = .__ACME_MULTI_POST_TESTRIG.ger_mount_post_pad_vertical_front.gracyl_8  &
   location = 0.0, 0.0, -1600.0  &
   orientation = 0.0d, 0.0d, 0.0d
!
marker attributes  &
   marker_name = .__ACME_MULTI_POST_TESTRIG.ger_mount_post_pad_vertical_front.gracyl_8  &
   visibility = off  &
   name_visibility = off
!
marker create  &
   marker_name = .__ACME_MULTI_POST_TESTRIG.ger_mount_post_pad_vertical_front.jxs_joint_i_2  &
   location = 0.0, 0.0, -400.0  &
   orientation = 0.0d, 0.0d, 0.0d
!
marker attributes  &
   marker_name = .__ACME_MULTI_POST_TESTRIG.ger_mount_post_pad_vertical_front.jxs_joint_i_2  &
   visibility = off  &
   name_visibility = off
!
marker create  &
   marker_name = .__ACME_MULTI_POST_TESTRIG.ger_mount_post_pad_vertical_front.jxr_joint_j_1  &
   location = 0.0, 0.0, 0.0  &
   orientation = 0.0d, 0.0d, 0.0d
!
marker attributes  &
   marker_name = .__ACME_MULTI_POST_TESTRIG.ger_mount_post_pad_vertical_front.jxr_joint_j_1  &
   visibility = off  &
   name_visibility = off
!
part create rigid_body mass_properties  &
   part_name = .__ACME_MULTI_POST_TESTRIG.ger_mount_post_pad_vertical_front  &
   mass = 1.0  &
   center_of_mass_marker =   &
                           .__ACME_MULTI_POST_TESTRIG.ger_mount_post_pad_vertical_front.cm  &
   inertia_marker =   &
                    .__ACME_MULTI_POST_TESTRIG.ger_mount_post_pad_vertical_front.inertia_frame  &
   ixx = 1.0  &
   iyy = 1.0  &
   izz = 1.0  &
   ixy = 0.0  &
   izx = 0.0  &
   iyz = 0.0
!
! ****** Graphics for current part ******
!
geometry create shape cylinder  &
   cylinder_name = .__ACME_MULTI_POST_TESTRIG.ger_mount_post_pad_vertical_front.gracyl_pad  &
   center_marker =   &
                   .__ACME_MULTI_POST_TESTRIG.ger_mount_post_pad_vertical_front.gracyl_2  &
   angle_extent = 360.0  &
   length = 50.0  &
   radius = 200.0  &
   side_count_for_body = 15  &
   segment_count_for_ends = 15
!
geometry attributes  &
   geometry_name = .__ACME_MULTI_POST_TESTRIG.ger_mount_post_pad_vertical_front.gracyl_pad  &
   color = BLUE_GRAY
!
geometry create shape cylinder  &
   cylinder_name = .__ACME_MULTI_POST_TESTRIG.ger_mount_post_pad_vertical_front.gracyl_post  &
   center_marker =   &
                   .__ACME_MULTI_POST_TESTRIG.ger_mount_post_pad_vertical_front.gracyl_8  &
   angle_extent = 360.0  &
   length = 1600.0  &
   radius = 50.0  &
   side_count_for_body = 15  &
   segment_count_for_ends = 15
!
geometry attributes  &
   geometry_name = .__ACME_MULTI_POST_TESTRIG.ger_mount_post_pad_vertical_front.gracyl_post  &
   color = BLUE_GRAY
!
part attributes  &
   part_name = .__ACME_MULTI_POST_TESTRIG.ger_mount_post_pad_vertical_front  &
   visibility = on  &
   name_visibility = on
!
!---------------------- gel_mount_post_pad_vertical_rear ----------------------!
!
!
defaults coordinate_system  &
   default_coordinate_system = .__ACME_MULTI_POST_TESTRIG.ground
!
part create rigid_body name_and_position  &
   part_name = .__ACME_MULTI_POST_TESTRIG.gel_mount_post_pad_vertical_rear  &
   location = 2700.0, -750.0, 0.0  &
   orientation = 0.0d, 0.0d, 0.0d
!
defaults coordinate_system  &
   default_coordinate_system = .__ACME_MULTI_POST_TESTRIG.gel_mount_post_pad_vertical_rear
!
! ****** Markers for current part ******
!
marker create  &
   marker_name = .__ACME_MULTI_POST_TESTRIG.gel_mount_post_pad_vertical_rear.cm  &
   location = 0.0, 0.0, 0.0  &
   orientation = 0.0d, 0.0d, 0.0d
!
marker attributes  &
   marker_name = .__ACME_MULTI_POST_TESTRIG.gel_mount_post_pad_vertical_rear.cm  &
   visibility = off  &
   name_visibility = off
!
marker create  &
   marker_name = .__ACME_MULTI_POST_TESTRIG.gel_mount_post_pad_vertical_rear.inertia_frame  &
   location = 0.0, 0.0, 0.0  &
   orientation = 0.0d, 0.0d, 0.0d
!
marker create  &
   marker_name = .__ACME_MULTI_POST_TESTRIG.gel_mount_post_pad_vertical_rear.gracyl_3  &
   location = 0.0, 0.0, -50.0  &
   orientation = 0.0d, 0.0d, 0.0d
!
marker attributes  &
   marker_name = .__ACME_MULTI_POST_TESTRIG.gel_mount_post_pad_vertical_rear.gracyl_3  &
   visibility = off  &
   name_visibility = off
!
marker create  &
   marker_name = .__ACME_MULTI_POST_TESTRIG.gel_mount_post_pad_vertical_rear.gracyl_9  &
   location = 0.0, 0.0, -1600.0  &
   orientation = 0.0d, 0.0d, 0.0d
!
marker attributes  &
   marker_name = .__ACME_MULTI_POST_TESTRIG.gel_mount_post_pad_vertical_rear.gracyl_9  &
   visibility = off  &
   name_visibility = off
!
marker create  &
   marker_name = .__ACME_MULTI_POST_TESTRIG.gel_mount_post_pad_vertical_rear.jxs_joint_i_3  &
   location = 0.0, 0.0, -400.0  &
   orientation = 0.0d, 0.0d, 0.0d
!
marker attributes  &
   marker_name = .__ACME_MULTI_POST_TESTRIG.gel_mount_post_pad_vertical_rear.jxs_joint_i_3  &
   visibility = off  &
   name_visibility = off
!
marker create  &
   marker_name = .__ACME_MULTI_POST_TESTRIG.gel_mount_post_pad_vertical_rear.jxl_joint_j_2  &
   location = 0.0, 0.0, 0.0  &
   orientation = 0.0d, 0.0d, 0.0d
!
marker attributes  &
   marker_name = .__ACME_MULTI_POST_TESTRIG.gel_mount_post_pad_vertical_rear.jxl_joint_j_2  &
   visibility = off  &
   name_visibility = off
!
part create rigid_body mass_properties  &
   part_name = .__ACME_MULTI_POST_TESTRIG.gel_mount_post_pad_vertical_rear  &
   mass = 1.0  &
   center_of_mass_marker =   &
                           .__ACME_MULTI_POST_TESTRIG.gel_mount_post_pad_vertical_rear.cm  &
   inertia_marker =   &
                    .__ACME_MULTI_POST_TESTRIG.gel_mount_post_pad_vertical_rear.inertia_frame  &
   ixx = 1.0  &
   iyy = 1.0  &
   izz = 1.0  &
   ixy = 0.0  &
   izx = 0.0  &
   iyz = 0.0
!
! ****** Graphics for current part ******
!
geometry create shape cylinder  &
   cylinder_name = .__ACME_MULTI_POST_TESTRIG.gel_mount_post_pad_vertical_rear.gracyl_pad  &
   center_marker =   &
                   .__ACME_MULTI_POST_TESTRIG.gel_mount_post_pad_vertical_rear.gracyl_3  &
   angle_extent = 360.0  &
   length = 50.0  &
   radius = 200.0  &
   side_count_for_body = 15  &
   segment_count_for_ends = 15
!
geometry attributes  &
   geometry_name = .__ACME_MULTI_POST_TESTRIG.gel_mount_post_pad_vertical_rear.gracyl_pad  &
   color = BLUE_GRAY
!
geometry create shape cylinder  &
   cylinder_name = .__ACME_MULTI_POST_TESTRIG.gel_mount_post_pad_vertical_rear.gracyl_post  &
   center_marker =   &
                   .__ACME_MULTI_POST_TESTRIG.gel_mount_post_pad_vertical_rear.gracyl_9  &
   angle_extent = 360.0  &
   length = 1600.0  &
   radius = 50.0  &
   side_count_for_body = 15  &
   segment_count_for_ends = 15
!
geometry attributes  &
   geometry_name = .__ACME_MULTI_POST_TESTRIG.gel_mount_post_pad_vertical_rear.gracyl_post  &
   color = BLUE_GRAY
!
part attributes  &
   part_name = .__ACME_MULTI_POST_TESTRIG.gel_mount_post_pad_vertical_rear  &
   visibility = on  &
   name_visibility = on
!
!---------------------- ger_mount_post_pad_vertical_rear ----------------------!
!
!
defaults coordinate_system  &
   default_coordinate_system = .__ACME_MULTI_POST_TESTRIG.ground
!
part create rigid_body name_and_position  &
   part_name = .__ACME_MULTI_POST_TESTRIG.ger_mount_post_pad_vertical_rear  &
   location = 2700.0, 750.0, 0.0  &
   orientation = 0.0d, 0.0d, 0.0d
!
defaults coordinate_system  &
   default_coordinate_system = .__ACME_MULTI_POST_TESTRIG.ger_mount_post_pad_vertical_rear
!
! ****** Markers for current part ******
!
marker create  &
   marker_name = .__ACME_MULTI_POST_TESTRIG.ger_mount_post_pad_vertical_rear.cm  &
   location = 0.0, 0.0, 0.0  &
   orientation = 0.0d, 0.0d, 0.0d
!
marker attributes  &
   marker_name = .__ACME_MULTI_POST_TESTRIG.ger_mount_post_pad_vertical_rear.cm  &
   visibility = off  &
   name_visibility = off
!
marker create  &
   marker_name = .__ACME_MULTI_POST_TESTRIG.ger_mount_post_pad_vertical_rear.inertia_frame  &
   location = 0.0, 0.0, 0.0  &
   orientation = 0.0d, 0.0d, 0.0d
!
marker create  &
   marker_name = .__ACME_MULTI_POST_TESTRIG.ger_mount_post_pad_vertical_rear.gracyl_4  &
   location = 0.0, 0.0, -50.0  &
   orientation = 0.0d, 0.0d, 0.0d
!
marker attributes  &
   marker_name = .__ACME_MULTI_POST_TESTRIG.ger_mount_post_pad_vertical_rear.gracyl_4  &
   visibility = off  &
   name_visibility = off
!
marker create  &
   marker_name = .__ACME_MULTI_POST_TESTRIG.ger_mount_post_pad_vertical_rear.gracyl_10  &
   location = 0.0, 0.0, -1600.0  &
   orientation = 0.0d, 0.0d, 0.0d
!
marker attributes  &
   marker_name = .__ACME_MULTI_POST_TESTRIG.ger_mount_post_pad_vertical_rear.gracyl_10  &
   visibility = off  &
   name_visibility = off
!
marker create  &
   marker_name = .__ACME_MULTI_POST_TESTRIG.ger_mount_post_pad_vertical_rear.jxs_joint_i_5  &
   location = 0.0, 0.0, -400.0  &
   orientation = 0.0d, 0.0d, 0.0d
!
marker attributes  &
   marker_name = .__ACME_MULTI_POST_TESTRIG.ger_mount_post_pad_vertical_rear.jxs_joint_i_5  &
   visibility = off  &
   name_visibility = off
!
marker create  &
   marker_name = .__ACME_MULTI_POST_TESTRIG.ger_mount_post_pad_vertical_rear.jxr_joint_j_2  &
   location = 0.0, 0.0, 0.0  &
   orientation = 0.0d, 0.0d, 0.0d
!
marker attributes  &
   marker_name = .__ACME_MULTI_POST_TESTRIG.ger_mount_post_pad_vertical_rear.jxr_joint_j_2  &
   visibility = off  &
   name_visibility = off
!
part create rigid_body mass_properties  &
   part_name = .__ACME_MULTI_POST_TESTRIG.ger_mount_post_pad_vertical_rear  &
   mass = 1.0  &
   center_of_mass_marker =   &
                           .__ACME_MULTI_POST_TESTRIG.ger_mount_post_pad_vertical_rear.cm  &
   inertia_marker =   &
                    .__ACME_MULTI_POST_TESTRIG.ger_mount_post_pad_vertical_rear.inertia_frame  &
   ixx = 1.0  &
   iyy = 1.0  &
   izz = 1.0  &
   ixy = 0.0  &
   izx = 0.0  &
   iyz = 0.0
!
! ****** Graphics for current part ******
!
geometry create shape cylinder  &
   cylinder_name = .__ACME_MULTI_POST_TESTRIG.ger_mount_post_pad_vertical_rear.gracyl_pad  &
   center_marker =   &
                   .__ACME_MULTI_POST_TESTRIG.ger_mount_post_pad_vertical_rear.gracyl_4  &
   angle_extent = 360.0  &
   length = 50.0  &
   radius = 200.0  &
   side_count_for_body = 15  &
   segment_count_for_ends = 15
!
geometry attributes  &
   geometry_name = .__ACME_MULTI_POST_TESTRIG.ger_mount_post_pad_vertical_rear.gracyl_pad  &
   color = BLUE_GRAY
!
geometry create shape cylinder  &
   cylinder_name = .__ACME_MULTI_POST_TESTRIG.ger_mount_post_pad_vertical_rear.gracyl_post  &
   center_marker =   &
                   .__ACME_MULTI_POST_TESTRIG.ger_mount_post_pad_vertical_rear.gracyl_10  &
   angle_extent = 360.0  &
   length = 1600.0  &
   radius = 50.0  &
   side_count_for_body = 15  &
   segment_count_for_ends = 15
!
geometry attributes  &
   geometry_name = .__ACME_MULTI_POST_TESTRIG.ger_mount_post_pad_vertical_rear.gracyl_post  &
   color = BLUE_GRAY
!
part attributes  &
   part_name = .__ACME_MULTI_POST_TESTRIG.ger_mount_post_pad_vertical_rear  &
   visibility = on  &
   name_visibility = on
!
!--------------------- gel_mount_post_pad_vertical_rear2 ----------------------!
!
!
defaults coordinate_system  &
   default_coordinate_system = .__ACME_MULTI_POST_TESTRIG.ground
!
part create rigid_body name_and_position  &
   part_name = .__ACME_MULTI_POST_TESTRIG.gel_mount_post_pad_vertical_rear2  &
   location = 4000.0, -750.0, 0.0  &
   orientation = 0.0d, 0.0d, 0.0d
!
defaults coordinate_system  &
   default_coordinate_system = .__ACME_MULTI_POST_TESTRIG.gel_mount_post_pad_vertical_rear2
!
! ****** Markers for current part ******
!
marker create  &
   marker_name = .__ACME_MULTI_POST_TESTRIG.gel_mount_post_pad_vertical_rear2.cm  &
   location = 0.0, 0.0, 0.0  &
   orientation = 0.0d, 0.0d, 0.0d
!
marker attributes  &
   marker_name = .__ACME_MULTI_POST_TESTRIG.gel_mount_post_pad_vertical_rear2.cm  &
   visibility = off  &
   name_visibility = off
!
marker create  &
   marker_name = .__ACME_MULTI_POST_TESTRIG.gel_mount_post_pad_vertical_rear2.inertia_frame  &
   location = 0.0, 0.0, 0.0  &
   orientation = 0.0d, 0.0d, 0.0d
!
marker create  &
   marker_name = .__ACME_MULTI_POST_TESTRIG.gel_mount_post_pad_vertical_rear2.gracyl_5  &
   location = 0.0, 0.0, -50.0  &
   orientation = 0.0d, 0.0d, 0.0d
!
marker attributes  &
   marker_name = .__ACME_MULTI_POST_TESTRIG.gel_mount_post_pad_vertical_rear2.gracyl_5  &
   visibility = off  &
   name_visibility = off
!
marker create  &
   marker_name = .__ACME_MULTI_POST_TESTRIG.gel_mount_post_pad_vertical_rear2.gracyl_11  &
   location = 0.0, 0.0, -1600.0  &
   orientation = 0.0d, 0.0d, 0.0d
!
marker attributes  &
   marker_name = .__ACME_MULTI_POST_TESTRIG.gel_mount_post_pad_vertical_rear2.gracyl_11  &
   visibility = off  &
   name_visibility = off
!
marker create  &
   marker_name = .__ACME_MULTI_POST_TESTRIG.gel_mount_post_pad_vertical_rear2.jxs_joint_i_4  &
   location = 0.0, 0.0, -400.0  &
   orientation = 0.0d, 0.0d, 0.0d
!
marker attributes  &
   marker_name = .__ACME_MULTI_POST_TESTRIG.gel_mount_post_pad_vertical_rear2.jxs_joint_i_4  &
   visibility = off  &
   name_visibility = off
!
marker create  &
   marker_name = .__ACME_MULTI_POST_TESTRIG.gel_mount_post_pad_vertical_rear2.jxl_joint_j_3  &
   location = 0.0, 0.0, 0.0  &
   orientation = 0.0d, 0.0d, 0.0d
!
marker attributes  &
   marker_name = .__ACME_MULTI_POST_TESTRIG.gel_mount_post_pad_vertical_rear2.jxl_joint_j_3  &
   visibility = off  &
   name_visibility = off
!
part create rigid_body mass_properties  &
   part_name = .__ACME_MULTI_POST_TESTRIG.gel_mount_post_pad_vertical_rear2  &
   mass = 1.0  &
   center_of_mass_marker =   &
                           .__ACME_MULTI_POST_TESTRIG.gel_mount_post_pad_vertical_rear2.cm  &
   inertia_marker =   &
                    .__ACME_MULTI_POST_TESTRIG.gel_mount_post_pad_vertical_rear2.inertia_frame  &
   ixx = 1.0  &
   iyy = 1.0  &
   izz = 1.0  &
   ixy = 0.0  &
   izx = 0.0  &
   iyz = 0.0
!
! ****** Graphics for current part ******
!
geometry create shape cylinder  &
   cylinder_name = .__ACME_MULTI_POST_TESTRIG.gel_mount_post_pad_vertical_rear2.gracyl_pad  &
   center_marker =   &
                   .__ACME_MULTI_POST_TESTRIG.gel_mount_post_pad_vertical_rear2.gracyl_5  &
   angle_extent = 360.0  &
   length = 50.0  &
   radius = 200.0  &
   side_count_for_body = 15  &
   segment_count_for_ends = 15
!
geometry attributes  &
   geometry_name = .__ACME_MULTI_POST_TESTRIG.gel_mount_post_pad_vertical_rear2.gracyl_pad  &
   color = BLUE_GRAY
!
geometry create shape cylinder  &
   cylinder_name = .__ACME_MULTI_POST_TESTRIG.gel_mount_post_pad_vertical_rear2.gracyl_post  &
   center_marker =   &
                   .__ACME_MULTI_POST_TESTRIG.gel_mount_post_pad_vertical_rear2.gracyl_11  &
   angle_extent = 360.0  &
   length = 1600.0  &
   radius = 50.0  &
   side_count_for_body = 15  &
   segment_count_for_ends = 15
!
geometry attributes  &
   geometry_name = .__ACME_MULTI_POST_TESTRIG.gel_mount_post_pad_vertical_rear2.gracyl_post  &
   color = BLUE_GRAY
!
part attributes  &
   part_name = .__ACME_MULTI_POST_TESTRIG.gel_mount_post_pad_vertical_rear2  &
   visibility = on  &
   name_visibility = on
!
!--------------------- ger_mount_post_pad_vertical_rear2 ----------------------!
!
!
defaults coordinate_system  &
   default_coordinate_system = .__ACME_MULTI_POST_TESTRIG.ground
!
part create rigid_body name_and_position  &
   part_name = .__ACME_MULTI_POST_TESTRIG.ger_mount_post_pad_vertical_rear2  &
   location = 4000.0, 750.0, 0.0  &
   orientation = 0.0d, 0.0d, 0.0d
!
defaults coordinate_system  &
   default_coordinate_system = .__ACME_MULTI_POST_TESTRIG.ger_mount_post_pad_vertical_rear2
!
! ****** Markers for current part ******
!
marker create  &
   marker_name = .__ACME_MULTI_POST_TESTRIG.ger_mount_post_pad_vertical_rear2.cm  &
   location = 0.0, 0.0, 0.0  &
   orientation = 0.0d, 0.0d, 0.0d
!
marker attributes  &
   marker_name = .__ACME_MULTI_POST_TESTRIG.ger_mount_post_pad_vertical_rear2.cm  &
   visibility = off  &
   name_visibility = off
!
marker create  &
   marker_name = .__ACME_MULTI_POST_TESTRIG.ger_mount_post_pad_vertical_rear2.inertia_frame  &
   location = 0.0, 0.0, 0.0  &
   orientation = 0.0d, 0.0d, 0.0d
!
marker create  &
   marker_name = .__ACME_MULTI_POST_TESTRIG.ger_mount_post_pad_vertical_rear2.gracyl_6  &
   location = 0.0, 0.0, -50.0  &
   orientation = 0.0d, 0.0d, 0.0d
!
marker attributes  &
   marker_name = .__ACME_MULTI_POST_TESTRIG.ger_mount_post_pad_vertical_rear2.gracyl_6  &
   visibility = off  &
   name_visibility = off
!
marker create  &
   marker_name = .__ACME_MULTI_POST_TESTRIG.ger_mount_post_pad_vertical_rear2.gracyl_12  &
   location = 0.0, 0.0, -1600.0  &
   orientation = 0.0d, 0.0d, 0.0d
!
marker attributes  &
   marker_name = .__ACME_MULTI_POST_TESTRIG.ger_mount_post_pad_vertical_rear2.gracyl_12  &
   visibility = off  &
   name_visibility = off
!
marker create  &
   marker_name = .__ACME_MULTI_POST_TESTRIG.ger_mount_post_pad_vertical_rear2.jxs_joint_i_6  &
   location = 0.0, 0.0, -400.0  &
   orientation = 0.0d, 0.0d, 0.0d
!
marker attributes  &
   marker_name = .__ACME_MULTI_POST_TESTRIG.ger_mount_post_pad_vertical_rear2.jxs_joint_i_6  &
   visibility = off  &
   name_visibility = off
!
marker create  &
   marker_name = .__ACME_MULTI_POST_TESTRIG.ger_mount_post_pad_vertical_rear2.jxr_joint_j_3  &
   location = 0.0, 0.0, 0.0  &
   orientation = 0.0d, 0.0d, 0.0d
!
marker attributes  &
   marker_name = .__ACME_MULTI_POST_TESTRIG.ger_mount_post_pad_vertical_rear2.jxr_joint_j_3  &
   visibility = off  &
   name_visibility = off
!
part create rigid_body mass_properties  &
   part_name = .__ACME_MULTI_POST_TESTRIG.ger_mount_post_pad_vertical_rear2  &
   mass = 1.0  &
   center_of_mass_marker =   &
                           .__ACME_MULTI_POST_TESTRIG.ger_mount_post_pad_vertical_rear2.cm  &
   inertia_marker =   &
                    .__ACME_MULTI_POST_TESTRIG.ger_mount_post_pad_vertical_rear2.inertia_frame  &
   ixx = 1.0  &
   iyy = 1.0  &
   izz = 1.0  &
   ixy = 0.0  &
   izx = 0.0  &
   iyz = 0.0
!
! ****** Graphics for current part ******
!
geometry create shape cylinder  &
   cylinder_name = .__ACME_MULTI_POST_TESTRIG.ger_mount_post_pad_vertical_rear2.gracyl_pad  &
   center_marker =   &
                   .__ACME_MULTI_POST_TESTRIG.ger_mount_post_pad_vertical_rear2.gracyl_6  &
   angle_extent = 360.0  &
   length = 50.0  &
   radius = 200.0  &
   side_count_for_body = 15  &
   segment_count_for_ends = 15
!
geometry attributes  &
   geometry_name = .__ACME_MULTI_POST_TESTRIG.ger_mount_post_pad_vertical_rear2.gracyl_pad  &
   color = BLUE_GRAY
!
geometry create shape cylinder  &
   cylinder_name = .__ACME_MULTI_POST_TESTRIG.ger_mount_post_pad_vertical_rear2.gracyl_post  &
   center_marker =   &
                   .__ACME_MULTI_POST_TESTRIG.ger_mount_post_pad_vertical_rear2.gracyl_12  &
   angle_extent = 360.0  &
   length = 1600.0  &
   radius = 50.0  &
   side_count_for_body = 15  &
   segment_count_for_ends = 15
!
geometry attributes  &
   geometry_name = .__ACME_MULTI_POST_TESTRIG.ger_mount_post_pad_vertical_rear2.gracyl_post  &
   color = BLUE_GRAY
!
part attributes  &
   part_name = .__ACME_MULTI_POST_TESTRIG.ger_mount_post_pad_vertical_rear2  &
   visibility = on  &
   name_visibility = on
!
!------------------------- mtl_suspension_mount_front -------------------------!
!
!
defaults coordinate_system  &
   default_coordinate_system = .__ACME_MULTI_POST_TESTRIG.ground
!
part create rigid_body name_and_position  &
   part_name = .__ACME_MULTI_POST_TESTRIG.mtl_suspension_mount_front  &
   location = 0.0, -750.0, 0.0  &
   orientation = 0.0d, 0.0d, 0.0d
!
defaults coordinate_system  &
   default_coordinate_system = .__ACME_MULTI_POST_TESTRIG.mtl_suspension_mount_front
!
! ****** Markers for current part ******
!
marker create  &
   marker_name = .__ACME_MULTI_POST_TESTRIG.mtl_suspension_mount_front.mount_i  &
   location = 0.0, 0.0, 0.0  &
   orientation = 0.0d, 0.0d, 0.0d
!
marker attributes  &
   marker_name = .__ACME_MULTI_POST_TESTRIG.mtl_suspension_mount_front.mount_i  &
   visibility = off  &
   name_visibility = off
!
marker create  &
   marker_name = .__ACME_MULTI_POST_TESTRIG.mtl_suspension_mount_front.jxl_joint_i_1  &
   location = 0.0, 0.0, 0.0  &
   orientation = 0.0d, 0.0d, 0.0d
!
marker attributes  &
   marker_name = .__ACME_MULTI_POST_TESTRIG.mtl_suspension_mount_front.jxl_joint_i_1  &
   visibility = off  &
   name_visibility = off
!
part attributes  &
   part_name = .__ACME_MULTI_POST_TESTRIG.mtl_suspension_mount_front  &
   visibility = on  &
   name_visibility = on
!
!------------------------- mtr_suspension_mount_front -------------------------!
!
!
defaults coordinate_system  &
   default_coordinate_system = .__ACME_MULTI_POST_TESTRIG.ground
!
part create rigid_body name_and_position  &
   part_name = .__ACME_MULTI_POST_TESTRIG.mtr_suspension_mount_front  &
   location = 0.0, 750.0, 0.0  &
   orientation = 0.0d, 0.0d, 0.0d
!
defaults coordinate_system  &
   default_coordinate_system = .__ACME_MULTI_POST_TESTRIG.mtr_suspension_mount_front
!
! ****** Markers for current part ******
!
marker create  &
   marker_name = .__ACME_MULTI_POST_TESTRIG.mtr_suspension_mount_front.mount_i  &
   location = 0.0, 0.0, 0.0  &
   orientation = 0.0d, 0.0d, 0.0d
!
marker attributes  &
   marker_name = .__ACME_MULTI_POST_TESTRIG.mtr_suspension_mount_front.mount_i  &
   visibility = off  &
   name_visibility = off
!
marker create  &
   marker_name = .__ACME_MULTI_POST_TESTRIG.mtr_suspension_mount_front.jxr_joint_i_1  &
   location = 0.0, 0.0, 0.0  &
   orientation = 0.0d, 0.0d, 0.0d
!
marker attributes  &
   marker_name = .__ACME_MULTI_POST_TESTRIG.mtr_suspension_mount_front.jxr_joint_i_1  &
   visibility = off  &
   name_visibility = off
!
part attributes  &
   part_name = .__ACME_MULTI_POST_TESTRIG.mtr_suspension_mount_front  &
   visibility = on  &
   name_visibility = on
!
!------------------------- mtl_suspension_mount_rear --------------------------!
!
!
defaults coordinate_system  &
   default_coordinate_system = .__ACME_MULTI_POST_TESTRIG.ground
!
part create rigid_body name_and_position  &
   part_name = .__ACME_MULTI_POST_TESTRIG.mtl_suspension_mount_rear  &
   location = 2700.0, -750.0, 0.0  &
   orientation = 0.0d, 0.0d, 0.0d
!
defaults coordinate_system  &
   default_coordinate_system = .__ACME_MULTI_POST_TESTRIG.mtl_suspension_mount_rear
!
! ****** Markers for current part ******
!
marker create  &
   marker_name = .__ACME_MULTI_POST_TESTRIG.mtl_suspension_mount_rear.mount_i  &
   location = 0.0, 0.0, 0.0  &
   orientation = 0.0d, 0.0d, 0.0d
!
marker attributes  &
   marker_name = .__ACME_MULTI_POST_TESTRIG.mtl_suspension_mount_rear.mount_i  &
   visibility = off  &
   name_visibility = off
!
marker create  &
   marker_name = .__ACME_MULTI_POST_TESTRIG.mtl_suspension_mount_rear.jxl_joint_i_2  &
   location = 0.0, 0.0, 0.0  &
   orientation = 0.0d, 0.0d, 0.0d
!
marker attributes  &
   marker_name = .__ACME_MULTI_POST_TESTRIG.mtl_suspension_mount_rear.jxl_joint_i_2  &
   visibility = off  &
   name_visibility = off
!
part attributes  &
   part_name = .__ACME_MULTI_POST_TESTRIG.mtl_suspension_mount_rear  &
   visibility = on  &
   name_visibility = on
!
!------------------------- mtr_suspension_mount_rear --------------------------!
!
!
defaults coordinate_system  &
   default_coordinate_system = .__ACME_MULTI_POST_TESTRIG.ground
!
part create rigid_body name_and_position  &
   part_name = .__ACME_MULTI_POST_TESTRIG.mtr_suspension_mount_rear  &
   location = 2700.0, 750.0, 0.0  &
   orientation = 0.0d, 0.0d, 0.0d
!
defaults coordinate_system  &
   default_coordinate_system = .__ACME_MULTI_POST_TESTRIG.mtr_suspension_mount_rear
!
! ****** Markers for current part ******
!
marker create  &
   marker_name = .__ACME_MULTI_POST_TESTRIG.mtr_suspension_mount_rear.mount_i  &
   location = 0.0, 0.0, 0.0  &
   orientation = 0.0d, 0.0d, 0.0d
!
marker attributes  &
   marker_name = .__ACME_MULTI_POST_TESTRIG.mtr_suspension_mount_rear.mount_i  &
   visibility = off  &
   name_visibility = off
!
marker create  &
   marker_name = .__ACME_MULTI_POST_TESTRIG.mtr_suspension_mount_rear.jxr_joint_i_2  &
   location = 0.0, 0.0, 0.0  &
   orientation = 0.0d, 0.0d, 0.0d
!
marker attributes  &
   marker_name = .__ACME_MULTI_POST_TESTRIG.mtr_suspension_mount_rear.jxr_joint_i_2  &
   visibility = off  &
   name_visibility = off
!
part attributes  &
   part_name = .__ACME_MULTI_POST_TESTRIG.mtr_suspension_mount_rear  &
   visibility = on  &
   name_visibility = on
!
!------------------------- mtl_suspension_mount_rear2 -------------------------!
!
!
defaults coordinate_system  &
   default_coordinate_system = .__ACME_MULTI_POST_TESTRIG.ground
!
part create rigid_body name_and_position  &
   part_name = .__ACME_MULTI_POST_TESTRIG.mtl_suspension_mount_rear2  &
   location = 4000.0, -750.0, 0.0  &
   orientation = 0.0d, 0.0d, 0.0d
!
defaults coordinate_system  &
   default_coordinate_system = .__ACME_MULTI_POST_TESTRIG.mtl_suspension_mount_rear2
!
! ****** Markers for current part ******
!
marker create  &
   marker_name = .__ACME_MULTI_POST_TESTRIG.mtl_suspension_mount_rear2.mount_i  &
   location = 0.0, 0.0, 0.0  &
   orientation = 0.0d, 0.0d, 0.0d
!
marker attributes  &
   marker_name = .__ACME_MULTI_POST_TESTRIG.mtl_suspension_mount_rear2.mount_i  &
   visibility = off  &
   name_visibility = off
!
marker create  &
   marker_name = .__ACME_MULTI_POST_TESTRIG.mtl_suspension_mount_rear2.jxl_joint_i_3  &
   location = 0.0, 0.0, 0.0  &
   orientation = 0.0d, 0.0d, 0.0d
!
marker attributes  &
   marker_name = .__ACME_MULTI_POST_TESTRIG.mtl_suspension_mount_rear2.jxl_joint_i_3  &
   visibility = off  &
   name_visibility = off
!
part attributes  &
   part_name = .__ACME_MULTI_POST_TESTRIG.mtl_suspension_mount_rear2  &
   visibility = on  &
   name_visibility = on
!
!------------------------- mtr_suspension_mount_rear2 -------------------------!
!
!
defaults coordinate_system  &
   default_coordinate_system = .__ACME_MULTI_POST_TESTRIG.ground
!
part create rigid_body name_and_position  &
   part_name = .__ACME_MULTI_POST_TESTRIG.mtr_suspension_mount_rear2  &
   location = 4000.0, 750.0, 0.0  &
   orientation = 0.0d, 0.0d, 0.0d
!
defaults coordinate_system  &
   default_coordinate_system = .__ACME_MULTI_POST_TESTRIG.mtr_suspension_mount_rear2
!
! ****** Markers for current part ******
!
marker create  &
   marker_name = .__ACME_MULTI_POST_TESTRIG.mtr_suspension_mount_rear2.mount_i  &
   location = 0.0, 0.0, 0.0  &
   orientation = 0.0d, 0.0d, 0.0d
!
marker attributes  &
   marker_name = .__ACME_MULTI_POST_TESTRIG.mtr_suspension_mount_rear2.mount_i  &
   visibility = off  &
   name_visibility = off
!
marker create  &
   marker_name = .__ACME_MULTI_POST_TESTRIG.mtr_suspension_mount_rear2.jxr_joint_i_3  &
   location = 0.0, 0.0, 0.0  &
   orientation = 0.0d, 0.0d, 0.0d
!
marker attributes  &
   marker_name = .__ACME_MULTI_POST_TESTRIG.mtr_suspension_mount_rear2.jxr_joint_i_3  &
   visibility = off  &
   name_visibility = off
!
part attributes  &
   part_name = .__ACME_MULTI_POST_TESTRIG.mtr_suspension_mount_rear2  &
   visibility = on  &
   name_visibility = on
!
!------------------------ mts_body_subsystem_deactive -------------------------!
!
!
defaults coordinate_system  &
   default_coordinate_system = .__ACME_MULTI_POST_TESTRIG.ground
!
part create rigid_body name_and_position  &
   part_name = .__ACME_MULTI_POST_TESTRIG.mts_body_subsystem_deactive  &
   location = 0.0, 0.0, 0.0  &
   orientation = 0.0d, 0.0d, 0.0d
!
defaults coordinate_system  &
   default_coordinate_system = .__ACME_MULTI_POST_TESTRIG.mts_body_subsystem_deactive
!
! ****** Markers for current part ******
!
marker create  &
   marker_name = .__ACME_MULTI_POST_TESTRIG.mts_body_subsystem_deactive.mount_i  &
   location = 0.0, 0.0, 0.0  &
   orientation = 0.0d, 0.0d, 0.0d
!
marker attributes  &
   marker_name = .__ACME_MULTI_POST_TESTRIG.mts_body_subsystem_deactive.mount_i  &
   visibility = off  &
   name_visibility = off
!
marker create  &
   marker_name = .__ACME_MULTI_POST_TESTRIG.mts_body_subsystem_deactive.jxs_joint_i_7  &
   location = 0.0, 0.0, 0.0  &
   orientation = 0.0d, 90.0d, 0.0d
!
marker attributes  &
   marker_name = .__ACME_MULTI_POST_TESTRIG.mts_body_subsystem_deactive.jxs_joint_i_7  &
   visibility = off  &
   name_visibility = off
!
marker create  &
   marker_name = .__ACME_MULTI_POST_TESTRIG.mts_body_subsystem_deactive.jxs_joint_i_8  &
   location = 0.0, 0.0, 0.0  &
   orientation = 0.0d, 0.0d, 0.0d
!
marker attributes  &
   marker_name = .__ACME_MULTI_POST_TESTRIG.mts_body_subsystem_deactive.jxs_joint_i_8  &
   visibility = off  &
   name_visibility = off
!
part attributes  &
   part_name = .__ACME_MULTI_POST_TESTRIG.mts_body_subsystem_deactive  &
   active = off  &
   visibility = on  &
   name_visibility = on
!
!--------------------------------- Equations ----------------------------------!
!
!
part create equation differential_equation  &
   differential_equation_name = .__ACME_MULTI_POST_TESTRIG._cv_diff  &
   comments = "Dummy for communicators"  &
   no_initial_condition = TRUE  &
   function = ""  &
   implicit = off  &
   static_hold = off
!
part attributes  &
   equation_name = .__ACME_MULTI_POST_TESTRIG._cv_diff  &
   visibility = off
!
!----------------------------------- Joints -----------------------------------!
!
!
constraint create joint cylindrical  &
   joint_name = .__ACME_MULTI_POST_TESTRIG._cv_joint_for_motion  &
   comments = "Dummy for communicators"  &
   i_marker_name = .__ACME_MULTI_POST_TESTRIG._cv_part.marker  &
   j_marker_name = .__ACME_MULTI_POST_TESTRIG.ground._cv_marker
!
constraint attributes  &
   constraint_name = .__ACME_MULTI_POST_TESTRIG._cv_joint_for_motion  &
   visibility = off  &
   name_visibility = off
!
constraint create joint translational  &
   joint_name = .__ACME_MULTI_POST_TESTRIG.jostra_mount_post_pad_vertical_lf  &
   i_marker_name =   &
                   .__ACME_MULTI_POST_TESTRIG.gel_mount_post_pad_vertical_front.jxs_joint_i_1  &
   j_marker_name = .__ACME_MULTI_POST_TESTRIG.ground.jxs_joint_j_1
!
constraint create joint translational  &
   joint_name = .__ACME_MULTI_POST_TESTRIG.jostra_mount_post_pad_vertical_rf  &
   i_marker_name =   &
                   .__ACME_MULTI_POST_TESTRIG.ger_mount_post_pad_vertical_front.jxs_joint_i_2  &
   j_marker_name = .__ACME_MULTI_POST_TESTRIG.ground.jxs_joint_j_2
!
constraint create joint translational  &
   joint_name = .__ACME_MULTI_POST_TESTRIG.jostra_mount_post_pad_vertical_lr  &
   i_marker_name =   &
                   .__ACME_MULTI_POST_TESTRIG.gel_mount_post_pad_vertical_rear.jxs_joint_i_3  &
   j_marker_name = .__ACME_MULTI_POST_TESTRIG.ground.jxs_joint_j_3
!
constraint create joint translational  &
   joint_name = .__ACME_MULTI_POST_TESTRIG.jostra_mount_post_pad_vertical_lr2  &
   i_marker_name =   &
                   .__ACME_MULTI_POST_TESTRIG.gel_mount_post_pad_vertical_rear2.jxs_joint_i_4  &
   j_marker_name = .__ACME_MULTI_POST_TESTRIG.ground.jxs_joint_j_4
!
constraint create joint translational  &
   joint_name = .__ACME_MULTI_POST_TESTRIG.jostra_mount_post_pad_vertical_rr  &
   i_marker_name =   &
                   .__ACME_MULTI_POST_TESTRIG.ger_mount_post_pad_vertical_rear.jxs_joint_i_5  &
   j_marker_name = .__ACME_MULTI_POST_TESTRIG.ground.jxs_joint_j_5
!
constraint create joint translational  &
   joint_name = .__ACME_MULTI_POST_TESTRIG.jostra_mount_post_pad_vertical_rr2  &
   i_marker_name =   &
                   .__ACME_MULTI_POST_TESTRIG.ger_mount_post_pad_vertical_rear2.jxs_joint_i_6  &
   j_marker_name = .__ACME_MULTI_POST_TESTRIG.ground.jxs_joint_j_6
!
constraint create joint fixed  &
   joint_name = .__ACME_MULTI_POST_TESTRIG.mtl_fixed_1  &
   i_marker_name =   &
                   .__ACME_MULTI_POST_TESTRIG.mtl_suspension_mount_front.mount_i  &
   j_marker_name = .__ACME_MULTI_POST_TESTRIG.ground.mtl_mount_j_1
!
constraint attributes  &
   constraint_name = .__ACME_MULTI_POST_TESTRIG.mtl_fixed_1  &
   visibility = off  &
   name_visibility = off
!
constraint create joint fixed  &
   joint_name = .__ACME_MULTI_POST_TESTRIG.mtr_fixed_1  &
   i_marker_name =   &
                   .__ACME_MULTI_POST_TESTRIG.mtr_suspension_mount_front.mount_i  &
   j_marker_name = .__ACME_MULTI_POST_TESTRIG.ground.mtr_mount_j_1
!
constraint attributes  &
   constraint_name = .__ACME_MULTI_POST_TESTRIG.mtr_fixed_1  &
   visibility = off  &
   name_visibility = off
!
constraint create joint fixed  &
   joint_name = .__ACME_MULTI_POST_TESTRIG.mtl_fixed_2  &
   i_marker_name =   &
                   .__ACME_MULTI_POST_TESTRIG.mtl_suspension_mount_rear.mount_i  &
   j_marker_name = .__ACME_MULTI_POST_TESTRIG.ground.mtl_mount_j_2
!
constraint attributes  &
   constraint_name = .__ACME_MULTI_POST_TESTRIG.mtl_fixed_2  &
   visibility = off  &
   name_visibility = off
!
constraint create joint fixed  &
   joint_name = .__ACME_MULTI_POST_TESTRIG.mtr_fixed_2  &
   i_marker_name =   &
                   .__ACME_MULTI_POST_TESTRIG.mtr_suspension_mount_rear.mount_i  &
   j_marker_name = .__ACME_MULTI_POST_TESTRIG.ground.mtr_mount_j_2
!
constraint attributes  &
   constraint_name = .__ACME_MULTI_POST_TESTRIG.mtr_fixed_2  &
   visibility = off  &
   name_visibility = off
!
constraint create joint fixed  &
   joint_name = .__ACME_MULTI_POST_TESTRIG.mtl_fixed_3  &
   i_marker_name =   &
                   .__ACME_MULTI_POST_TESTRIG.mtl_suspension_mount_rear2.mount_i  &
   j_marker_name = .__ACME_MULTI_POST_TESTRIG.ground.mtl_mount_j_3
!
constraint attributes  &
   constraint_name = .__ACME_MULTI_POST_TESTRIG.mtl_fixed_3  &
   visibility = off  &
   name_visibility = off
!
constraint create joint fixed  &
   joint_name = .__ACME_MULTI_POST_TESTRIG.mtr_fixed_3  &
   i_marker_name =   &
                   .__ACME_MULTI_POST_TESTRIG.mtr_suspension_mount_rear2.mount_i  &
   j_marker_name = .__ACME_MULTI_POST_TESTRIG.ground.mtr_mount_j_3
!
constraint attributes  &
   constraint_name = .__ACME_MULTI_POST_TESTRIG.mtr_fixed_3  &
   visibility = off  &
   name_visibility = off
!
constraint create joint fixed  &
   joint_name = .__ACME_MULTI_POST_TESTRIG.mts_fixed_1  &
   i_marker_name =   &
                   .__ACME_MULTI_POST_TESTRIG.mts_body_subsystem_deactive.mount_i  &
   j_marker_name = .__ACME_MULTI_POST_TESTRIG.ground.mts_mount_j_1
!
constraint attributes  &
   constraint_name = .__ACME_MULTI_POST_TESTRIG.mts_fixed_1  &
   active = off  &
   visibility = off  &
   name_visibility = off
!
!------------------------------ Joint Primitives ------------------------------!
!
!
constraint create primitive_joint inplane  &
   jprim_name = .__ACME_MULTI_POST_TESTRIG._cv_joint  &
   comments = "Dummy for communicators"  &
   i_marker_name = .__ACME_MULTI_POST_TESTRIG._cv_part.marker  &
   j_marker_name = .__ACME_MULTI_POST_TESTRIG.ground._cv_marker
!
constraint attributes  &
   constraint_name = .__ACME_MULTI_POST_TESTRIG._cv_joint  &
   visibility = off  &
   name_visibility = off
!
constraint create primitive_joint inplane  &
   jprim_name = .__ACME_MULTI_POST_TESTRIG.jolinp_mount_post_to_spindle_vertical_front  &
   i_marker_name =   &
                   .__ACME_MULTI_POST_TESTRIG.mtl_suspension_mount_front.jxl_joint_i_1  &
   j_marker_name =   &
                   .__ACME_MULTI_POST_TESTRIG.gel_mount_post_pad_vertical_front.jxl_joint_j_1
!
constraint create primitive_joint inplane  &
   jprim_name = .__ACME_MULTI_POST_TESTRIG.jorinp_mount_post_to_spindle_vertical_front  &
   i_marker_name =   &
                   .__ACME_MULTI_POST_TESTRIG.mtr_suspension_mount_front.jxr_joint_i_1  &
   j_marker_name =   &
                   .__ACME_MULTI_POST_TESTRIG.ger_mount_post_pad_vertical_front.jxr_joint_j_1
!
constraint create primitive_joint inplane  &
   jprim_name = .__ACME_MULTI_POST_TESTRIG.jolinp_mount_post_to_spindle_vertical_rear  &
   i_marker_name =   &
                   .__ACME_MULTI_POST_TESTRIG.mtl_suspension_mount_rear.jxl_joint_i_2  &
   j_marker_name =   &
                   .__ACME_MULTI_POST_TESTRIG.gel_mount_post_pad_vertical_rear.jxl_joint_j_2
!
constraint create primitive_joint inplane  &
   jprim_name = .__ACME_MULTI_POST_TESTRIG.jorinp_mount_post_to_spindle_vertical_rear  &
   i_marker_name =   &
                   .__ACME_MULTI_POST_TESTRIG.mtr_suspension_mount_rear.jxr_joint_i_2  &
   j_marker_name =   &
                   .__ACME_MULTI_POST_TESTRIG.ger_mount_post_pad_vertical_rear.jxr_joint_j_2
!
constraint create primitive_joint inplane  &
   jprim_name = .__ACME_MULTI_POST_TESTRIG.jolinp_mount_post_to_spindle_vertical_rear2  &
   i_marker_name =   &
                   .__ACME_MULTI_POST_TESTRIG.mtl_suspension_mount_rear2.jxl_joint_i_3  &
   j_marker_name =   &
                   .__ACME_MULTI_POST_TESTRIG.gel_mount_post_pad_vertical_rear2.jxl_joint_j_3
!
constraint create primitive_joint inplane  &
   jprim_name = .__ACME_MULTI_POST_TESTRIG.jorinp_mount_post_to_spindle_vertical_rear2  &
   i_marker_name =   &
                   .__ACME_MULTI_POST_TESTRIG.mtr_suspension_mount_rear2.jxr_joint_i_3  &
   j_marker_name =   &
                   .__ACME_MULTI_POST_TESTRIG.ger_mount_post_pad_vertical_rear2.jxr_joint_j_3
!
constraint create primitive_joint perpendicular  &
   jprim_name = .__ACME_MULTI_POST_TESTRIG.josper_yaw_stake  &
   i_marker_name =   &
                   .__ACME_MULTI_POST_TESTRIG.mts_body_subsystem_deactive.jxs_joint_i_7  &
   j_marker_name = .__ACME_MULTI_POST_TESTRIG.ground.jxs_joint_j_7
!
constraint attributes  &
   constraint_name = .__ACME_MULTI_POST_TESTRIG.josper_yaw_stake  &
   active = off
!
constraint create primitive_joint inline  &
   jprim_name = .__ACME_MULTI_POST_TESTRIG.josinl_body_stake  &
   i_marker_name =   &
                   .__ACME_MULTI_POST_TESTRIG.mts_body_subsystem_deactive.jxs_joint_i_8  &
   j_marker_name = .__ACME_MULTI_POST_TESTRIG.ground.jxs_joint_j_8
!
constraint attributes  &
   constraint_name = .__ACME_MULTI_POST_TESTRIG.josinl_body_stake  &
   active = off
!
!----------------------------------- Forces -----------------------------------!
!
!
force create element_like field  &
   field_name = .__ACME_MULTI_POST_TESTRIG._cv_bushing  &
   comments = "Dummy for communicators"  &
   i_marker_name = .__ACME_MULTI_POST_TESTRIG._cv_part.marker  &
   j_marker_name = .__ACME_MULTI_POST_TESTRIG.ground._cv_marker  &
   stiffness_matrix =  &
      0.0, 0.0, 0.0, 0.0, 0.0, 0.0,  &
      0.0, 0.0, 0.0, 0.0, 0.0, 0.0,  &
      0.0, 0.0, 0.0, 0.0, 0.0, 0.0,  &
      0.0, 0.0, 0.0, 0.0, 0.0, 0.0,  &
      0.0, 0.0, 0.0, 0.0, 0.0, 0.0,  &
      0.0, 0.0, 0.0, 0.0, 0.0, 0.0
!
force attributes  &
   force_name = .__ACME_MULTI_POST_TESTRIG._cv_bushing  &
   visibility = off  &
   name_visibility = off
!
!-------------------------- Adams View UDE Instances --------------------------!
!
!
defaults coordinate_system  &
   default_coordinate_system = .__ACME_MULTI_POST_TESTRIG.ground
!
undo begin_block suppress = yes
!
ude create instance  &
   instance_name = .__ACME_MULTI_POST_TESTRIG.jms_post_pad_vertical_lf  &
   definition_name = .ACAR.inputs.ac_joint_motion_actuator  &
   location = 0.0, 0.0, 0.0  &
   orientation = 0.0, 0.0, 0.0
!
ude attributes  &
   instance_name = .__ACME_MULTI_POST_TESTRIG.jms_post_pad_vertical_lf  &
   active = on
!
ude create instance  &
   instance_name = .__ACME_MULTI_POST_TESTRIG.jms_post_pad_vertical_rf  &
   definition_name = .ACAR.inputs.ac_joint_motion_actuator  &
   location = 0.0, 0.0, 0.0  &
   orientation = 0.0, 0.0, 0.0
!
ude attributes  &
   instance_name = .__ACME_MULTI_POST_TESTRIG.jms_post_pad_vertical_rf  &
   active = on
!
ude create instance  &
   instance_name = .__ACME_MULTI_POST_TESTRIG.jms_post_pad_vertical_lr  &
   definition_name = .ACAR.inputs.ac_joint_motion_actuator  &
   location = 0.0, 0.0, 0.0  &
   orientation = 0.0, 0.0, 0.0
!
ude attributes  &
   instance_name = .__ACME_MULTI_POST_TESTRIG.jms_post_pad_vertical_lr  &
   active = on
!
ude create instance  &
   instance_name = .__ACME_MULTI_POST_TESTRIG.jms_post_pad_vertical_rr  &
   definition_name = .ACAR.inputs.ac_joint_motion_actuator  &
   location = 0.0, 0.0, 0.0  &
   orientation = 0.0, 0.0, 0.0
!
ude attributes  &
   instance_name = .__ACME_MULTI_POST_TESTRIG.jms_post_pad_vertical_rr  &
   active = on
!
ude create instance  &
   instance_name = .__ACME_MULTI_POST_TESTRIG.jms_post_pad_vertical_lr2  &
   definition_name = .ACAR.inputs.ac_joint_motion_actuator  &
   location = 0.0, 0.0, 0.0  &
   orientation = 0.0, 0.0, 0.0
!
ude attributes  &
   instance_name = .__ACME_MULTI_POST_TESTRIG.jms_post_pad_vertical_lr2  &
   active = on
!
ude create instance  &
   instance_name = .__ACME_MULTI_POST_TESTRIG.jms_post_pad_vertical_rr2  &
   definition_name = .ACAR.inputs.ac_joint_motion_actuator  &
   location = 0.0, 0.0, 0.0  &
   orientation = 0.0, 0.0, 0.0
!
ude attributes  &
   instance_name = .__ACME_MULTI_POST_TESTRIG.jms_post_pad_vertical_rr2  &
   active = on
!
!-------------------------- Adams View UDE Instance ---------------------------!
!
!
variable modify  &
   variable_name = .__ACME_MULTI_POST_TESTRIG.jms_post_pad_vertical_lf.type_of_freedom  &
   string_value = "translational"
!
variable modify  &
   variable_name = .__ACME_MULTI_POST_TESTRIG.jms_post_pad_vertical_lf.function  &
   string_value = "0"
!
variable modify  &
   variable_name = .__ACME_MULTI_POST_TESTRIG.jms_post_pad_vertical_lf.time_derivative  &
   string_value = "displacement"
!
variable modify  &
   variable_name = .__ACME_MULTI_POST_TESTRIG.jms_post_pad_vertical_lf.application  &
   string_value = "pad_excitation"
!
variable modify  &
   variable_name = .__ACME_MULTI_POST_TESTRIG.jms_post_pad_vertical_lf.identifier  &
   string_value = "front_left_actuator"
!
variable modify  &
   variable_name = .__ACME_MULTI_POST_TESTRIG.jms_post_pad_vertical_lf.force_limits  &
   real_value =   &
      0.0,  &
      0.0
!
variable modify  &
   variable_name = .__ACME_MULTI_POST_TESTRIG.jms_post_pad_vertical_lf.displacement_limits  &
   real_value =   &
      0.0,  &
      0.0
!
variable modify  &
   variable_name = .__ACME_MULTI_POST_TESTRIG.jms_post_pad_vertical_lf.velocity_limits  &
   real_value =   &
      0.0,  &
      0.0
!
variable modify  &
   variable_name = .__ACME_MULTI_POST_TESTRIG.jms_post_pad_vertical_lf.acceleration_limits  &
   real_value =   &
      0.0,  &
      0.0
!
variable modify  &
   variable_name = .__ACME_MULTI_POST_TESTRIG.jms_post_pad_vertical_lf.unit_string  &
   string_value = "mm"
!
variable modify  &
   variable_name = .__ACME_MULTI_POST_TESTRIG.jms_post_pad_vertical_lf.ic_disp  &
   real_value = 0.0
!
variable modify  &
   variable_name = .__ACME_MULTI_POST_TESTRIG.jms_post_pad_vertical_lf.ic_vel  &
   real_value = 0.0
!
variable modify  &
   variable_name = .__ACME_MULTI_POST_TESTRIG.jms_post_pad_vertical_lf.joint  &
   object_value = .__ACME_MULTI_POST_TESTRIG.jostra_mount_post_pad_vertical_lf
!
variable modify  &
   variable_name = .__ACME_MULTI_POST_TESTRIG.jms_post_pad_vertical_lf.i_marker  &
   object_value = (.__ACME_MULTI_POST_TESTRIG.jostra_mount_post_pad_vertical_lf.i)
!
variable modify  &
   variable_name = .__ACME_MULTI_POST_TESTRIG.jms_post_pad_vertical_lf.j_marker  &
   object_value = (.__ACME_MULTI_POST_TESTRIG.jostra_mount_post_pad_vertical_lf.j)
!
ude modify instance  &
   instance_name = .__ACME_MULTI_POST_TESTRIG.jms_post_pad_vertical_lf
!
!-------------------------- Adams View UDE Instance ---------------------------!
!
!
variable modify  &
   variable_name = .__ACME_MULTI_POST_TESTRIG.jms_post_pad_vertical_rf.type_of_freedom  &
   string_value = "translational"
!
variable modify  &
   variable_name = .__ACME_MULTI_POST_TESTRIG.jms_post_pad_vertical_rf.function  &
   string_value = "0"
!
variable modify  &
   variable_name = .__ACME_MULTI_POST_TESTRIG.jms_post_pad_vertical_rf.time_derivative  &
   string_value = "displacement"
!
variable modify  &
   variable_name = .__ACME_MULTI_POST_TESTRIG.jms_post_pad_vertical_rf.application  &
   string_value = "pad_excitation"
!
variable modify  &
   variable_name = .__ACME_MULTI_POST_TESTRIG.jms_post_pad_vertical_rf.identifier  &
   string_value = "front_right_actuator"
!
variable modify  &
   variable_name = .__ACME_MULTI_POST_TESTRIG.jms_post_pad_vertical_rf.force_limits  &
   real_value =   &
      0.0,  &
      0.0
!
variable modify  &
   variable_name = .__ACME_MULTI_POST_TESTRIG.jms_post_pad_vertical_rf.displacement_limits  &
   real_value =   &
      0.0,  &
      0.0
!
variable modify  &
   variable_name = .__ACME_MULTI_POST_TESTRIG.jms_post_pad_vertical_rf.velocity_limits  &
   real_value =   &
      0.0,  &
      0.0
!
variable modify  &
   variable_name = .__ACME_MULTI_POST_TESTRIG.jms_post_pad_vertical_rf.acceleration_limits  &
   real_value =   &
      0.0,  &
      0.0
!
variable modify  &
   variable_name = .__ACME_MULTI_POST_TESTRIG.jms_post_pad_vertical_rf.unit_string  &
   string_value = "mm"
!
variable modify  &
   variable_name = .__ACME_MULTI_POST_TESTRIG.jms_post_pad_vertical_rf.ic_disp  &
   real_value = 0.0
!
variable modify  &
   variable_name = .__ACME_MULTI_POST_TESTRIG.jms_post_pad_vertical_rf.ic_vel  &
   real_value = 0.0
!
variable modify  &
   variable_name = .__ACME_MULTI_POST_TESTRIG.jms_post_pad_vertical_rf.joint  &
   object_value = .__ACME_MULTI_POST_TESTRIG.jostra_mount_post_pad_vertical_rf
!
variable modify  &
   variable_name = .__ACME_MULTI_POST_TESTRIG.jms_post_pad_vertical_rf.i_marker  &
   object_value = (.__ACME_MULTI_POST_TESTRIG.jostra_mount_post_pad_vertical_rf.i)
!
variable modify  &
   variable_name = .__ACME_MULTI_POST_TESTRIG.jms_post_pad_vertical_rf.j_marker  &
   object_value = (.__ACME_MULTI_POST_TESTRIG.jostra_mount_post_pad_vertical_rf.j)
!
ude modify instance  &
   instance_name = .__ACME_MULTI_POST_TESTRIG.jms_post_pad_vertical_rf
!
!-------------------------- Adams View UDE Instance ---------------------------!
!
!
variable modify  &
   variable_name = .__ACME_MULTI_POST_TESTRIG.jms_post_pad_vertical_lr.type_of_freedom  &
   string_value = "translational"
!
variable modify  &
   variable_name = .__ACME_MULTI_POST_TESTRIG.jms_post_pad_vertical_lr.function  &
   string_value = "0"
!
variable modify  &
   variable_name = .__ACME_MULTI_POST_TESTRIG.jms_post_pad_vertical_lr.time_derivative  &
   string_value = "displacement"
!
variable modify  &
   variable_name = .__ACME_MULTI_POST_TESTRIG.jms_post_pad_vertical_lr.application  &
   string_value = "pad_excitation"
!
variable modify  &
   variable_name = .__ACME_MULTI_POST_TESTRIG.jms_post_pad_vertical_lr.identifier  &
   string_value = "rear_left_actuator"
!
variable modify  &
   variable_name = .__ACME_MULTI_POST_TESTRIG.jms_post_pad_vertical_lr.force_limits  &
   real_value =   &
      0.0,  &
      0.0
!
variable modify  &
   variable_name = .__ACME_MULTI_POST_TESTRIG.jms_post_pad_vertical_lr.displacement_limits  &
   real_value =   &
      0.0,  &
      0.0
!
variable modify  &
   variable_name = .__ACME_MULTI_POST_TESTRIG.jms_post_pad_vertical_lr.velocity_limits  &
   real_value =   &
      0.0,  &
      0.0
!
variable modify  &
   variable_name = .__ACME_MULTI_POST_TESTRIG.jms_post_pad_vertical_lr.acceleration_limits  &
   real_value =   &
      0.0,  &
      0.0
!
variable modify  &
   variable_name = .__ACME_MULTI_POST_TESTRIG.jms_post_pad_vertical_lr.unit_string  &
   string_value = "mm"
!
variable modify  &
   variable_name = .__ACME_MULTI_POST_TESTRIG.jms_post_pad_vertical_lr.ic_disp  &
   real_value = 0.0
!
variable modify  &
   variable_name = .__ACME_MULTI_POST_TESTRIG.jms_post_pad_vertical_lr.ic_vel  &
   real_value = 0.0
!
variable modify  &
   variable_name = .__ACME_MULTI_POST_TESTRIG.jms_post_pad_vertical_lr.joint  &
   object_value = .__ACME_MULTI_POST_TESTRIG.jostra_mount_post_pad_vertical_lr
!
variable modify  &
   variable_name = .__ACME_MULTI_POST_TESTRIG.jms_post_pad_vertical_lr.i_marker  &
   object_value = (.__ACME_MULTI_POST_TESTRIG.jostra_mount_post_pad_vertical_lr.i)
!
variable modify  &
   variable_name = .__ACME_MULTI_POST_TESTRIG.jms_post_pad_vertical_lr.j_marker  &
   object_value = (.__ACME_MULTI_POST_TESTRIG.jostra_mount_post_pad_vertical_lr.j)
!
ude modify instance  &
   instance_name = .__ACME_MULTI_POST_TESTRIG.jms_post_pad_vertical_lr
!
!-------------------------- Adams View UDE Instance ---------------------------!
!
!
variable modify  &
   variable_name = .__ACME_MULTI_POST_TESTRIG.jms_post_pad_vertical_rr.type_of_freedom  &
   string_value = "translational"
!
variable modify  &
   variable_name = .__ACME_MULTI_POST_TESTRIG.jms_post_pad_vertical_rr.function  &
   string_value = "0"
!
variable modify  &
   variable_name = .__ACME_MULTI_POST_TESTRIG.jms_post_pad_vertical_rr.time_derivative  &
   string_value = "displacement"
!
variable modify  &
   variable_name = .__ACME_MULTI_POST_TESTRIG.jms_post_pad_vertical_rr.application  &
   string_value = "pad_excitation"
!
variable modify  &
   variable_name = .__ACME_MULTI_POST_TESTRIG.jms_post_pad_vertical_rr.identifier  &
   string_value = "rear_right_actuator"
!
variable modify  &
   variable_name = .__ACME_MULTI_POST_TESTRIG.jms_post_pad_vertical_rr.force_limits  &
   real_value =   &
      0.0,  &
      0.0
!
variable modify  &
   variable_name = .__ACME_MULTI_POST_TESTRIG.jms_post_pad_vertical_rr.displacement_limits  &
   real_value =   &
      0.0,  &
      0.0
!
variable modify  &
   variable_name = .__ACME_MULTI_POST_TESTRIG.jms_post_pad_vertical_rr.velocity_limits  &
   real_value =   &
      0.0,  &
      0.0
!
variable modify  &
   variable_name = .__ACME_MULTI_POST_TESTRIG.jms_post_pad_vertical_rr.acceleration_limits  &
   real_value =   &
      0.0,  &
      0.0
!
variable modify  &
   variable_name = .__ACME_MULTI_POST_TESTRIG.jms_post_pad_vertical_rr.unit_string  &
   string_value = "mm"
!
variable modify  &
   variable_name = .__ACME_MULTI_POST_TESTRIG.jms_post_pad_vertical_rr.ic_disp  &
   real_value = 0.0
!
variable modify  &
   variable_name = .__ACME_MULTI_POST_TESTRIG.jms_post_pad_vertical_rr.ic_vel  &
   real_value = 0.0
!
variable modify  &
   variable_name = .__ACME_MULTI_POST_TESTRIG.jms_post_pad_vertical_rr.joint  &
   object_value = .__ACME_MULTI_POST_TESTRIG.jostra_mount_post_pad_vertical_rr
!
variable modify  &
   variable_name = .__ACME_MULTI_POST_TESTRIG.jms_post_pad_vertical_rr.i_marker  &
   object_value = (.__ACME_MULTI_POST_TESTRIG.jostra_mount_post_pad_vertical_rr.i)
!
variable modify  &
   variable_name = .__ACME_MULTI_POST_TESTRIG.jms_post_pad_vertical_rr.j_marker  &
   object_value = (.__ACME_MULTI_POST_TESTRIG.jostra_mount_post_pad_vertical_rr.j)
!
ude modify instance  &
   instance_name = .__ACME_MULTI_POST_TESTRIG.jms_post_pad_vertical_rr
!
!-------------------------- Adams View UDE Instance ---------------------------!
!
!
variable modify  &
   variable_name = .__ACME_MULTI_POST_TESTRIG.jms_post_pad_vertical_lr2.type_of_freedom  &
   string_value = "translational"
!
variable modify  &
   variable_name = .__ACME_MULTI_POST_TESTRIG.jms_post_pad_vertical_lr2.function  &
   string_value = "0"
!
variable modify  &
   variable_name = .__ACME_MULTI_POST_TESTRIG.jms_post_pad_vertical_lr2.time_derivative  &
   string_value = "displacement"
!
variable modify  &
   variable_name = .__ACME_MULTI_POST_TESTRIG.jms_post_pad_vertical_lr2.application  &
   string_value = "pad_excitation"
!
variable modify  &
   variable_name = .__ACME_MULTI_POST_TESTRIG.jms_post_pad_vertical_lr2.identifier  &
   string_value = "rear2_left_actuator"
!
variable modify  &
   variable_name = .__ACME_MULTI_POST_TESTRIG.jms_post_pad_vertical_lr2.force_limits  &
   real_value =   &
      0.0,  &
      0.0
!
variable modify  &
   variable_name = .__ACME_MULTI_POST_TESTRIG.jms_post_pad_vertical_lr2.displacement_limits  &
   real_value =   &
      0.0,  &
      0.0
!
variable modify  &
   variable_name = .__ACME_MULTI_POST_TESTRIG.jms_post_pad_vertical_lr2.velocity_limits  &
   real_value =   &
      0.0,  &
      0.0
!
variable modify  &
   variable_name = .__ACME_MULTI_POST_TESTRIG.jms_post_pad_vertical_lr2.acceleration_limits  &
   real_value =   &
      0.0,  &
      0.0
!
variable modify  &
   variable_name = .__ACME_MULTI_POST_TESTRIG.jms_post_pad_vertical_lr2.unit_string  &
   string_value = "mm"
!
variable modify  &
   variable_name = .__ACME_MULTI_POST_TESTRIG.jms_post_pad_vertical_lr2.ic_disp  &
   real_value = 0.0
!
variable modify  &
   variable_name = .__ACME_MULTI_POST_TESTRIG.jms_post_pad_vertical_lr2.ic_vel  &
   real_value = 0.0
!
variable modify  &
   variable_name = .__ACME_MULTI_POST_TESTRIG.jms_post_pad_vertical_lr2.joint  &
   object_value = .__ACME_MULTI_POST_TESTRIG.jostra_mount_post_pad_vertical_lr2
!
variable modify  &
   variable_name = .__ACME_MULTI_POST_TESTRIG.jms_post_pad_vertical_lr2.i_marker  &
   object_value = (.__ACME_MULTI_POST_TESTRIG.jostra_mount_post_pad_vertical_lr2.i)
!
variable modify  &
   variable_name = .__ACME_MULTI_POST_TESTRIG.jms_post_pad_vertical_lr2.j_marker  &
   object_value = (.__ACME_MULTI_POST_TESTRIG.jostra_mount_post_pad_vertical_lr2.j)
!
ude modify instance  &
   instance_name = .__ACME_MULTI_POST_TESTRIG.jms_post_pad_vertical_lr2
!
!-------------------------- Adams View UDE Instance ---------------------------!
!
!
variable modify  &
   variable_name = .__ACME_MULTI_POST_TESTRIG.jms_post_pad_vertical_rr2.type_of_freedom  &
   string_value = "translational"
!
variable modify  &
   variable_name = .__ACME_MULTI_POST_TESTRIG.jms_post_pad_vertical_rr2.function  &
   string_value = "0"
!
variable modify  &
   variable_name = .__ACME_MULTI_POST_TESTRIG.jms_post_pad_vertical_rr2.time_derivative  &
   string_value = "displacement"
!
variable modify  &
   variable_name = .__ACME_MULTI_POST_TESTRIG.jms_post_pad_vertical_rr2.application  &
   string_value = "pad_excitation"
!
variable modify  &
   variable_name = .__ACME_MULTI_POST_TESTRIG.jms_post_pad_vertical_rr2.identifier  &
   string_value = "rear2_right_actuator"
!
variable modify  &
   variable_name = .__ACME_MULTI_POST_TESTRIG.jms_post_pad_vertical_rr2.force_limits  &
   real_value =   &
      0.0,  &
      0.0
!
variable modify  &
   variable_name = .__ACME_MULTI_POST_TESTRIG.jms_post_pad_vertical_rr2.displacement_limits  &
   real_value =   &
      0.0,  &
      0.0
!
variable modify  &
   variable_name = .__ACME_MULTI_POST_TESTRIG.jms_post_pad_vertical_rr2.velocity_limits  &
   real_value =   &
      0.0,  &
      0.0
!
variable modify  &
   variable_name = .__ACME_MULTI_POST_TESTRIG.jms_post_pad_vertical_rr2.acceleration_limits  &
   real_value =   &
      0.0,  &
      0.0
!
variable modify  &
   variable_name = .__ACME_MULTI_POST_TESTRIG.jms_post_pad_vertical_rr2.unit_string  &
   string_value = "mm"
!
variable modify  &
   variable_name = .__ACME_MULTI_POST_TESTRIG.jms_post_pad_vertical_rr2.ic_disp  &
   real_value = 0.0
!
variable modify  &
   variable_name = .__ACME_MULTI_POST_TESTRIG.jms_post_pad_vertical_rr2.ic_vel  &
   real_value = 0.0
!
variable modify  &
   variable_name = .__ACME_MULTI_POST_TESTRIG.jms_post_pad_vertical_rr2.joint  &
   object_value = .__ACME_MULTI_POST_TESTRIG.jostra_mount_post_pad_vertical_rr2
!
variable modify  &
   variable_name = .__ACME_MULTI_POST_TESTRIG.jms_post_pad_vertical_rr2.i_marker  &
   object_value = (.__ACME_MULTI_POST_TESTRIG.jostra_mount_post_pad_vertical_rr2.i)
!
variable modify  &
   variable_name = .__ACME_MULTI_POST_TESTRIG.jms_post_pad_vertical_rr2.j_marker  &
   object_value = (.__ACME_MULTI_POST_TESTRIG.jostra_mount_post_pad_vertical_rr2.j)
!
ude modify instance  &
   instance_name = .__ACME_MULTI_POST_TESTRIG.jms_post_pad_vertical_rr2
!
undo end_block
!
!---------------------------------- Motions -----------------------------------!
!
!
constraint create motion_generator  &
   motion_name = .__ACME_MULTI_POST_TESTRIG._cv_motion  &
   comments = "Dummy for communicators"  &
   type_of_freedom = rotational  &
   joint_name = .__ACME_MULTI_POST_TESTRIG._cv_joint_for_motion  &
   function = ""
!
constraint attributes  &
   constraint_name = .__ACME_MULTI_POST_TESTRIG._cv_motion  &
   visibility = off  &
   name_visibility = off
!
!---------------------------------- Accgrav -----------------------------------!
!
!
force create body gravitational  &
   gravity_field_name = gravity  &
   x_component_gravity = 0.0  &
   y_component_gravity = 0.0  &
   z_component_gravity = -9806.65
!
!----------------------------- Analysis settings ------------------------------!
!
!
!---------------------------- Adams View Variables ----------------------------!
!
!
variable create  &
   variable_name = .__ACME_MULTI_POST_TESTRIG.speed  &
   units = "velocity"  &
   real_value = 0.0
!
variable create  &
   variable_name = .__ACME_MULTI_POST_TESTRIG.model_class  &
   string_value = "testrig"  &
   comments = "Memory for Adams Car model class"
!
variable create  &
   variable_name = .__ACME_MULTI_POST_TESTRIG.template_creation_date  &
   string_value = "2022/06/15,11:25:07"  &
   comments = "do not remove"
!
variable create  &
   variable_name = .__ACME_MULTI_POST_TESTRIG.role  &
   string_value = "analysis"  &
   comments = "Memory for Adams Car major role"
!
variable create  &
   variable_name = .__ACME_MULTI_POST_TESTRIG.minor_role  &
   string_value = "any"  &
   comments = "Memory for Adams Car minor role"
!
variable create  &
   variable_name = .__ACME_MULTI_POST_TESTRIG.phs_kinematic_flag  &
   integer_value = 0  &
   comments =   &
              "Flag that determines if kinematic joints or bushings are active"
!
variable create  &
   variable_name = .__ACME_MULTI_POST_TESTRIG.cil_wheel_center_front  &
   units = "length"  &
   real_value = 0.0, -750.0, 0.0
!
variable create  &
   variable_name = .__ACME_MULTI_POST_TESTRIG.cil_wheel_center_front.matching_name  &
   string_value = "wheel_center"
!
variable create  &
   variable_name = .__ACME_MULTI_POST_TESTRIG.cil_wheel_center_front.entity  &
   string_value = "location"
!
variable create  &
   variable_name = .__ACME_MULTI_POST_TESTRIG.cil_wheel_center_front.minor_role  &
   string_value = "front"
!
variable create  &
   variable_name = .__ACME_MULTI_POST_TESTRIG.cil_wheel_center_front.subsystem_index  &
   string_value = "inherit"
!
variable create  &
   variable_name = .__ACME_MULTI_POST_TESTRIG.cir_wheel_center_front  &
   units = "length"  &
   real_value = 0.0, 750.0, 0.0
!
variable create  &
   variable_name = .__ACME_MULTI_POST_TESTRIG.cir_wheel_center_front.matching_name  &
   string_value = "wheel_center"
!
variable create  &
   variable_name = .__ACME_MULTI_POST_TESTRIG.cir_wheel_center_front.entity  &
   string_value = "location"
!
variable create  &
   variable_name = .__ACME_MULTI_POST_TESTRIG.cir_wheel_center_front.minor_role  &
   string_value = "front"
!
variable create  &
   variable_name = .__ACME_MULTI_POST_TESTRIG.cir_wheel_center_front.subsystem_index  &
   string_value = "inherit"
!
variable create  &
   variable_name = .__ACME_MULTI_POST_TESTRIG.cil_wheel_center_rear  &
   units = "length"  &
   real_value = 2700.0, -750.0, 0.0
!
variable create  &
   variable_name = .__ACME_MULTI_POST_TESTRIG.cil_wheel_center_rear.matching_name  &
   string_value = "wheel_center"
!
variable create  &
   variable_name = .__ACME_MULTI_POST_TESTRIG.cil_wheel_center_rear.entity  &
   string_value = "location"
!
variable create  &
   variable_name = .__ACME_MULTI_POST_TESTRIG.cil_wheel_center_rear.minor_role  &
   string_value = "rear"
!
variable create  &
   variable_name = .__ACME_MULTI_POST_TESTRIG.cil_wheel_center_rear.subsystem_index  &
   string_value = "inherit"
!
variable create  &
   variable_name = .__ACME_MULTI_POST_TESTRIG.cir_wheel_center_rear  &
   units = "length"  &
   real_value = 2700.0, 750.0, 0.0
!
variable create  &
   variable_name = .__ACME_MULTI_POST_TESTRIG.cir_wheel_center_rear.matching_name  &
   string_value = "wheel_center"
!
variable create  &
   variable_name = .__ACME_MULTI_POST_TESTRIG.cir_wheel_center_rear.entity  &
   string_value = "location"
!
variable create  &
   variable_name = .__ACME_MULTI_POST_TESTRIG.cir_wheel_center_rear.minor_role  &
   string_value = "rear"
!
variable create  &
   variable_name = .__ACME_MULTI_POST_TESTRIG.cir_wheel_center_rear.subsystem_index  &
   string_value = "inherit"
!
variable create  &
   variable_name = .__ACME_MULTI_POST_TESTRIG.cil_wheel_center_rear2  &
   units = "length"  &
   real_value = 4000.0, -750.0, 0.0
!
variable create  &
   variable_name = .__ACME_MULTI_POST_TESTRIG.cil_wheel_center_rear2.matching_name  &
   string_value = "wheel_center"
!
variable create  &
   variable_name = .__ACME_MULTI_POST_TESTRIG.cil_wheel_center_rear2.entity  &
   string_value = "location"
!
variable create  &
   variable_name = .__ACME_MULTI_POST_TESTRIG.cil_wheel_center_rear2.minor_role  &
   string_value = "rear2"
!
variable create  &
   variable_name = .__ACME_MULTI_POST_TESTRIG.cil_wheel_center_rear2.subsystem_index  &
   string_value = "inherit"
!
variable create  &
   variable_name = .__ACME_MULTI_POST_TESTRIG.cir_wheel_center_rear2  &
   units = "length"  &
   real_value = 4000.0, 750.0, 0.0
!
variable create  &
   variable_name = .__ACME_MULTI_POST_TESTRIG.cir_wheel_center_rear2.matching_name  &
   string_value = "wheel_center"
!
variable create  &
   variable_name = .__ACME_MULTI_POST_TESTRIG.cir_wheel_center_rear2.entity  &
   string_value = "location"
!
variable create  &
   variable_name = .__ACME_MULTI_POST_TESTRIG.cir_wheel_center_rear2.minor_role  &
   string_value = "rear2"
!
variable create  &
   variable_name = .__ACME_MULTI_POST_TESTRIG.cir_wheel_center_rear2.subsystem_index  &
   string_value = "inherit"
!
variable create  &
   variable_name = .__ACME_MULTI_POST_TESTRIG.gel_mount_post_pad_vertical_front.sml_sprung_mass_percent  &
   range = 0.0, 100.0  &
   delta_type = relative  &
   real_value = 100.0
!
variable create  &
   variable_name = .__ACME_MULTI_POST_TESTRIG.ger_mount_post_pad_vertical_front.smr_sprung_mass_percent  &
   range = 0.0, 100.0  &
   delta_type = relative  &
   real_value = 100.0
!
variable create  &
   variable_name = .__ACME_MULTI_POST_TESTRIG.gel_mount_post_pad_vertical_rear.sml_sprung_mass_percent  &
   range = 0.0, 100.0  &
   delta_type = relative  &
   real_value = 100.0
!
variable create  &
   variable_name = .__ACME_MULTI_POST_TESTRIG.ger_mount_post_pad_vertical_rear.smr_sprung_mass_percent  &
   range = 0.0, 100.0  &
   delta_type = relative  &
   real_value = 100.0
!
variable create  &
   variable_name = .__ACME_MULTI_POST_TESTRIG.gel_mount_post_pad_vertical_rear2.sml_sprung_mass_percent  &
   range = 0.0, 100.0  &
   delta_type = relative  &
   real_value = 100.0
!
variable create  &
   variable_name = .__ACME_MULTI_POST_TESTRIG.ger_mount_post_pad_vertical_rear2.smr_sprung_mass_percent  &
   range = 0.0, 100.0  &
   delta_type = relative  &
   real_value = 100.0
!
variable create  &
   variable_name = .__ACME_MULTI_POST_TESTRIG.mtl_suspension_mount_front.minor_role  &
   string_value = "front"
!
variable create  &
   variable_name = .__ACME_MULTI_POST_TESTRIG.mtl_suspension_mount_front.subsystem_index  &
   string_value = "inherit"
!
variable create  &
   variable_name = .__ACME_MULTI_POST_TESTRIG.mtl_suspension_mount_front.dependents  &
   object_value = (NONE)
!
variable create  &
   variable_name = .__ACME_MULTI_POST_TESTRIG.cil_suspension_mount_front  &
   object_value = (NONE)  &
   comments = "Autocreated for mount part: mtl_suspension_mount_front"
!
variable create  &
   variable_name = .__ACME_MULTI_POST_TESTRIG.cil_suspension_mount_front.matching_name  &
   string_value = "suspension_mount"
!
variable create  &
   variable_name = .__ACME_MULTI_POST_TESTRIG.cil_suspension_mount_front.entity  &
   string_value = "mount"
!
variable create  &
   variable_name = .__ACME_MULTI_POST_TESTRIG.cil_suspension_mount_front.minor_role  &
   string_value = "front"
!
variable create  &
   variable_name = .__ACME_MULTI_POST_TESTRIG.cil_suspension_mount_front.subsystem_index  &
   string_value = "inherit"
!
variable create  &
   variable_name = .__ACME_MULTI_POST_TESTRIG.mtr_suspension_mount_front.minor_role  &
   string_value = "front"
!
variable create  &
   variable_name = .__ACME_MULTI_POST_TESTRIG.mtr_suspension_mount_front.subsystem_index  &
   string_value = "inherit"
!
variable create  &
   variable_name = .__ACME_MULTI_POST_TESTRIG.mtr_suspension_mount_front.dependents  &
   object_value = (NONE)
!
variable create  &
   variable_name = .__ACME_MULTI_POST_TESTRIG.cir_suspension_mount_front  &
   object_value = (NONE)  &
   comments = "Autocreated for mount part: mtr_suspension_mount_front"
!
variable create  &
   variable_name = .__ACME_MULTI_POST_TESTRIG.cir_suspension_mount_front.matching_name  &
   string_value = "suspension_mount"
!
variable create  &
   variable_name = .__ACME_MULTI_POST_TESTRIG.cir_suspension_mount_front.entity  &
   string_value = "mount"
!
variable create  &
   variable_name = .__ACME_MULTI_POST_TESTRIG.cir_suspension_mount_front.minor_role  &
   string_value = "front"
!
variable create  &
   variable_name = .__ACME_MULTI_POST_TESTRIG.cir_suspension_mount_front.subsystem_index  &
   string_value = "inherit"
!
variable create  &
   variable_name = .__ACME_MULTI_POST_TESTRIG.mtl_suspension_mount_rear.minor_role  &
   string_value = "rear"
!
variable create  &
   variable_name = .__ACME_MULTI_POST_TESTRIG.mtl_suspension_mount_rear.subsystem_index  &
   string_value = "inherit"
!
variable create  &
   variable_name = .__ACME_MULTI_POST_TESTRIG.mtl_suspension_mount_rear.dependents  &
   object_value = (NONE)
!
variable create  &
   variable_name = .__ACME_MULTI_POST_TESTRIG.cil_suspension_mount_rear  &
   object_value = (NONE)  &
   comments = "Autocreated for mount part: mtl_suspension_mount_rear"
!
variable create  &
   variable_name = .__ACME_MULTI_POST_TESTRIG.cil_suspension_mount_rear.matching_name  &
   string_value = "suspension_mount"
!
variable create  &
   variable_name = .__ACME_MULTI_POST_TESTRIG.cil_suspension_mount_rear.entity  &
   string_value = "mount"
!
variable create  &
   variable_name = .__ACME_MULTI_POST_TESTRIG.cil_suspension_mount_rear.minor_role  &
   string_value = "rear"
!
variable create  &
   variable_name = .__ACME_MULTI_POST_TESTRIG.cil_suspension_mount_rear.subsystem_index  &
   string_value = "inherit"
!
variable create  &
   variable_name = .__ACME_MULTI_POST_TESTRIG.mtr_suspension_mount_rear.minor_role  &
   string_value = "rear"
!
variable create  &
   variable_name = .__ACME_MULTI_POST_TESTRIG.mtr_suspension_mount_rear.subsystem_index  &
   string_value = "inherit"
!
variable create  &
   variable_name = .__ACME_MULTI_POST_TESTRIG.mtr_suspension_mount_rear.dependents  &
   object_value = (NONE)
!
variable create  &
   variable_name = .__ACME_MULTI_POST_TESTRIG.cir_suspension_mount_rear  &
   object_value = (NONE)  &
   comments = "Autocreated for mount part: mtr_suspension_mount_rear"
!
variable create  &
   variable_name = .__ACME_MULTI_POST_TESTRIG.cir_suspension_mount_rear.matching_name  &
   string_value = "suspension_mount"
!
variable create  &
   variable_name = .__ACME_MULTI_POST_TESTRIG.cir_suspension_mount_rear.entity  &
   string_value = "mount"
!
variable create  &
   variable_name = .__ACME_MULTI_POST_TESTRIG.cir_suspension_mount_rear.minor_role  &
   string_value = "rear"
!
variable create  &
   variable_name = .__ACME_MULTI_POST_TESTRIG.cir_suspension_mount_rear.subsystem_index  &
   string_value = "inherit"
!
variable create  &
   variable_name = .__ACME_MULTI_POST_TESTRIG.mtl_suspension_mount_rear2.minor_role  &
   string_value = "rear2"
!
variable create  &
   variable_name = .__ACME_MULTI_POST_TESTRIG.mtl_suspension_mount_rear2.subsystem_index  &
   string_value = "inherit"
!
variable create  &
   variable_name = .__ACME_MULTI_POST_TESTRIG.mtl_suspension_mount_rear2.dependents  &
   object_value = (NONE)
!
variable create  &
   variable_name = .__ACME_MULTI_POST_TESTRIG.cil_suspension_mount_rear2  &
   object_value = (NONE)  &
   comments = "Autocreated for mount part: mtl_suspension_mount_rear2"
!
variable create  &
   variable_name = .__ACME_MULTI_POST_TESTRIG.cil_suspension_mount_rear2.matching_name  &
   string_value = "suspension_mount"
!
variable create  &
   variable_name = .__ACME_MULTI_POST_TESTRIG.cil_suspension_mount_rear2.entity  &
   string_value = "mount"
!
variable create  &
   variable_name = .__ACME_MULTI_POST_TESTRIG.cil_suspension_mount_rear2.minor_role  &
   string_value = "rear2"
!
variable create  &
   variable_name = .__ACME_MULTI_POST_TESTRIG.cil_suspension_mount_rear2.subsystem_index  &
   string_value = "inherit"
!
variable create  &
   variable_name = .__ACME_MULTI_POST_TESTRIG.mtr_suspension_mount_rear2.minor_role  &
   string_value = "rear2"
!
variable create  &
   variable_name = .__ACME_MULTI_POST_TESTRIG.mtr_suspension_mount_rear2.subsystem_index  &
   string_value = "inherit"
!
variable create  &
   variable_name = .__ACME_MULTI_POST_TESTRIG.mtr_suspension_mount_rear2.dependents  &
   object_value = (NONE)
!
variable create  &
   variable_name = .__ACME_MULTI_POST_TESTRIG.cir_suspension_mount_rear2  &
   object_value = (NONE)  &
   comments = "Autocreated for mount part: mtr_suspension_mount_rear2"
!
variable create  &
   variable_name = .__ACME_MULTI_POST_TESTRIG.cir_suspension_mount_rear2.matching_name  &
   string_value = "suspension_mount"
!
variable create  &
   variable_name = .__ACME_MULTI_POST_TESTRIG.cir_suspension_mount_rear2.entity  &
   string_value = "mount"
!
variable create  &
   variable_name = .__ACME_MULTI_POST_TESTRIG.cir_suspension_mount_rear2.minor_role  &
   string_value = "rear2"
!
variable create  &
   variable_name = .__ACME_MULTI_POST_TESTRIG.cir_suspension_mount_rear2.subsystem_index  &
   string_value = "inherit"
!
variable create  &
   variable_name = .__ACME_MULTI_POST_TESTRIG.phs_flag_active_actuators  &
   string_value = "not set"
!
variable create  &
   variable_name = .__ACME_MULTI_POST_TESTRIG.phs_flag_input_locations  &
   string_value = "not set"
!
variable create  &
   variable_name = .__ACME_MULTI_POST_TESTRIG.col_mount_post_pad_vertical_front  &
   object_value = (NONE)
!
variable create  &
   variable_name = .__ACME_MULTI_POST_TESTRIG.col_mount_post_pad_vertical_front.matching_name  &
   string_value = "mount_post_pad_vertical_front"
!
variable create  &
   variable_name = .__ACME_MULTI_POST_TESTRIG.col_mount_post_pad_vertical_front.minor_role  &
   string_value = "front"
!
variable create  &
   variable_name = .__ACME_MULTI_POST_TESTRIG.col_mount_post_pad_vertical_front.entity  &
   string_value = "mount"
!
variable create  &
   variable_name = .__ACME_MULTI_POST_TESTRIG.cor_mount_post_pad_vertical_front  &
   object_value = (NONE)
!
variable create  &
   variable_name = .__ACME_MULTI_POST_TESTRIG.cor_mount_post_pad_vertical_front.matching_name  &
   string_value = "mount_post_pad_vertical_front"
!
variable create  &
   variable_name = .__ACME_MULTI_POST_TESTRIG.cor_mount_post_pad_vertical_front.minor_role  &
   string_value = "front"
!
variable create  &
   variable_name = .__ACME_MULTI_POST_TESTRIG.cor_mount_post_pad_vertical_front.entity  &
   string_value = "mount"
!
variable create  &
   variable_name = .__ACME_MULTI_POST_TESTRIG.col_mount_post_pad_vertical_rear  &
   object_value = (NONE)
!
variable create  &
   variable_name = .__ACME_MULTI_POST_TESTRIG.col_mount_post_pad_vertical_rear.matching_name  &
   string_value = "mount_post_pad_vertical_rear"
!
variable create  &
   variable_name = .__ACME_MULTI_POST_TESTRIG.col_mount_post_pad_vertical_rear.minor_role  &
   string_value = "rear"
!
variable create  &
   variable_name = .__ACME_MULTI_POST_TESTRIG.col_mount_post_pad_vertical_rear.entity  &
   string_value = "mount"
!
variable create  &
   variable_name = .__ACME_MULTI_POST_TESTRIG.cor_mount_post_pad_vertical_rear  &
   object_value = (NONE)
!
variable create  &
   variable_name = .__ACME_MULTI_POST_TESTRIG.cor_mount_post_pad_vertical_rear.matching_name  &
   string_value = "mount_post_pad_vertical_rear"
!
variable create  &
   variable_name = .__ACME_MULTI_POST_TESTRIG.cor_mount_post_pad_vertical_rear.minor_role  &
   string_value = "rear"
!
variable create  &
   variable_name = .__ACME_MULTI_POST_TESTRIG.cor_mount_post_pad_vertical_rear.entity  &
   string_value = "mount"
!
variable create  &
   variable_name = .__ACME_MULTI_POST_TESTRIG.col_mount_post_pad_vertical_rear2  &
   object_value = (NONE)
!
variable create  &
   variable_name = .__ACME_MULTI_POST_TESTRIG.col_mount_post_pad_vertical_rear2.matching_name  &
   string_value = "mount_post_pad_vertical_rear2"
!
variable create  &
   variable_name = .__ACME_MULTI_POST_TESTRIG.col_mount_post_pad_vertical_rear2.minor_role  &
   string_value = "rear2"
!
variable create  &
   variable_name = .__ACME_MULTI_POST_TESTRIG.col_mount_post_pad_vertical_rear2.entity  &
   string_value = "mount"
!
variable create  &
   variable_name = .__ACME_MULTI_POST_TESTRIG.cor_mount_post_pad_vertical_rear2  &
   object_value = (NONE)
!
variable create  &
   variable_name = .__ACME_MULTI_POST_TESTRIG.cor_mount_post_pad_vertical_rear2.matching_name  &
   string_value = "mount_post_pad_vertical_rear2"
!
variable create  &
   variable_name = .__ACME_MULTI_POST_TESTRIG.cor_mount_post_pad_vertical_rear2.minor_role  &
   string_value = "rear2"
!
variable create  &
   variable_name = .__ACME_MULTI_POST_TESTRIG.cor_mount_post_pad_vertical_rear2.entity  &
   string_value = "mount"
!
variable create  &
   variable_name = .__ACME_MULTI_POST_TESTRIG.cis_body_subsystem_location  &
   units = "length"  &
   real_value = 0.0, 0.0, 0.0
!
variable create  &
   variable_name = .__ACME_MULTI_POST_TESTRIG.cis_body_subsystem_location.matching_name  &
   string_value = "body_subsystem_location"
!
variable create  &
   variable_name = .__ACME_MULTI_POST_TESTRIG.cis_body_subsystem_location.entity  &
   string_value = "location"
!
variable create  &
   variable_name = .__ACME_MULTI_POST_TESTRIG.cis_body_subsystem_location.minor_role  &
   string_value = "any"
!
variable create  &
   variable_name = .__ACME_MULTI_POST_TESTRIG.mts_body_subsystem_deactive.minor_role  &
   string_value = "any"
!
variable create  &
   variable_name = .__ACME_MULTI_POST_TESTRIG.mts_body_subsystem_deactive.dependents  &
   object_value = (NONE)
!
variable create  &
   variable_name = .__ACME_MULTI_POST_TESTRIG.cis_body_subsystem_deactive  &
   object_value = (NONE)  &
   comments = "Autocreated for mount part: mts_body_subsystem_deactive"
!
variable create  &
   variable_name = .__ACME_MULTI_POST_TESTRIG.cis_body_subsystem_deactive.matching_name  &
   string_value = "body_subsystem_deactive"
!
variable create  &
   variable_name = .__ACME_MULTI_POST_TESTRIG.cis_body_subsystem_deactive.entity  &
   string_value = "mount"
!
variable create  &
   variable_name = .__ACME_MULTI_POST_TESTRIG.cis_body_subsystem_deactive.minor_role  &
   string_value = "any"
!
variable create  &
   variable_name = .__ACME_MULTI_POST_TESTRIG.cil_outside_wheel_center_rear  &
   units = "length"  &
   real_value = 2700.0, -750.0, 0.0
!
variable create  &
   variable_name = .__ACME_MULTI_POST_TESTRIG.cil_outside_wheel_center_rear.matching_name  &
   string_value = "outside_wheel_center"
!
variable create  &
   variable_name = .__ACME_MULTI_POST_TESTRIG.cil_outside_wheel_center_rear.entity  &
   string_value = "location"
!
variable create  &
   variable_name = .__ACME_MULTI_POST_TESTRIG.cil_outside_wheel_center_rear.minor_role  &
   string_value = "rear"
!
variable create  &
   variable_name = .__ACME_MULTI_POST_TESTRIG.cir_outside_wheel_center_rear  &
   units = "length"  &
   real_value = 2700.0, 750.0, 0.0
!
variable create  &
   variable_name = .__ACME_MULTI_POST_TESTRIG.cir_outside_wheel_center_rear.matching_name  &
   string_value = "outside_wheel_center"
!
variable create  &
   variable_name = .__ACME_MULTI_POST_TESTRIG.cir_outside_wheel_center_rear.entity  &
   string_value = "location"
!
variable create  &
   variable_name = .__ACME_MULTI_POST_TESTRIG.cir_outside_wheel_center_rear.minor_role  &
   string_value = "rear"
!
variable create  &
   variable_name = .__ACME_MULTI_POST_TESTRIG.cil_outside_wheel_center_rear2  &
   units = "length"  &
   real_value = 4000.0, -750.0, 0.0
!
variable create  &
   variable_name = .__ACME_MULTI_POST_TESTRIG.cil_outside_wheel_center_rear2.matching_name  &
   string_value = "outside_wheel_center"
!
variable create  &
   variable_name = .__ACME_MULTI_POST_TESTRIG.cil_outside_wheel_center_rear2.entity  &
   string_value = "location"
!
variable create  &
   variable_name = .__ACME_MULTI_POST_TESTRIG.cil_outside_wheel_center_rear2.minor_role  &
   string_value = "rear2"
!
variable create  &
   variable_name = .__ACME_MULTI_POST_TESTRIG.cir_outside_wheel_center_rear2  &
   units = "length"  &
   real_value = 4000.0, 750.0, 0.0
!
variable create  &
   variable_name = .__ACME_MULTI_POST_TESTRIG.cir_outside_wheel_center_rear2.matching_name  &
   string_value = "outside_wheel_center"
!
variable create  &
   variable_name = .__ACME_MULTI_POST_TESTRIG.cir_outside_wheel_center_rear2.entity  &
   string_value = "location"
!
variable create  &
   variable_name = .__ACME_MULTI_POST_TESTRIG.cir_outside_wheel_center_rear2.minor_role  &
   string_value = "rear2"
!
variable create  &
   variable_name = .__ACME_MULTI_POST_TESTRIG.dual_wheel_offset_rear  &
   units = "no_units"  &
   range = -1.0, 1.0  &
   use_allowed_values = no  &
   real_value = 0.0
!
variable create  &
   variable_name = .__ACME_MULTI_POST_TESTRIG.dual_wheel_offset_rear2  &
   units = "no_units"  &
   range = -1.0, 1.0  &
   use_allowed_values = no  &
   real_value = 0.0
!
variable create  &
   variable_name = .__ACME_MULTI_POST_TESTRIG.format  &
   string_value = "binary"
!
variable create  &
   variable_name = .__ACME_MULTI_POST_TESTRIG.testrig_class  &
   string_value = "full_vehicle"
!
!---------------------------- Adams View Functions ----------------------------!
!
!
function create  &
   function_name = .SYMMETRY  &
   text_of_expression = "LOC_MIRROR(location, .__ACAR.ground.origo, .ACAR.variables.symmetry_plane)"  &
   argument_names = "location"  &
   type = location_orientation  &
   comments =   &
              "Compute mirrored location over the symmetry plane given 3x1 location vector"
!
!------------------------- Groups Owned By This Model -------------------------!
!
!
group create  &
   group_name = .__ACME_MULTI_POST_TESTRIG.kinematic_mode_active  &
   expr_active = 0
!
group create  &
   group_name = .__ACME_MULTI_POST_TESTRIG.kinematic_mode_inactive  &
   expr_active = 1
!
!---------------------- Set Adams View Object Variables -----------------------!
!
!
variable modify  &
   variable_name = .__ACME_MULTI_POST_TESTRIG.mtl_suspension_mount_front.dependents  &
   object_value = .__ACME_MULTI_POST_TESTRIG.mtl_fixed_1,  &
                  .__ACME_MULTI_POST_TESTRIG.cil_suspension_mount_front
!
variable modify  &
   variable_name = .__ACME_MULTI_POST_TESTRIG.cil_suspension_mount_front  &
   object_value = .__ACME_MULTI_POST_TESTRIG.ground.mtl_mount_j_1,  &
                  .__ACME_MULTI_POST_TESTRIG.mtl_suspension_mount_front,  &
                  .__ACME_MULTI_POST_TESTRIG.mtl_fixed_1
!
variable modify  &
   variable_name = .__ACME_MULTI_POST_TESTRIG.mtr_suspension_mount_front.dependents  &
   object_value = .__ACME_MULTI_POST_TESTRIG.mtr_fixed_1,  &
                  .__ACME_MULTI_POST_TESTRIG.cir_suspension_mount_front
!
variable modify  &
   variable_name = .__ACME_MULTI_POST_TESTRIG.cir_suspension_mount_front  &
   object_value = .__ACME_MULTI_POST_TESTRIG.ground.mtr_mount_j_1,  &
                  .__ACME_MULTI_POST_TESTRIG.mtr_suspension_mount_front,  &
                  .__ACME_MULTI_POST_TESTRIG.mtr_fixed_1
!
variable modify  &
   variable_name = .__ACME_MULTI_POST_TESTRIG.mtl_suspension_mount_rear.dependents  &
   object_value = .__ACME_MULTI_POST_TESTRIG.mtl_fixed_2,  &
                  .__ACME_MULTI_POST_TESTRIG.cil_suspension_mount_rear
!
variable modify  &
   variable_name = .__ACME_MULTI_POST_TESTRIG.cil_suspension_mount_rear  &
   object_value = .__ACME_MULTI_POST_TESTRIG.ground.mtl_mount_j_2,  &
                  .__ACME_MULTI_POST_TESTRIG.mtl_suspension_mount_rear,  &
                  .__ACME_MULTI_POST_TESTRIG.mtl_fixed_2
!
variable modify  &
   variable_name = .__ACME_MULTI_POST_TESTRIG.mtr_suspension_mount_rear.dependents  &
   object_value = .__ACME_MULTI_POST_TESTRIG.mtr_fixed_2,  &
                  .__ACME_MULTI_POST_TESTRIG.cir_suspension_mount_rear
!
variable modify  &
   variable_name = .__ACME_MULTI_POST_TESTRIG.cir_suspension_mount_rear  &
   object_value = .__ACME_MULTI_POST_TESTRIG.ground.mtr_mount_j_2,  &
                  .__ACME_MULTI_POST_TESTRIG.mtr_suspension_mount_rear,  &
                  .__ACME_MULTI_POST_TESTRIG.mtr_fixed_2
!
variable modify  &
   variable_name = .__ACME_MULTI_POST_TESTRIG.mtl_suspension_mount_rear2.dependents  &
   object_value = .__ACME_MULTI_POST_TESTRIG.mtl_fixed_3,  &
                  .__ACME_MULTI_POST_TESTRIG.cil_suspension_mount_rear2
!
variable modify  &
   variable_name = .__ACME_MULTI_POST_TESTRIG.cil_suspension_mount_rear2  &
   object_value = .__ACME_MULTI_POST_TESTRIG.ground.mtl_mount_j_3,  &
                  .__ACME_MULTI_POST_TESTRIG.mtl_suspension_mount_rear2,  &
                  .__ACME_MULTI_POST_TESTRIG.mtl_fixed_3
!
variable modify  &
   variable_name = .__ACME_MULTI_POST_TESTRIG.mtr_suspension_mount_rear2.dependents  &
   object_value = .__ACME_MULTI_POST_TESTRIG.mtr_fixed_3,  &
                  .__ACME_MULTI_POST_TESTRIG.cir_suspension_mount_rear2
!
variable modify  &
   variable_name = .__ACME_MULTI_POST_TESTRIG.cir_suspension_mount_rear2  &
   object_value = .__ACME_MULTI_POST_TESTRIG.ground.mtr_mount_j_3,  &
                  .__ACME_MULTI_POST_TESTRIG.mtr_suspension_mount_rear2,  &
                  .__ACME_MULTI_POST_TESTRIG.mtr_fixed_3
!
variable modify  &
   variable_name = .__ACME_MULTI_POST_TESTRIG.col_mount_post_pad_vertical_front  &
   object_value =   &
                  .__ACME_MULTI_POST_TESTRIG.gel_mount_post_pad_vertical_front
!
variable modify  &
   variable_name = .__ACME_MULTI_POST_TESTRIG.cor_mount_post_pad_vertical_front  &
   object_value =   &
                  .__ACME_MULTI_POST_TESTRIG.ger_mount_post_pad_vertical_front
!
variable modify  &
   variable_name = .__ACME_MULTI_POST_TESTRIG.col_mount_post_pad_vertical_rear  &
   object_value =   &
                  .__ACME_MULTI_POST_TESTRIG.gel_mount_post_pad_vertical_rear
!
variable modify  &
   variable_name = .__ACME_MULTI_POST_TESTRIG.cor_mount_post_pad_vertical_rear  &
   object_value =   &
                  .__ACME_MULTI_POST_TESTRIG.ger_mount_post_pad_vertical_rear
!
variable modify  &
   variable_name = .__ACME_MULTI_POST_TESTRIG.col_mount_post_pad_vertical_rear2  &
   object_value =   &
                  .__ACME_MULTI_POST_TESTRIG.gel_mount_post_pad_vertical_rear2
!
variable modify  &
   variable_name = .__ACME_MULTI_POST_TESTRIG.cor_mount_post_pad_vertical_rear2  &
   object_value =   &
                  .__ACME_MULTI_POST_TESTRIG.ger_mount_post_pad_vertical_rear2
!
variable modify  &
   variable_name = .__ACME_MULTI_POST_TESTRIG.mts_body_subsystem_deactive.dependents  &
   object_value = .__ACME_MULTI_POST_TESTRIG.mts_fixed_1,  &
                  .__ACME_MULTI_POST_TESTRIG.cis_body_subsystem_deactive
!
variable modify  &
   variable_name = .__ACME_MULTI_POST_TESTRIG.cis_body_subsystem_deactive  &
   object_value = .__ACME_MULTI_POST_TESTRIG.ground.mts_mount_j_1,  &
                  .__ACME_MULTI_POST_TESTRIG.mts_body_subsystem_deactive,  &
                  .__ACME_MULTI_POST_TESTRIG.mts_fixed_1
!
!--------------------------- Add Objects To Groups ----------------------------!
!
!
group modify  &
   group_name = .__ACME_MULTI_POST_TESTRIG.kinematic_mode_active
!
group modify  &
   group_name = .__ACME_MULTI_POST_TESTRIG.kinematic_mode_inactive
!
!---------------------------- Function definitions ----------------------------!
!
!
constraint modify motion_generator  &
   motion_name = .__ACME_MULTI_POST_TESTRIG._cv_motion  &
   function = "0"
!
data_element modify variable  &
   variable_name = .__ACME_MULTI_POST_TESTRIG._cv_solver_variable  &
   function = "0"
!
part modify equation differential_equation  &
   differential_equation_name = .__ACME_MULTI_POST_TESTRIG._cv_diff  &
   function = "0"
!
!-------------------------- Adams View UDE Instance ---------------------------!
!
!
ude modify instance  &
   instance_name = .__ACME_MULTI_POST_TESTRIG.jms_post_pad_vertical_lf
!
!-------------------------- Adams View UDE Instance ---------------------------!
!
!
ude modify instance  &
   instance_name = .__ACME_MULTI_POST_TESTRIG.jms_post_pad_vertical_rf
!
!-------------------------- Adams View UDE Instance ---------------------------!
!
!
ude modify instance  &
   instance_name = .__ACME_MULTI_POST_TESTRIG.jms_post_pad_vertical_lr
!
!-------------------------- Adams View UDE Instance ---------------------------!
!
!
ude modify instance  &
   instance_name = .__ACME_MULTI_POST_TESTRIG.jms_post_pad_vertical_rr
!
!-------------------------- Adams View UDE Instance ---------------------------!
!
!
ude modify instance  &
   instance_name = .__ACME_MULTI_POST_TESTRIG.jms_post_pad_vertical_lr2
!
!-------------------------- Adams View UDE Instance ---------------------------!
!
!
ude modify instance  &
   instance_name = .__ACME_MULTI_POST_TESTRIG.jms_post_pad_vertical_rr2
!
!--------------------------- Expression definitions ---------------------------!
!
!
defaults coordinate_system  &
   default_coordinate_system = ground
!
marker modify  &
   marker_name = .__ACME_MULTI_POST_TESTRIG.ground.cfl_wheel_center_front  &
   location =   &
      (.__ACME_MULTI_POST_TESTRIG.cil_wheel_center_front)  &
   orientation =   &
      (ORI_RELATIVE_TO({0.0, 0.0, 0.0}degrees, .__ACME_MULTI_POST_TESTRIG.ground.origo))
!
marker modify  &
   marker_name = .__ACME_MULTI_POST_TESTRIG.ground.cfr_wheel_center_front  &
   location =   &
      (.__ACME_MULTI_POST_TESTRIG.cir_wheel_center_front)  &
   orientation =   &
      (ORI_RELATIVE_TO({0.0, 0.0, 0.0}degrees, .__ACME_MULTI_POST_TESTRIG.ground.origo))
!
marker modify  &
   marker_name = .__ACME_MULTI_POST_TESTRIG.ground.cfl_wheel_center_rear  &
   location =   &
      (.__ACME_MULTI_POST_TESTRIG.cil_wheel_center_rear)  &
   orientation =   &
      (ORI_RELATIVE_TO({0.0, 0.0, 0.0}degrees, .__ACME_MULTI_POST_TESTRIG.ground.origo))
!
marker modify  &
   marker_name = .__ACME_MULTI_POST_TESTRIG.ground.cfr_wheel_center_rear  &
   location =   &
      (.__ACME_MULTI_POST_TESTRIG.cir_wheel_center_rear)  &
   orientation =   &
      (ORI_RELATIVE_TO({0.0, 0.0, 0.0}degrees, .__ACME_MULTI_POST_TESTRIG.ground.origo))
!
marker modify  &
   marker_name = .__ACME_MULTI_POST_TESTRIG.ground.cfl_wheel_center_rear2  &
   location =   &
      (.__ACME_MULTI_POST_TESTRIG.cil_wheel_center_rear2)  &
   orientation =   &
      (ORI_RELATIVE_TO({0.0, 0.0, 0.0}degrees, .__ACME_MULTI_POST_TESTRIG.ground.origo))
!
marker modify  &
   marker_name = .__ACME_MULTI_POST_TESTRIG.ground.cfr_wheel_center_rear2  &
   location =   &
      (.__ACME_MULTI_POST_TESTRIG.cir_wheel_center_rear2)  &
   orientation =   &
      (ORI_RELATIVE_TO({0.0, 0.0, 0.0}degrees, .__ACME_MULTI_POST_TESTRIG.ground.origo))
!
marker modify  &
   marker_name = .__ACME_MULTI_POST_TESTRIG.ground.cfl_mount_post_pad_vertical_front  &
   location =   &
      (.__ACME_MULTI_POST_TESTRIG.cil_wheel_center_front[1]),  &
      (.__ACME_MULTI_POST_TESTRIG.cil_wheel_center_front[2]),  &
      (.__ACME_MULTI_POST_TESTRIG.ground.std_tire_ref.loc[3])  &
   orientation =   &
      (ORI_RELATIVE_TO({0.0, 0.0, 0.0}degrees, .__ACME_MULTI_POST_TESTRIG.ground.origo))
!
marker modify  &
   marker_name = .__ACME_MULTI_POST_TESTRIG.ground.cfr_mount_post_pad_vertical_front  &
   location =   &
      (.__ACME_MULTI_POST_TESTRIG.cir_wheel_center_front[1]),  &
      (.__ACME_MULTI_POST_TESTRIG.cir_wheel_center_front[2]),  &
      (.__ACME_MULTI_POST_TESTRIG.ground.std_tire_ref.loc[3])  &
   orientation =   &
      (ORI_RELATIVE_TO({0.0, 0.0, 0.0}degrees, .__ACME_MULTI_POST_TESTRIG.ground.origo))
!
marker modify  &
   marker_name = .__ACME_MULTI_POST_TESTRIG.ground.cfl_mount_post_pad_vertical_rear  &
   location =   &
      (.__ACME_MULTI_POST_TESTRIG.cil_wheel_center_rear[1]),  &
      (.__ACME_MULTI_POST_TESTRIG.cil_wheel_center_rear[2]),  &
      (.__ACME_MULTI_POST_TESTRIG.ground.std_tire_ref.loc[3])  &
   orientation =   &
      (ORI_RELATIVE_TO({0.0, 0.0, 0.0}degrees, .__ACME_MULTI_POST_TESTRIG.ground.origo))
!
marker modify  &
   marker_name = .__ACME_MULTI_POST_TESTRIG.ground.cfr_mount_post_pad_vertical_rear  &
   location =   &
      (.__ACME_MULTI_POST_TESTRIG.cir_wheel_center_rear[1]),  &
      (.__ACME_MULTI_POST_TESTRIG.cir_wheel_center_rear[2]),  &
      (.__ACME_MULTI_POST_TESTRIG.ground.std_tire_ref.loc[3])  &
   orientation =   &
      (ORI_RELATIVE_TO({0.0, 0.0, 0.0}degrees, .__ACME_MULTI_POST_TESTRIG.ground.origo))
!
marker modify  &
   marker_name = .__ACME_MULTI_POST_TESTRIG.ground.cfl_mount_post_pad_vertical_rear2  &
   location =   &
      (.__ACME_MULTI_POST_TESTRIG.cil_wheel_center_rear2[1]),  &
      (.__ACME_MULTI_POST_TESTRIG.cil_wheel_center_rear2[2]),  &
      (.__ACME_MULTI_POST_TESTRIG.ground.std_tire_ref.loc[3])  &
   orientation =   &
      (ORI_RELATIVE_TO({0.0, 0.0, 0.0}degrees, .__ACME_MULTI_POST_TESTRIG.ground.origo))
!
marker modify  &
   marker_name = .__ACME_MULTI_POST_TESTRIG.ground.cfr_mount_post_pad_vertical_rear2  &
   location =   &
      (.__ACME_MULTI_POST_TESTRIG.cir_wheel_center_rear2[1]),  &
      (.__ACME_MULTI_POST_TESTRIG.cir_wheel_center_rear2[2]),  &
      (.__ACME_MULTI_POST_TESTRIG.ground.std_tire_ref.loc[3])  &
   orientation =   &
      (ORI_RELATIVE_TO({0.0, 0.0, 0.0}degrees, .__ACME_MULTI_POST_TESTRIG.ground.origo))
!
marker modify  &
   marker_name = .__ACME_MULTI_POST_TESTRIG.ground.base_cm_fl  &
   location =   &
      (LOC_RELATIVE_TO({0, 0, -2000.0}, .__ACME_MULTI_POST_TESTRIG.ground.cfl_mount_post_base_vertical_front))  &
   orientation =   &
      (ORI_RELATIVE_TO({0, 0, 0}, .__ACME_MULTI_POST_TESTRIG.ground.cfl_mount_post_base_vertical_front))
!
marker modify  &
   marker_name = .__ACME_MULTI_POST_TESTRIG.ground.base_cm_fr  &
   location =   &
      (LOC_RELATIVE_TO({0, 0, -2000.0}, .__ACME_MULTI_POST_TESTRIG.ground.cfr_mount_post_base_vertical_front))  &
   orientation =   &
      (ORI_RELATIVE_TO({0, 0, 0}, .__ACME_MULTI_POST_TESTRIG.ground.cfr_mount_post_base_vertical_front))
!
marker modify  &
   marker_name = .__ACME_MULTI_POST_TESTRIG.ground.base_cm_rl  &
   location =   &
      (LOC_RELATIVE_TO({0, 0, -2000.0}, .__ACME_MULTI_POST_TESTRIG.ground.cfl_mount_post_base_vertical_rear))  &
   orientation =   &
      (ORI_RELATIVE_TO({0, 0, 0}, .__ACME_MULTI_POST_TESTRIG.ground.cfl_mount_post_base_vertical_rear))
!
marker modify  &
   marker_name = .__ACME_MULTI_POST_TESTRIG.ground.base_cm_rr  &
   location =   &
      (LOC_RELATIVE_TO({0, 0, -2000.0}, .__ACME_MULTI_POST_TESTRIG.ground.cfr_mount_post_base_vertical_rear))  &
   orientation =   &
      (ORI_RELATIVE_TO({0, 0, 0}, .__ACME_MULTI_POST_TESTRIG.ground.cfr_mount_post_base_vertical_rear))
!
marker modify  &
   marker_name = .__ACME_MULTI_POST_TESTRIG.ground.base_cm_r2l  &
   location =   &
      (LOC_RELATIVE_TO({0, 0, -2000.0}, .__ACME_MULTI_POST_TESTRIG.ground.cfl_mount_post_base_vertical_rear2))  &
   orientation =   &
      (ORI_RELATIVE_TO({0, 0, 0}, .__ACME_MULTI_POST_TESTRIG.ground.cfl_mount_post_base_vertical_rear2))
!
marker modify  &
   marker_name = .__ACME_MULTI_POST_TESTRIG.ground.base_cm_r2r  &
   location =   &
      (LOC_RELATIVE_TO({0, 0, -2000.0}, .__ACME_MULTI_POST_TESTRIG.ground.cfr_mount_post_base_vertical_rear2))  &
   orientation =   &
      (ORI_RELATIVE_TO({0, 0, 0}, .__ACME_MULTI_POST_TESTRIG.ground.cfr_mount_post_base_vertical_rear2))
!
marker modify  &
   marker_name = .__ACME_MULTI_POST_TESTRIG.ground.jxs_joint_j_1  &
   location =   &
      (LOC_RELATIVE_TO({0.0, 0.0, -400.0}mm, .__ACME_MULTI_POST_TESTRIG.ground.cfl_mount_post_pad_vertical_front))  &
   orientation =   &
      (ORI_RELATIVE_TO({0.0, 0.0, 0.0}degrees, .__ACME_MULTI_POST_TESTRIG.ground.cfl_mount_post_pad_vertical_front))
!
marker modify  &
   marker_name = .__ACME_MULTI_POST_TESTRIG.ground.jxs_joint_j_2  &
   location =   &
      (LOC_RELATIVE_TO({0.0, 0.0, -400.0}mm, .__ACME_MULTI_POST_TESTRIG.ground.cfr_mount_post_pad_vertical_front))  &
   orientation =   &
      (ORI_RELATIVE_TO({0.0, 0.0, 0.0}degrees, .__ACME_MULTI_POST_TESTRIG.ground.cfr_mount_post_pad_vertical_front))
!
marker modify  &
   marker_name = .__ACME_MULTI_POST_TESTRIG.ground.jxs_joint_j_3  &
   location =   &
      (LOC_RELATIVE_TO({0.0, 0.0, -400.0}mm, .__ACME_MULTI_POST_TESTRIG.ground.cfl_mount_post_pad_vertical_rear))  &
   orientation =   &
      (ORI_RELATIVE_TO({0.0, 0.0, 0.0}degrees, .__ACME_MULTI_POST_TESTRIG.ground.cfl_mount_post_pad_vertical_rear))
!
marker modify  &
   marker_name = .__ACME_MULTI_POST_TESTRIG.ground.jxs_joint_j_4  &
   location =   &
      (LOC_RELATIVE_TO({0.0, 0.0, -400.0}mm, .__ACME_MULTI_POST_TESTRIG.ground.cfl_mount_post_pad_vertical_rear2))  &
   orientation =   &
      (ORI_RELATIVE_TO({0.0, 0.0, 0.0}degrees, .__ACME_MULTI_POST_TESTRIG.ground.cfl_mount_post_pad_vertical_rear2))
!
marker modify  &
   marker_name = .__ACME_MULTI_POST_TESTRIG.ground.jxs_joint_j_5  &
   location =   &
      (LOC_RELATIVE_TO({0.0, 0.0, -400.0}mm, .__ACME_MULTI_POST_TESTRIG.ground.cfr_mount_post_pad_vertical_rear))  &
   orientation =   &
      (ORI_RELATIVE_TO({0.0, 0.0, 0.0}degrees, .__ACME_MULTI_POST_TESTRIG.ground.cfr_mount_post_pad_vertical_rear))
!
marker modify  &
   marker_name = .__ACME_MULTI_POST_TESTRIG.ground.jxs_joint_j_6  &
   location =   &
      (LOC_RELATIVE_TO({0.0, 0.0, -400.0}mm, .__ACME_MULTI_POST_TESTRIG.ground.cfr_mount_post_pad_vertical_rear2))  &
   orientation =   &
      (ORI_RELATIVE_TO({0.0, 0.0, 0.0}degrees, .__ACME_MULTI_POST_TESTRIG.ground.cfr_mount_post_pad_vertical_rear2))
!
marker modify  &
   marker_name = .__ACME_MULTI_POST_TESTRIG.ground.mtl_mount_j_1  &
   location =   &
      (LOC_RELATIVE_TO({0, 0, 0}, .__ACME_MULTI_POST_TESTRIG.mtl_suspension_mount_front))  &
   orientation =   &
      (ORI_RELATIVE_TO({0, 0, 0}, .__ACME_MULTI_POST_TESTRIG.mtl_suspension_mount_front))
!
marker modify  &
   marker_name = .__ACME_MULTI_POST_TESTRIG.ground.mtr_mount_j_1  &
   location =   &
      (LOC_RELATIVE_TO({0, 0, 0}, .__ACME_MULTI_POST_TESTRIG.mtr_suspension_mount_front))  &
   orientation =   &
      (ORI_RELATIVE_TO({0, 0, 0}, .__ACME_MULTI_POST_TESTRIG.mtr_suspension_mount_front))
!
marker modify  &
   marker_name = .__ACME_MULTI_POST_TESTRIG.ground.mtl_mount_j_2  &
   location =   &
      (LOC_RELATIVE_TO({0, 0, 0}, .__ACME_MULTI_POST_TESTRIG.mtl_suspension_mount_rear))  &
   orientation =   &
      (ORI_RELATIVE_TO({0, 0, 0}, .__ACME_MULTI_POST_TESTRIG.mtl_suspension_mount_rear))
!
marker modify  &
   marker_name = .__ACME_MULTI_POST_TESTRIG.ground.mtr_mount_j_2  &
   location =   &
      (LOC_RELATIVE_TO({0, 0, 0}, .__ACME_MULTI_POST_TESTRIG.mtr_suspension_mount_rear))  &
   orientation =   &
      (ORI_RELATIVE_TO({0, 0, 0}, .__ACME_MULTI_POST_TESTRIG.mtr_suspension_mount_rear))
!
marker modify  &
   marker_name = .__ACME_MULTI_POST_TESTRIG.ground.mtl_mount_j_3  &
   location =   &
      (LOC_RELATIVE_TO({0, 0, 0}, .__ACME_MULTI_POST_TESTRIG.mtl_suspension_mount_rear2))  &
   orientation =   &
      (ORI_RELATIVE_TO({0, 0, 0}, .__ACME_MULTI_POST_TESTRIG.mtl_suspension_mount_rear2))
!
marker modify  &
   marker_name = .__ACME_MULTI_POST_TESTRIG.ground.mtr_mount_j_3  &
   location =   &
      (LOC_RELATIVE_TO({0, 0, 0}, .__ACME_MULTI_POST_TESTRIG.mtr_suspension_mount_rear2))  &
   orientation =   &
      (ORI_RELATIVE_TO({0, 0, 0}, .__ACME_MULTI_POST_TESTRIG.mtr_suspension_mount_rear2))
!
marker modify  &
   marker_name = .__ACME_MULTI_POST_TESTRIG.ground.cfs_body_subsystem  &
   location =   &
      (.__ACME_MULTI_POST_TESTRIG.cis_body_subsystem_location)  &
   orientation =   &
      (ORI_RELATIVE_TO({0.0, 0.0, 0.0}degrees, .__ACME_MULTI_POST_TESTRIG.ground.origo))
!
marker modify  &
   marker_name = .__ACME_MULTI_POST_TESTRIG.ground.mts_mount_j_1  &
   location =   &
      (LOC_RELATIVE_TO({0, 0, 0}, .__ACME_MULTI_POST_TESTRIG.mts_body_subsystem_deactive))  &
   orientation =   &
      (ORI_RELATIVE_TO({0, 0, 0}, .__ACME_MULTI_POST_TESTRIG.mts_body_subsystem_deactive))
!
marker modify  &
   marker_name = .__ACME_MULTI_POST_TESTRIG.ground.jxs_joint_j_7  &
   location =   &
      (LOC_RELATIVE_TO({0.0, 0.0, 0.0}mm, .__ACME_MULTI_POST_TESTRIG.ground.cfs_body_subsystem))  &
   orientation =   &
      (ORI_RELATIVE_TO({90d, 90d, 0}, .__ACME_MULTI_POST_TESTRIG.ground.origo))
!
marker modify  &
   marker_name = .__ACME_MULTI_POST_TESTRIG.ground.jxs_joint_j_8  &
   location =   &
      (LOC_RELATIVE_TO({0.0, 0.0, 0.0}mm, .__ACME_MULTI_POST_TESTRIG.ground.cfs_body_subsystem))  &
   orientation =   &
      (ORI_RELATIVE_TO({0.0, 0.0, 0.0}degrees, .__ACME_MULTI_POST_TESTRIG.ground.origo))
!
marker modify  &
   marker_name = .__ACME_MULTI_POST_TESTRIG.ground.cfl_mount_post_base_vertical_front  &
   location =   &
      (LOC_RELATIVE_TO({0.0, 0.0, -400.0}mm, .__ACME_MULTI_POST_TESTRIG.ground.cfl_mount_post_pad_vertical_front))  &
   orientation =   &
      (ORI_RELATIVE_TO({0.0, 0.0, 0.0}degrees, .__ACME_MULTI_POST_TESTRIG.ground.origo))
!
marker modify  &
   marker_name = .__ACME_MULTI_POST_TESTRIG.ground.cfr_mount_post_base_vertical_front  &
   location =   &
      (LOC_RELATIVE_TO({0.0, 0.0, -400.0}mm, .__ACME_MULTI_POST_TESTRIG.ground.cfr_mount_post_pad_vertical_front))  &
   orientation =   &
      (ORI_RELATIVE_TO({0.0, 0.0, 0.0}degrees, .__ACME_MULTI_POST_TESTRIG.ground.origo))
!
marker modify  &
   marker_name = .__ACME_MULTI_POST_TESTRIG.ground.cfl_mount_post_base_vertical_rear  &
   location =   &
      (LOC_RELATIVE_TO({0.0, 0.0, -400.0}mm, .__ACME_MULTI_POST_TESTRIG.ground.cfl_mount_post_pad_vertical_rear))  &
   orientation =   &
      (ORI_RELATIVE_TO({0.0, 0.0, 0.0}degrees, .__ACME_MULTI_POST_TESTRIG.ground.origo))
!
marker modify  &
   marker_name = .__ACME_MULTI_POST_TESTRIG.ground.cfr_mount_post_base_vertical_rear  &
   location =   &
      (LOC_RELATIVE_TO({0.0, 0.0, -400.0}mm, .__ACME_MULTI_POST_TESTRIG.ground.cfr_mount_post_pad_vertical_rear))  &
   orientation =   &
      (ORI_RELATIVE_TO({0.0, 0.0, 0.0}degrees, .__ACME_MULTI_POST_TESTRIG.ground.origo))
!
marker modify  &
   marker_name = .__ACME_MULTI_POST_TESTRIG.ground.cfl_mount_post_base_vertical_rear2  &
   location =   &
      (LOC_RELATIVE_TO({0.0, 0.0, -400.0}mm, .__ACME_MULTI_POST_TESTRIG.ground.cfl_mount_post_pad_vertical_rear2))  &
   orientation =   &
      (ORI_RELATIVE_TO({0.0, 0.0, 0.0}degrees, .__ACME_MULTI_POST_TESTRIG.ground.origo))
!
marker modify  &
   marker_name = .__ACME_MULTI_POST_TESTRIG.ground.cfr_mount_post_base_vertical_rear2  &
   location =   &
      (LOC_RELATIVE_TO({0.0, 0.0, -400.0}mm, .__ACME_MULTI_POST_TESTRIG.ground.cfr_mount_post_pad_vertical_rear2))  &
   orientation =   &
      (ORI_RELATIVE_TO({0.0, 0.0, 0.0}degrees, .__ACME_MULTI_POST_TESTRIG.ground.origo))
!
data_element modify string  &
   string_name = .__ACME_MULTI_POST_TESTRIG.minor_role_string  &
   string = (.__ACME_MULTI_POST_TESTRIG.minor_role)
!
group modify  &
   group_name = .__ACME_MULTI_POST_TESTRIG.kinematic_mode_active  &
   expr_active = ((.__ACME_MULTI_POST_TESTRIG.phs_kinematic_flag || .__ACME_MULTI_POST_TESTRIG.model_class == "template" ? 1 : 0) && DB_ACTIVE(.__ACME_MULTI_POST_TESTRIG))
!
group modify  &
   group_name = .__ACME_MULTI_POST_TESTRIG.kinematic_mode_inactive  &
   expr_active = (( ! .__ACME_MULTI_POST_TESTRIG.phs_kinematic_flag || .__ACME_MULTI_POST_TESTRIG.model_class == "template" ? 1 : 0) && DB_ACTIVE(.__ACME_MULTI_POST_TESTRIG))
!
marker modify  &
   marker_name = .__ACME_MULTI_POST_TESTRIG.gel_mount_post_pad_vertical_front.inertia_frame  &
   location =   &
      (LOC_RELATIVE_TO({0, 0, 0}, .__ACME_MULTI_POST_TESTRIG.gel_mount_post_pad_vertical_front.cm))  &
   orientation =   &
      (ORI_RELATIVE_TO({0, 0, 0}, .__ACME_MULTI_POST_TESTRIG.gel_mount_post_pad_vertical_front))  &
   relative_to = .__ACME_MULTI_POST_TESTRIG.gel_mount_post_pad_vertical_front
!
defaults coordinate_system  &
   default_coordinate_system = .__ACME_MULTI_POST_TESTRIG.ground
!
marker modify  &
   marker_name = .__ACME_MULTI_POST_TESTRIG.gel_mount_post_pad_vertical_front.gracyl_1  &
   location =   &
      (LOC_RELATIVE_TO({0, 0, -50.0}mm, .__ACME_MULTI_POST_TESTRIG.ground.cfl_mount_post_pad_vertical_front))  &
   orientation =   &
      (ORI_RELATIVE_TO({0, 0, 0}, .__ACME_MULTI_POST_TESTRIG.ground.cfl_mount_post_pad_vertical_front))  &
   relative_to = .__ACME_MULTI_POST_TESTRIG.gel_mount_post_pad_vertical_front
!
defaults coordinate_system  &
   default_coordinate_system = .__ACME_MULTI_POST_TESTRIG.ground
!
geometry modify shape cylinder  &
   cylinder_name = .__ACME_MULTI_POST_TESTRIG.gel_mount_post_pad_vertical_front.gracyl_pad  &
   length = (0.0 + 50.0)
!
marker modify  &
   marker_name = .__ACME_MULTI_POST_TESTRIG.gel_mount_post_pad_vertical_front.gracyl_7  &
   location =   &
      (LOC_RELATIVE_TO({0, 0, -1600.0}mm, .__ACME_MULTI_POST_TESTRIG.ground.cfl_mount_post_pad_vertical_front))  &
   orientation =   &
      (ORI_RELATIVE_TO({0, 0, 0}, .__ACME_MULTI_POST_TESTRIG.ground.cfl_mount_post_pad_vertical_front))  &
   relative_to = .__ACME_MULTI_POST_TESTRIG.gel_mount_post_pad_vertical_front
!
defaults coordinate_system  &
   default_coordinate_system = .__ACME_MULTI_POST_TESTRIG.ground
!
geometry modify shape cylinder  &
   cylinder_name = .__ACME_MULTI_POST_TESTRIG.gel_mount_post_pad_vertical_front.gracyl_post  &
   length = (0.0 + 1600.0)
!
marker modify  &
   marker_name = .__ACME_MULTI_POST_TESTRIG.gel_mount_post_pad_vertical_front.jxs_joint_i_1  &
   location =   &
      (LOC_RELATIVE_TO({0, 0, 0}, .__ACME_MULTI_POST_TESTRIG.ground.jxs_joint_j_1))  &
   orientation =   &
      (ORI_RELATIVE_TO({0, 0, 0}, .__ACME_MULTI_POST_TESTRIG.ground.jxs_joint_j_1))  &
   relative_to = .__ACME_MULTI_POST_TESTRIG.gel_mount_post_pad_vertical_front
!
defaults coordinate_system  &
   default_coordinate_system = .__ACME_MULTI_POST_TESTRIG.ground
!
marker modify  &
   marker_name = .__ACME_MULTI_POST_TESTRIG.gel_mount_post_pad_vertical_front.jxl_joint_j_1  &
   location =   &
      (LOC_RELATIVE_TO({0.0, 0.0, 0.0}mm, .__ACME_MULTI_POST_TESTRIG.ground.cfl_wheel_center_front))  &
   orientation =   &
      (ORI_RELATIVE_TO({0.0, 0.0, 0.0}degrees, .__ACME_MULTI_POST_TESTRIG.ground.cfl_wheel_center_front))  &
   relative_to = .__ACME_MULTI_POST_TESTRIG.gel_mount_post_pad_vertical_front
!
defaults coordinate_system  &
   default_coordinate_system = .__ACME_MULTI_POST_TESTRIG.ground
!
part modify rigid_body name_and_position  &
   part_name = .__ACME_MULTI_POST_TESTRIG.gel_mount_post_pad_vertical_front  &
   location =   &
      (LOC_RELATIVE_TO({0.0, 0.0, 0.0}mm, .__ACME_MULTI_POST_TESTRIG.ground.cfl_mount_post_pad_vertical_front))
!
marker modify  &
   marker_name = .__ACME_MULTI_POST_TESTRIG.ger_mount_post_pad_vertical_front.inertia_frame  &
   location =   &
      (LOC_RELATIVE_TO({0, 0, 0}, .__ACME_MULTI_POST_TESTRIG.ger_mount_post_pad_vertical_front.cm))  &
   orientation =   &
      (ORI_RELATIVE_TO({0, 0, 0}, .__ACME_MULTI_POST_TESTRIG.ger_mount_post_pad_vertical_front))  &
   relative_to = .__ACME_MULTI_POST_TESTRIG.ger_mount_post_pad_vertical_front
!
defaults coordinate_system  &
   default_coordinate_system = .__ACME_MULTI_POST_TESTRIG.ground
!
marker modify  &
   marker_name = .__ACME_MULTI_POST_TESTRIG.ger_mount_post_pad_vertical_front.gracyl_2  &
   location =   &
      (LOC_RELATIVE_TO({0, 0, -50.0}mm, .__ACME_MULTI_POST_TESTRIG.ground.cfr_mount_post_pad_vertical_front))  &
   orientation =   &
      (ORI_RELATIVE_TO({0, 0, 0}, .__ACME_MULTI_POST_TESTRIG.ground.cfr_mount_post_pad_vertical_front))  &
   relative_to = .__ACME_MULTI_POST_TESTRIG.ger_mount_post_pad_vertical_front
!
defaults coordinate_system  &
   default_coordinate_system = .__ACME_MULTI_POST_TESTRIG.ground
!
geometry modify shape cylinder  &
   cylinder_name = .__ACME_MULTI_POST_TESTRIG.ger_mount_post_pad_vertical_front.gracyl_pad  &
   length = (0.0 + 50.0)
!
marker modify  &
   marker_name = .__ACME_MULTI_POST_TESTRIG.ger_mount_post_pad_vertical_front.gracyl_8  &
   location =   &
      (LOC_RELATIVE_TO({0, 0, -1600.0}mm, .__ACME_MULTI_POST_TESTRIG.ground.cfr_mount_post_pad_vertical_front))  &
   orientation =   &
      (ORI_RELATIVE_TO({0, 0, 0}, .__ACME_MULTI_POST_TESTRIG.ground.cfr_mount_post_pad_vertical_front))  &
   relative_to = .__ACME_MULTI_POST_TESTRIG.ger_mount_post_pad_vertical_front
!
defaults coordinate_system  &
   default_coordinate_system = .__ACME_MULTI_POST_TESTRIG.ground
!
geometry modify shape cylinder  &
   cylinder_name = .__ACME_MULTI_POST_TESTRIG.ger_mount_post_pad_vertical_front.gracyl_post  &
   length = (0.0 + 1600.0)
!
marker modify  &
   marker_name = .__ACME_MULTI_POST_TESTRIG.ger_mount_post_pad_vertical_front.jxs_joint_i_2  &
   location =   &
      (LOC_RELATIVE_TO({0, 0, 0}, .__ACME_MULTI_POST_TESTRIG.ground.jxs_joint_j_2))  &
   orientation =   &
      (ORI_RELATIVE_TO({0, 0, 0}, .__ACME_MULTI_POST_TESTRIG.ground.jxs_joint_j_2))  &
   relative_to = .__ACME_MULTI_POST_TESTRIG.ger_mount_post_pad_vertical_front
!
defaults coordinate_system  &
   default_coordinate_system = .__ACME_MULTI_POST_TESTRIG.ground
!
marker modify  &
   marker_name = .__ACME_MULTI_POST_TESTRIG.ger_mount_post_pad_vertical_front.jxr_joint_j_1  &
   location =   &
      (LOC_RELATIVE_TO({0.0, 0.0, 0.0}mm, .__ACME_MULTI_POST_TESTRIG.ground.cfr_wheel_center_front))  &
   orientation =   &
      (ORI_RELATIVE_TO({0.0, 0.0, 0.0}degrees, .__ACME_MULTI_POST_TESTRIG.ground.cfr_wheel_center_front))  &
   relative_to = .__ACME_MULTI_POST_TESTRIG.ger_mount_post_pad_vertical_front
!
defaults coordinate_system  &
   default_coordinate_system = .__ACME_MULTI_POST_TESTRIG.ground
!
part modify rigid_body name_and_position  &
   part_name = .__ACME_MULTI_POST_TESTRIG.ger_mount_post_pad_vertical_front  &
   location =   &
      (LOC_RELATIVE_TO({0.0, 0.0, 0.0}mm, .__ACME_MULTI_POST_TESTRIG.ground.cfr_mount_post_pad_vertical_front))
!
marker modify  &
   marker_name = .__ACME_MULTI_POST_TESTRIG.gel_mount_post_pad_vertical_rear.inertia_frame  &
   location =   &
      (LOC_RELATIVE_TO({0, 0, 0}, .__ACME_MULTI_POST_TESTRIG.gel_mount_post_pad_vertical_rear.cm))  &
   orientation =   &
      (ORI_RELATIVE_TO({0, 0, 0}, .__ACME_MULTI_POST_TESTRIG.gel_mount_post_pad_vertical_rear))  &
   relative_to = .__ACME_MULTI_POST_TESTRIG.gel_mount_post_pad_vertical_rear
!
defaults coordinate_system  &
   default_coordinate_system = .__ACME_MULTI_POST_TESTRIG.ground
!
marker modify  &
   marker_name = .__ACME_MULTI_POST_TESTRIG.gel_mount_post_pad_vertical_rear.gracyl_3  &
   location =   &
      (LOC_RELATIVE_TO({0, 0, -50.0}mm, .__ACME_MULTI_POST_TESTRIG.ground.cfl_mount_post_pad_vertical_rear))  &
   orientation =   &
      (ORI_RELATIVE_TO({0, 0, 0}, .__ACME_MULTI_POST_TESTRIG.ground.cfl_mount_post_pad_vertical_rear))  &
   relative_to = .__ACME_MULTI_POST_TESTRIG.gel_mount_post_pad_vertical_rear
!
defaults coordinate_system  &
   default_coordinate_system = .__ACME_MULTI_POST_TESTRIG.ground
!
geometry modify shape cylinder  &
   cylinder_name = .__ACME_MULTI_POST_TESTRIG.gel_mount_post_pad_vertical_rear.gracyl_pad  &
   length = (0.0 + 50.0)
!
marker modify  &
   marker_name = .__ACME_MULTI_POST_TESTRIG.gel_mount_post_pad_vertical_rear.gracyl_9  &
   location =   &
      (LOC_RELATIVE_TO({0, 0, -1600.0}mm, .__ACME_MULTI_POST_TESTRIG.ground.cfl_mount_post_pad_vertical_rear))  &
   orientation =   &
      (ORI_RELATIVE_TO({0, 0, 0}, .__ACME_MULTI_POST_TESTRIG.ground.cfl_mount_post_pad_vertical_rear))  &
   relative_to = .__ACME_MULTI_POST_TESTRIG.gel_mount_post_pad_vertical_rear
!
defaults coordinate_system  &
   default_coordinate_system = .__ACME_MULTI_POST_TESTRIG.ground
!
geometry modify shape cylinder  &
   cylinder_name = .__ACME_MULTI_POST_TESTRIG.gel_mount_post_pad_vertical_rear.gracyl_post  &
   length = (0.0 + 1600.0)
!
marker modify  &
   marker_name = .__ACME_MULTI_POST_TESTRIG.gel_mount_post_pad_vertical_rear.jxs_joint_i_3  &
   location =   &
      (LOC_RELATIVE_TO({0, 0, 0}, .__ACME_MULTI_POST_TESTRIG.ground.jxs_joint_j_3))  &
   orientation =   &
      (ORI_RELATIVE_TO({0, 0, 0}, .__ACME_MULTI_POST_TESTRIG.ground.jxs_joint_j_3))  &
   relative_to = .__ACME_MULTI_POST_TESTRIG.gel_mount_post_pad_vertical_rear
!
defaults coordinate_system  &
   default_coordinate_system = .__ACME_MULTI_POST_TESTRIG.ground
!
marker modify  &
   marker_name = .__ACME_MULTI_POST_TESTRIG.gel_mount_post_pad_vertical_rear.jxl_joint_j_2  &
   location =   &
      (LOC_RELATIVE_TO({0.0, 0.0, 0.0}mm, .__ACME_MULTI_POST_TESTRIG.ground.cfl_wheel_center_rear))  &
   orientation =   &
      (ORI_RELATIVE_TO({0.0, 0.0, 0.0}degrees, .__ACME_MULTI_POST_TESTRIG.ground.cfl_wheel_center_rear))  &
   relative_to = .__ACME_MULTI_POST_TESTRIG.gel_mount_post_pad_vertical_rear
!
defaults coordinate_system  &
   default_coordinate_system = .__ACME_MULTI_POST_TESTRIG.ground
!
part modify rigid_body name_and_position  &
   part_name = .__ACME_MULTI_POST_TESTRIG.gel_mount_post_pad_vertical_rear  &
   location =   &
      (LOC_RELATIVE_TO({0.0, 0.0, 0.0}mm, .__ACME_MULTI_POST_TESTRIG.ground.cfl_mount_post_pad_vertical_rear))
!
marker modify  &
   marker_name = .__ACME_MULTI_POST_TESTRIG.ger_mount_post_pad_vertical_rear.inertia_frame  &
   location =   &
      (LOC_RELATIVE_TO({0, 0, 0}, .__ACME_MULTI_POST_TESTRIG.ger_mount_post_pad_vertical_rear.cm))  &
   orientation =   &
      (ORI_RELATIVE_TO({0, 0, 0}, .__ACME_MULTI_POST_TESTRIG.ger_mount_post_pad_vertical_rear))  &
   relative_to = .__ACME_MULTI_POST_TESTRIG.ger_mount_post_pad_vertical_rear
!
defaults coordinate_system  &
   default_coordinate_system = .__ACME_MULTI_POST_TESTRIG.ground
!
marker modify  &
   marker_name = .__ACME_MULTI_POST_TESTRIG.ger_mount_post_pad_vertical_rear.gracyl_4  &
   location =   &
      (LOC_RELATIVE_TO({0, 0, -50.0}mm, .__ACME_MULTI_POST_TESTRIG.ground.cfr_mount_post_pad_vertical_rear))  &
   orientation =   &
      (ORI_RELATIVE_TO({0, 0, 0}, .__ACME_MULTI_POST_TESTRIG.ground.cfr_mount_post_pad_vertical_rear))  &
   relative_to = .__ACME_MULTI_POST_TESTRIG.ger_mount_post_pad_vertical_rear
!
defaults coordinate_system  &
   default_coordinate_system = .__ACME_MULTI_POST_TESTRIG.ground
!
geometry modify shape cylinder  &
   cylinder_name = .__ACME_MULTI_POST_TESTRIG.ger_mount_post_pad_vertical_rear.gracyl_pad  &
   length = (0.0 + 50.0)
!
marker modify  &
   marker_name = .__ACME_MULTI_POST_TESTRIG.ger_mount_post_pad_vertical_rear.gracyl_10  &
   location =   &
      (LOC_RELATIVE_TO({0, 0, -1600.0}mm, .__ACME_MULTI_POST_TESTRIG.ground.cfr_mount_post_pad_vertical_rear))  &
   orientation =   &
      (ORI_RELATIVE_TO({0, 0, 0}, .__ACME_MULTI_POST_TESTRIG.ground.cfr_mount_post_pad_vertical_rear))  &
   relative_to = .__ACME_MULTI_POST_TESTRIG.ger_mount_post_pad_vertical_rear
!
defaults coordinate_system  &
   default_coordinate_system = .__ACME_MULTI_POST_TESTRIG.ground
!
geometry modify shape cylinder  &
   cylinder_name = .__ACME_MULTI_POST_TESTRIG.ger_mount_post_pad_vertical_rear.gracyl_post  &
   length = (0.0 + 1600.0)
!
marker modify  &
   marker_name = .__ACME_MULTI_POST_TESTRIG.ger_mount_post_pad_vertical_rear.jxs_joint_i_5  &
   location =   &
      (LOC_RELATIVE_TO({0, 0, 0}, .__ACME_MULTI_POST_TESTRIG.ground.jxs_joint_j_5))  &
   orientation =   &
      (ORI_RELATIVE_TO({0, 0, 0}, .__ACME_MULTI_POST_TESTRIG.ground.jxs_joint_j_5))  &
   relative_to = .__ACME_MULTI_POST_TESTRIG.ger_mount_post_pad_vertical_rear
!
defaults coordinate_system  &
   default_coordinate_system = .__ACME_MULTI_POST_TESTRIG.ground
!
marker modify  &
   marker_name = .__ACME_MULTI_POST_TESTRIG.ger_mount_post_pad_vertical_rear.jxr_joint_j_2  &
   location =   &
      (LOC_RELATIVE_TO({0.0, 0.0, 0.0}mm, .__ACME_MULTI_POST_TESTRIG.ground.cfr_wheel_center_rear))  &
   orientation =   &
      (ORI_RELATIVE_TO({0.0, 0.0, 0.0}degrees, .__ACME_MULTI_POST_TESTRIG.ground.cfr_wheel_center_rear))  &
   relative_to = .__ACME_MULTI_POST_TESTRIG.ger_mount_post_pad_vertical_rear
!
defaults coordinate_system  &
   default_coordinate_system = .__ACME_MULTI_POST_TESTRIG.ground
!
part modify rigid_body name_and_position  &
   part_name = .__ACME_MULTI_POST_TESTRIG.ger_mount_post_pad_vertical_rear  &
   location =   &
      (LOC_RELATIVE_TO({0.0, 0.0, 0.0}mm, .__ACME_MULTI_POST_TESTRIG.ground.cfr_mount_post_pad_vertical_rear))
!
marker modify  &
   marker_name = .__ACME_MULTI_POST_TESTRIG.gel_mount_post_pad_vertical_rear2.inertia_frame  &
   location =   &
      (LOC_RELATIVE_TO({0, 0, 0}, .__ACME_MULTI_POST_TESTRIG.gel_mount_post_pad_vertical_rear2.cm))  &
   orientation =   &
      (ORI_RELATIVE_TO({0, 0, 0}, .__ACME_MULTI_POST_TESTRIG.gel_mount_post_pad_vertical_rear2))  &
   relative_to = .__ACME_MULTI_POST_TESTRIG.gel_mount_post_pad_vertical_rear2
!
defaults coordinate_system  &
   default_coordinate_system = .__ACME_MULTI_POST_TESTRIG.ground
!
marker modify  &
   marker_name = .__ACME_MULTI_POST_TESTRIG.gel_mount_post_pad_vertical_rear2.gracyl_5  &
   location =   &
      (LOC_RELATIVE_TO({0, 0, -50.0}mm, .__ACME_MULTI_POST_TESTRIG.ground.cfl_mount_post_pad_vertical_rear2))  &
   orientation =   &
      (ORI_RELATIVE_TO({0, 0, 0}, .__ACME_MULTI_POST_TESTRIG.ground.cfl_mount_post_pad_vertical_rear2))  &
   relative_to = .__ACME_MULTI_POST_TESTRIG.gel_mount_post_pad_vertical_rear2
!
defaults coordinate_system  &
   default_coordinate_system = .__ACME_MULTI_POST_TESTRIG.ground
!
geometry modify shape cylinder  &
   cylinder_name = .__ACME_MULTI_POST_TESTRIG.gel_mount_post_pad_vertical_rear2.gracyl_pad  &
   length = (0.0 + 50.0)
!
marker modify  &
   marker_name = .__ACME_MULTI_POST_TESTRIG.gel_mount_post_pad_vertical_rear2.gracyl_11  &
   location =   &
      (LOC_RELATIVE_TO({0, 0, -1600.0}mm, .__ACME_MULTI_POST_TESTRIG.ground.cfl_mount_post_pad_vertical_rear2))  &
   orientation =   &
      (ORI_RELATIVE_TO({0, 0, 0}, .__ACME_MULTI_POST_TESTRIG.ground.cfl_mount_post_pad_vertical_rear2))  &
   relative_to = .__ACME_MULTI_POST_TESTRIG.gel_mount_post_pad_vertical_rear2
!
defaults coordinate_system  &
   default_coordinate_system = .__ACME_MULTI_POST_TESTRIG.ground
!
geometry modify shape cylinder  &
   cylinder_name = .__ACME_MULTI_POST_TESTRIG.gel_mount_post_pad_vertical_rear2.gracyl_post  &
   length = (0.0 + 1600.0)
!
marker modify  &
   marker_name = .__ACME_MULTI_POST_TESTRIG.gel_mount_post_pad_vertical_rear2.jxs_joint_i_4  &
   location =   &
      (LOC_RELATIVE_TO({0, 0, 0}, .__ACME_MULTI_POST_TESTRIG.ground.jxs_joint_j_4))  &
   orientation =   &
      (ORI_RELATIVE_TO({0, 0, 0}, .__ACME_MULTI_POST_TESTRIG.ground.jxs_joint_j_4))  &
   relative_to = .__ACME_MULTI_POST_TESTRIG.gel_mount_post_pad_vertical_rear2
!
defaults coordinate_system  &
   default_coordinate_system = .__ACME_MULTI_POST_TESTRIG.ground
!
marker modify  &
   marker_name = .__ACME_MULTI_POST_TESTRIG.gel_mount_post_pad_vertical_rear2.jxl_joint_j_3  &
   location =   &
      (LOC_RELATIVE_TO({0.0, 0.0, 0.0}mm, .__ACME_MULTI_POST_TESTRIG.ground.cfl_wheel_center_rear2))  &
   orientation =   &
      (ORI_RELATIVE_TO({0.0, 0.0, 0.0}degrees, .__ACME_MULTI_POST_TESTRIG.ground.cfl_wheel_center_rear2))  &
   relative_to = .__ACME_MULTI_POST_TESTRIG.gel_mount_post_pad_vertical_rear2
!
defaults coordinate_system  &
   default_coordinate_system = .__ACME_MULTI_POST_TESTRIG.ground
!
part modify rigid_body name_and_position  &
   part_name = .__ACME_MULTI_POST_TESTRIG.gel_mount_post_pad_vertical_rear2  &
   location =   &
      (LOC_RELATIVE_TO({0.0, 0.0, 0.0}mm, .__ACME_MULTI_POST_TESTRIG.ground.cfl_mount_post_pad_vertical_rear2))
!
marker modify  &
   marker_name = .__ACME_MULTI_POST_TESTRIG.ger_mount_post_pad_vertical_rear2.inertia_frame  &
   location =   &
      (LOC_RELATIVE_TO({0, 0, 0}, .__ACME_MULTI_POST_TESTRIG.ger_mount_post_pad_vertical_rear2.cm))  &
   orientation =   &
      (ORI_RELATIVE_TO({0, 0, 0}, .__ACME_MULTI_POST_TESTRIG.ger_mount_post_pad_vertical_rear2))  &
   relative_to = .__ACME_MULTI_POST_TESTRIG.ger_mount_post_pad_vertical_rear2
!
defaults coordinate_system  &
   default_coordinate_system = .__ACME_MULTI_POST_TESTRIG.ground
!
marker modify  &
   marker_name = .__ACME_MULTI_POST_TESTRIG.ger_mount_post_pad_vertical_rear2.gracyl_6  &
   location =   &
      (LOC_RELATIVE_TO({0, 0, -50.0}mm, .__ACME_MULTI_POST_TESTRIG.ground.cfr_mount_post_pad_vertical_rear2))  &
   orientation =   &
      (ORI_RELATIVE_TO({0, 0, 0}, .__ACME_MULTI_POST_TESTRIG.ground.cfr_mount_post_pad_vertical_rear2))  &
   relative_to = .__ACME_MULTI_POST_TESTRIG.ger_mount_post_pad_vertical_rear2
!
defaults coordinate_system  &
   default_coordinate_system = .__ACME_MULTI_POST_TESTRIG.ground
!
geometry modify shape cylinder  &
   cylinder_name = .__ACME_MULTI_POST_TESTRIG.ger_mount_post_pad_vertical_rear2.gracyl_pad  &
   length = (0.0 + 50.0)
!
marker modify  &
   marker_name = .__ACME_MULTI_POST_TESTRIG.ger_mount_post_pad_vertical_rear2.gracyl_12  &
   location =   &
      (LOC_RELATIVE_TO({0, 0, -1600.0}mm, .__ACME_MULTI_POST_TESTRIG.ground.cfr_mount_post_pad_vertical_rear2))  &
   orientation =   &
      (ORI_RELATIVE_TO({0, 0, 0}, .__ACME_MULTI_POST_TESTRIG.ground.cfr_mount_post_pad_vertical_rear2))  &
   relative_to = .__ACME_MULTI_POST_TESTRIG.ger_mount_post_pad_vertical_rear2
!
defaults coordinate_system  &
   default_coordinate_system = .__ACME_MULTI_POST_TESTRIG.ground
!
geometry modify shape cylinder  &
   cylinder_name = .__ACME_MULTI_POST_TESTRIG.ger_mount_post_pad_vertical_rear2.gracyl_post  &
   length = (0.0 + 1600.0)
!
marker modify  &
   marker_name = .__ACME_MULTI_POST_TESTRIG.ger_mount_post_pad_vertical_rear2.jxs_joint_i_6  &
   location =   &
      (LOC_RELATIVE_TO({0, 0, 0}, .__ACME_MULTI_POST_TESTRIG.ground.jxs_joint_j_6))  &
   orientation =   &
      (ORI_RELATIVE_TO({0, 0, 0}, .__ACME_MULTI_POST_TESTRIG.ground.jxs_joint_j_6))  &
   relative_to = .__ACME_MULTI_POST_TESTRIG.ger_mount_post_pad_vertical_rear2
!
defaults coordinate_system  &
   default_coordinate_system = .__ACME_MULTI_POST_TESTRIG.ground
!
marker modify  &
   marker_name = .__ACME_MULTI_POST_TESTRIG.ger_mount_post_pad_vertical_rear2.jxr_joint_j_3  &
   location =   &
      (LOC_RELATIVE_TO({0.0, 0.0, 0.0}mm, .__ACME_MULTI_POST_TESTRIG.ground.cfr_wheel_center_rear2))  &
   orientation =   &
      (ORI_RELATIVE_TO({0.0, 0.0, 0.0}degrees, .__ACME_MULTI_POST_TESTRIG.ground.cfr_wheel_center_rear2))  &
   relative_to = .__ACME_MULTI_POST_TESTRIG.ger_mount_post_pad_vertical_rear2
!
defaults coordinate_system  &
   default_coordinate_system = .__ACME_MULTI_POST_TESTRIG.ground
!
part modify rigid_body name_and_position  &
   part_name = .__ACME_MULTI_POST_TESTRIG.ger_mount_post_pad_vertical_rear2  &
   location =   &
      (LOC_RELATIVE_TO({0.0, 0.0, 0.0}mm, .__ACME_MULTI_POST_TESTRIG.ground.cfr_mount_post_pad_vertical_rear2))
!
ude modify instance  &
   instance_name = .__ACME_MULTI_POST_TESTRIG.jms_post_pad_vertical_lf  &
   location =   &
      (LOC_RELATIVE_TO({0, 0, 0}, .__ACME_MULTI_POST_TESTRIG.ground.origo))  &
   orientation =   &
      (ORI_RELATIVE_TO({0, 0, 0}, .__ACME_MULTI_POST_TESTRIG.ground.origo))
!
ude modify instance  &
   instance_name = .__ACME_MULTI_POST_TESTRIG.jms_post_pad_vertical_rf  &
   location =   &
      (LOC_RELATIVE_TO({0, 0, 0}, .__ACME_MULTI_POST_TESTRIG.ground.origo))  &
   orientation =   &
      (ORI_RELATIVE_TO({0, 0, 0}, .__ACME_MULTI_POST_TESTRIG.ground.origo))
!
ude modify instance  &
   instance_name = .__ACME_MULTI_POST_TESTRIG.jms_post_pad_vertical_lr  &
   location =   &
      (LOC_RELATIVE_TO({0, 0, 0}, .__ACME_MULTI_POST_TESTRIG.ground.origo))  &
   orientation =   &
      (ORI_RELATIVE_TO({0, 0, 0}, .__ACME_MULTI_POST_TESTRIG.ground.origo))
!
ude modify instance  &
   instance_name = .__ACME_MULTI_POST_TESTRIG.jms_post_pad_vertical_rr  &
   location =   &
      (LOC_RELATIVE_TO({0, 0, 0}, .__ACME_MULTI_POST_TESTRIG.ground.origo))  &
   orientation =   &
      (ORI_RELATIVE_TO({0, 0, 0}, .__ACME_MULTI_POST_TESTRIG.ground.origo))
!
ude modify instance  &
   instance_name = .__ACME_MULTI_POST_TESTRIG.jms_post_pad_vertical_lr2  &
   location =   &
      (LOC_RELATIVE_TO({0, 0, 0}, .__ACME_MULTI_POST_TESTRIG.ground.origo))  &
   orientation =   &
      (ORI_RELATIVE_TO({0, 0, 0}, .__ACME_MULTI_POST_TESTRIG.ground.origo))
!
ude modify instance  &
   instance_name = .__ACME_MULTI_POST_TESTRIG.jms_post_pad_vertical_rr2  &
   location =   &
      (LOC_RELATIVE_TO({0, 0, 0}, .__ACME_MULTI_POST_TESTRIG.ground.origo))  &
   orientation =   &
      (ORI_RELATIVE_TO({0, 0, 0}, .__ACME_MULTI_POST_TESTRIG.ground.origo))
!
marker modify  &
   marker_name = .__ACME_MULTI_POST_TESTRIG.mtl_suspension_mount_front.jxl_joint_i_1  &
   location =   &
      (LOC_RELATIVE_TO({0, 0, 0}, .__ACME_MULTI_POST_TESTRIG.gel_mount_post_pad_vertical_front.jxl_joint_j_1))  &
   orientation =   &
      (ORI_RELATIVE_TO({0, 0, 0}, .__ACME_MULTI_POST_TESTRIG.gel_mount_post_pad_vertical_front.jxl_joint_j_1))  &
   relative_to = .__ACME_MULTI_POST_TESTRIG.mtl_suspension_mount_front
!
defaults coordinate_system  &
   default_coordinate_system = .__ACME_MULTI_POST_TESTRIG.ground
!
part modify rigid_body name_and_position  &
   part_name = .__ACME_MULTI_POST_TESTRIG.mtl_suspension_mount_front  &
   location =   &
      (LOC_RELATIVE_TO({0, 0, 0}, .__ACME_MULTI_POST_TESTRIG.ground.cfl_mount_post_pad_vertical_front))  &
   orientation =   &
      (ORI_RELATIVE_TO({0, 0, 0}, .__ACME_MULTI_POST_TESTRIG.ground.origo))
!
variable modify  &
   variable_name = .__ACME_MULTI_POST_TESTRIG.cil_suspension_mount_front.minor_role  &
   string_value = (.__ACME_MULTI_POST_TESTRIG.mtl_suspension_mount_front.minor_role)
!
variable modify  &
   variable_name = .__ACME_MULTI_POST_TESTRIG.cil_suspension_mount_front.subsystem_index  &
   string_value = (.__ACME_MULTI_POST_TESTRIG.mtl_suspension_mount_front.subsystem_index)
!
variable modify  &
   variable_name = .__ACME_MULTI_POST_TESTRIG.cil_suspension_mount_front  &
   comments = ("Autocreated for mount part: " // .__ACME_MULTI_POST_TESTRIG.cil_suspension_mount_front[2].name)
!
marker modify  &
   marker_name = .__ACME_MULTI_POST_TESTRIG.mtr_suspension_mount_front.jxr_joint_i_1  &
   location =   &
      (LOC_RELATIVE_TO({0, 0, 0}, .__ACME_MULTI_POST_TESTRIG.ger_mount_post_pad_vertical_front.jxr_joint_j_1))  &
   orientation =   &
      (ORI_RELATIVE_TO({0, 0, 0}, .__ACME_MULTI_POST_TESTRIG.ger_mount_post_pad_vertical_front.jxr_joint_j_1))  &
   relative_to = .__ACME_MULTI_POST_TESTRIG.mtr_suspension_mount_front
!
defaults coordinate_system  &
   default_coordinate_system = .__ACME_MULTI_POST_TESTRIG.ground
!
part modify rigid_body name_and_position  &
   part_name = .__ACME_MULTI_POST_TESTRIG.mtr_suspension_mount_front  &
   location =   &
      (LOC_RELATIVE_TO({0, 0, 0}, .__ACME_MULTI_POST_TESTRIG.ground.cfr_mount_post_pad_vertical_front))  &
   orientation =   &
      (ORI_RELATIVE_TO({0, 0, 0}, .__ACME_MULTI_POST_TESTRIG.ground.origo))
!
variable modify  &
   variable_name = .__ACME_MULTI_POST_TESTRIG.cir_suspension_mount_front.minor_role  &
   string_value = (.__ACME_MULTI_POST_TESTRIG.mtr_suspension_mount_front.minor_role)
!
variable modify  &
   variable_name = .__ACME_MULTI_POST_TESTRIG.cir_suspension_mount_front.subsystem_index  &
   string_value = (.__ACME_MULTI_POST_TESTRIG.mtr_suspension_mount_front.subsystem_index)
!
variable modify  &
   variable_name = .__ACME_MULTI_POST_TESTRIG.cir_suspension_mount_front  &
   comments = ("Autocreated for mount part: " // .__ACME_MULTI_POST_TESTRIG.cir_suspension_mount_front[2].name)
!
marker modify  &
   marker_name = .__ACME_MULTI_POST_TESTRIG.mtl_suspension_mount_rear.jxl_joint_i_2  &
   location =   &
      (LOC_RELATIVE_TO({0, 0, 0}, .__ACME_MULTI_POST_TESTRIG.gel_mount_post_pad_vertical_rear.jxl_joint_j_2))  &
   orientation =   &
      (ORI_RELATIVE_TO({0, 0, 0}, .__ACME_MULTI_POST_TESTRIG.gel_mount_post_pad_vertical_rear.jxl_joint_j_2))  &
   relative_to = .__ACME_MULTI_POST_TESTRIG.mtl_suspension_mount_rear
!
defaults coordinate_system  &
   default_coordinate_system = .__ACME_MULTI_POST_TESTRIG.ground
!
part modify rigid_body name_and_position  &
   part_name = .__ACME_MULTI_POST_TESTRIG.mtl_suspension_mount_rear  &
   location =   &
      (LOC_RELATIVE_TO({0, 0, 0}, .__ACME_MULTI_POST_TESTRIG.ground.cfl_mount_post_pad_vertical_rear))  &
   orientation =   &
      (ORI_RELATIVE_TO({0, 0, 0}, .__ACME_MULTI_POST_TESTRIG.ground.origo))
!
variable modify  &
   variable_name = .__ACME_MULTI_POST_TESTRIG.cil_suspension_mount_rear.minor_role  &
   string_value = (.__ACME_MULTI_POST_TESTRIG.mtl_suspension_mount_rear.minor_role)
!
variable modify  &
   variable_name = .__ACME_MULTI_POST_TESTRIG.cil_suspension_mount_rear.subsystem_index  &
   string_value = (.__ACME_MULTI_POST_TESTRIG.mtl_suspension_mount_rear.subsystem_index)
!
variable modify  &
   variable_name = .__ACME_MULTI_POST_TESTRIG.cil_suspension_mount_rear  &
   comments = ("Autocreated for mount part: " // .__ACME_MULTI_POST_TESTRIG.cil_suspension_mount_rear[2].name)
!
marker modify  &
   marker_name = .__ACME_MULTI_POST_TESTRIG.mtr_suspension_mount_rear.jxr_joint_i_2  &
   location =   &
      (LOC_RELATIVE_TO({0, 0, 0}, .__ACME_MULTI_POST_TESTRIG.ger_mount_post_pad_vertical_rear.jxr_joint_j_2))  &
   orientation =   &
      (ORI_RELATIVE_TO({0, 0, 0}, .__ACME_MULTI_POST_TESTRIG.ger_mount_post_pad_vertical_rear.jxr_joint_j_2))  &
   relative_to = .__ACME_MULTI_POST_TESTRIG.mtr_suspension_mount_rear
!
defaults coordinate_system  &
   default_coordinate_system = .__ACME_MULTI_POST_TESTRIG.ground
!
part modify rigid_body name_and_position  &
   part_name = .__ACME_MULTI_POST_TESTRIG.mtr_suspension_mount_rear  &
   location =   &
      (LOC_RELATIVE_TO({0, 0, 0}, .__ACME_MULTI_POST_TESTRIG.ground.cfr_mount_post_pad_vertical_rear))  &
   orientation =   &
      (ORI_RELATIVE_TO({0, 0, 0}, .__ACME_MULTI_POST_TESTRIG.ground.origo))
!
variable modify  &
   variable_name = .__ACME_MULTI_POST_TESTRIG.cir_suspension_mount_rear.minor_role  &
   string_value = (.__ACME_MULTI_POST_TESTRIG.mtr_suspension_mount_rear.minor_role)
!
variable modify  &
   variable_name = .__ACME_MULTI_POST_TESTRIG.cir_suspension_mount_rear.subsystem_index  &
   string_value = (.__ACME_MULTI_POST_TESTRIG.mtr_suspension_mount_rear.subsystem_index)
!
variable modify  &
   variable_name = .__ACME_MULTI_POST_TESTRIG.cir_suspension_mount_rear  &
   comments = ("Autocreated for mount part: " // .__ACME_MULTI_POST_TESTRIG.cir_suspension_mount_rear[2].name)
!
marker modify  &
   marker_name = .__ACME_MULTI_POST_TESTRIG.mtl_suspension_mount_rear2.jxl_joint_i_3  &
   location =   &
      (LOC_RELATIVE_TO({0, 0, 0}, .__ACME_MULTI_POST_TESTRIG.gel_mount_post_pad_vertical_rear2.jxl_joint_j_3))  &
   orientation =   &
      (ORI_RELATIVE_TO({0, 0, 0}, .__ACME_MULTI_POST_TESTRIG.gel_mount_post_pad_vertical_rear2.jxl_joint_j_3))  &
   relative_to = .__ACME_MULTI_POST_TESTRIG.mtl_suspension_mount_rear2
!
defaults coordinate_system  &
   default_coordinate_system = .__ACME_MULTI_POST_TESTRIG.ground
!
part modify rigid_body name_and_position  &
   part_name = .__ACME_MULTI_POST_TESTRIG.mtl_suspension_mount_rear2  &
   location =   &
      (LOC_RELATIVE_TO({0, 0, 0}, .__ACME_MULTI_POST_TESTRIG.ground.cfl_mount_post_pad_vertical_rear2))  &
   orientation =   &
      (ORI_RELATIVE_TO({0, 0, 0}, .__ACME_MULTI_POST_TESTRIG.ground.origo))
!
variable modify  &
   variable_name = .__ACME_MULTI_POST_TESTRIG.cil_suspension_mount_rear2.minor_role  &
   string_value = (.__ACME_MULTI_POST_TESTRIG.mtl_suspension_mount_rear2.minor_role)
!
variable modify  &
   variable_name = .__ACME_MULTI_POST_TESTRIG.cil_suspension_mount_rear2.subsystem_index  &
   string_value = (.__ACME_MULTI_POST_TESTRIG.mtl_suspension_mount_rear2.subsystem_index)
!
variable modify  &
   variable_name = .__ACME_MULTI_POST_TESTRIG.cil_suspension_mount_rear2  &
   comments = ("Autocreated for mount part: " // .__ACME_MULTI_POST_TESTRIG.cil_suspension_mount_rear2[2].name)
!
marker modify  &
   marker_name = .__ACME_MULTI_POST_TESTRIG.mtr_suspension_mount_rear2.jxr_joint_i_3  &
   location =   &
      (LOC_RELATIVE_TO({0, 0, 0}, .__ACME_MULTI_POST_TESTRIG.ger_mount_post_pad_vertical_rear2.jxr_joint_j_3))  &
   orientation =   &
      (ORI_RELATIVE_TO({0, 0, 0}, .__ACME_MULTI_POST_TESTRIG.ger_mount_post_pad_vertical_rear2.jxr_joint_j_3))  &
   relative_to = .__ACME_MULTI_POST_TESTRIG.mtr_suspension_mount_rear2
!
defaults coordinate_system  &
   default_coordinate_system = .__ACME_MULTI_POST_TESTRIG.ground
!
part modify rigid_body name_and_position  &
   part_name = .__ACME_MULTI_POST_TESTRIG.mtr_suspension_mount_rear2  &
   location =   &
      (LOC_RELATIVE_TO({0, 0, 0}, .__ACME_MULTI_POST_TESTRIG.ground.cfr_mount_post_pad_vertical_rear2))  &
   orientation =   &
      (ORI_RELATIVE_TO({0, 0, 0}, .__ACME_MULTI_POST_TESTRIG.ground.origo))
!
variable modify  &
   variable_name = .__ACME_MULTI_POST_TESTRIG.cir_suspension_mount_rear2.minor_role  &
   string_value = (.__ACME_MULTI_POST_TESTRIG.mtr_suspension_mount_rear2.minor_role)
!
variable modify  &
   variable_name = .__ACME_MULTI_POST_TESTRIG.cir_suspension_mount_rear2.subsystem_index  &
   string_value = (.__ACME_MULTI_POST_TESTRIG.mtr_suspension_mount_rear2.subsystem_index)
!
variable modify  &
   variable_name = .__ACME_MULTI_POST_TESTRIG.cir_suspension_mount_rear2  &
   comments = ("Autocreated for mount part: " // .__ACME_MULTI_POST_TESTRIG.cir_suspension_mount_rear2[2].name)
!
part modify rigid_body name_and_position  &
   part_name = .__ACME_MULTI_POST_TESTRIG.mts_body_subsystem_deactive  &
   location =   &
      (LOC_RELATIVE_TO({0, 0, 0}, .__ACME_MULTI_POST_TESTRIG.ground.cfs_body_subsystem))  &
   orientation =   &
      (ORI_RELATIVE_TO({0, 0, 0}, .__ACME_MULTI_POST_TESTRIG.ground.origo))
!
marker modify  &
   marker_name = .__ACME_MULTI_POST_TESTRIG.mts_body_subsystem_deactive.jxs_joint_i_7  &
   location =   &
      (LOC_RELATIVE_TO({0, 0, 0}, .__ACME_MULTI_POST_TESTRIG.ground.jxs_joint_j_7))  &
   orientation =   &
      (ORI_RELATIVE_TO({0, 90d, 0}, .__ACME_MULTI_POST_TESTRIG.ground.origo))  &
   relative_to = .__ACME_MULTI_POST_TESTRIG.mts_body_subsystem_deactive
!
defaults coordinate_system  &
   default_coordinate_system = .__ACME_MULTI_POST_TESTRIG.ground
!
marker modify  &
   marker_name = .__ACME_MULTI_POST_TESTRIG.mts_body_subsystem_deactive.jxs_joint_i_8  &
   location =   &
      (LOC_RELATIVE_TO({0, 0, 0}, .__ACME_MULTI_POST_TESTRIG.ground.jxs_joint_j_8))  &
   orientation =   &
      (ORI_RELATIVE_TO({0, 0, 0}, .__ACME_MULTI_POST_TESTRIG.ground.jxs_joint_j_8))  &
   relative_to = .__ACME_MULTI_POST_TESTRIG.mts_body_subsystem_deactive
!
defaults coordinate_system  &
   default_coordinate_system = .__ACME_MULTI_POST_TESTRIG.ground
!
variable modify  &
   variable_name = .__ACME_MULTI_POST_TESTRIG.cis_body_subsystem_deactive  &
   comments = ("Autocreated for mount part: " // .__ACME_MULTI_POST_TESTRIG.cis_body_subsystem_deactive[2].name)
!
variable modify  &
   variable_name = .__ACME_MULTI_POST_TESTRIG.cis_body_subsystem_deactive.minor_role  &
   string_value = (.__ACME_MULTI_POST_TESTRIG.mts_body_subsystem_deactive.minor_role)
!
variable modify  &
   variable_name = .__ACME_MULTI_POST_TESTRIG.dual_wheel_offset_rear  &
   real_value = (EXPR_EXISTS(.__ACME_MULTI_POST_TESTRIG // ".cil_outside_wheel_center_rear.real_value") ? ABS(.__ACME_MULTI_POST_TESTRIG.cil_outside_wheel_center_rear[2] - .__ACME_MULTI_POST_TESTRIG.cil_wheel_center_rear[2]) : 0)
!
variable modify  &
   variable_name = .__ACME_MULTI_POST_TESTRIG.dual_wheel_offset_rear2  &
   real_value = (EXPR_EXISTS(.__ACME_MULTI_POST_TESTRIG // ".cil_outside_wheel_center_rear2.real_value") ? ABS(.__ACME_MULTI_POST_TESTRIG.cil_outside_wheel_center_rear2[2] - .__ACME_MULTI_POST_TESTRIG.cil_wheel_center_rear2[2]) : 0)
!
material modify  &
   material_name = .__ACME_MULTI_POST_TESTRIG.steel  &
   density = (7801.0(kg/meter**3))  &
   youngs_modulus = (2.07E+011(Newton/meter**2))
!
model display  &
   model_name = __ACME_MULTI_POST_TESTRIG
